////////////////////////////////////////////////////////////////////////////////
//
//  ****************************************************************************
//  * Unit Name : GSListviewActions
//  * Purpose   :    GSListView
//  * Author    : Max,  (Rouse_) 
//  * Copyright :    1998 - 2009 .
//  * Version   : 1.00
//  ****************************************************************************
//

unit GSListViewActions;

interface

uses
  Windows, SysUtils, Classes, ActnList, GSListView;

type

  TGsListViewActionUpdate = procedure(Sender, Target: TObject; var AEnabled: Boolean) of object;


  TCustomGsListViewAction = class(TCustomAction)
  private
    FOnUpdate: TGsListViewActionUpdate;
  protected
    function DoOnUpdate(Target: TObject;
      InitialState: Boolean): Boolean; virtual;
  public
    constructor Create(AOwner: TComponent); override;
    function HandlesTarget(Target: TObject): Boolean; override;
  published
    property OnUpdate: TGsListViewActionUpdate read FOnUpdate write FOnUpdate;
  end;

  TGsListViewAction = class(TCustomGsListViewAction)
  private
    FViewStyle: TGSViewStyle;
    FToggle: boolean;
  public
    procedure UpdateTarget(Target: TObject); override;
    procedure ExecuteTarget(Target: TObject); override;
  published
    property Caption;
    property Enabled;
    property HelpContext;
    property HelpKeyword;
    property HelpType;
    property Hint;
    property ImageIndex;
    property ShortCut;
    property SecondaryShortCuts;
    property Toggle: boolean read FToggle write FToggle default false;
    property Visible;
    property ViewStyle: TGSViewStyle read FViewStyle write FViewStyle default vsIcon;
      
    property OnHint;
  end;

implementation

{ TCustomGsListViewAction }

constructor TCustomGsListViewAction.Create(AOwner: TComponent);
begin
  inherited;
  DisableIfNoHandler := True;
end;

function TCustomGsListViewAction.DoOnUpdate(Target: TObject;
  InitialState: Boolean): Boolean;
begin
  Result := InitialState;
  if Assigned(FOnUpdate) then FOnUpdate(Self, Target, Result);
end;

function TCustomGsListViewAction.HandlesTarget(Target: TObject): Boolean;
begin
  Result := (Target <> nil) and (Target is TGSCustomListView) and TGSCustomListView(Target).Showing;
  if not Result then Checked := false;
end;

{ TGsListViewAction }

procedure TGsListViewAction.ExecuteTarget(Target: TObject);
var Vs: TGSViewStyle;  // vsIcon, vsSmallIcon, vsList, vsReport, vsTile
begin
  if FToggle then begin
    Vs := TGSCustomListView(Target).ViewStyle;
    if Vs = vsTile then Vs := vsIcon else inc(Vs);
  end
  else Vs := FViewStyle;
  TGSCustomListView(Target).ViewStyle := Vs;
end;

procedure TGsListViewAction.UpdateTarget(Target: TObject);
begin
  Enabled := DoOnUpdate(Target, true);
  if Enabled and not FToggle then Checked := TGSCustomListView(Target).ViewStyle = FViewStyle;
end;

end.
