////////////////////////////////////////////////////////////////////////////////
//
//  ****************************************************************************
//  * Unit Name : GSListView
//  * Purpose   :   VCL   SysListView32
//  * Author    :  (Rouse_) 
//  * Copyright :    1998 - 2011 .
//  * Version   : 1.53
//  ****************************************************************************
//

unit GSListView;

{$R-,T-,H+,X+,Q-}

interface

uses
  Messages, Windows, SysUtils, CommCtrl, Classes, Controls, Forms, Menus,
  Graphics, StdCtrls, RichEdit, ToolWin, ImgList, ExtCtrls, ListActns,
  ShlObj, GraphUtil, ComCtrls,
  GSListViewConsts
  {$IFDEF DEBUG}, Dialogs {$ENDIF};

  {$REGION ' SomeTypes '}
type

  TGSHitTest = (htAbove, htBelow, htNowhere, htOnItem, htOnButton, htOnIcon,
    htOnIndent, htOnLabel, htOnRight, htOnStateIcon, htToLeft, htToRight,
    htOnGroup, htOnGroupHeader, htOnGroupFooter, htOnGroupCollapse,
    htOnGroupBackGround, htOnGroupStateIcon, htOnGroupSubSetLink,
    htOnContents, htOnFooter);
  TGSHitTests = set of TGSHitTest;

  TSortType = (stNone, stData, stText, stBoth);
  TAutoSortStyle = (asUpDown, asUpDownNop);
  TAutoSortDataType = (dtNone, dtText, dtInteger, dtFloat, dtDate);

  TConversion = class(TObject)
  public
    function ConvertReadStream(Stream: TStream; Buffer: PChar; BufSize: Integer): Integer; virtual;
    function ConvertWriteStream(Stream: TStream; Buffer: PChar; BufSize: Integer): Integer; virtual;
  end;

  TConversionClass = class of TConversion;  

  PConversionFormat = ^TConversionFormat;
  TConversionFormat = record
    ConversionClass: TConversionClass;
    Extension: string;
    Next: PConversionFormat;
  end;  

{ Custom draw }

  TCustomDrawTarget = (dtControl, dtItem, dtSubItem);
  TCustomDrawStage = (cdPrePaint, cdPostPaint, cdPreErase, cdPostErase);
  TCustomDrawState = set of (cdsSelected, cdsGrayed, cdsDisabled, cdsChecked,
    cdsFocused, cdsDefault, cdsHot, cdsMarked, cdsIndeterminate);

const
  ColumnHeaderWidth = LVSCW_AUTOSIZE_USEHEADER;
  ColumnTextWidth = LVSCW_AUTOSIZE;

type
  TGSListColumns = class;
  TGSListItem = class;
  TGSListItems = class;
  TGSCustomListView = class;
  TWidth = ColumnHeaderWidth..MaxInt;
  TGSSortDirection = (sdNone, sdUp, sdDown);

  TGSListGroupState = (
    lgsNormal,
    lgsHidden,
    lgsCollapsed,
    lgsNoHeader,
    lgsCollapsible,
    lgsFocused,
    lgsSelected,
    lgsSubseted,
    lgsSubSetLinkFocused
  );
  TGSListGroupStates = set of TGSListGroupState;

  TGSTileSizeFlag = (tsAutoSize, tsFixedWidth,
    tsFixedHeight, tsFixedSize, tsExtended);

  TUINTDinArray = array of UINT;

{$ENDREGION}

  { TGSAutosortParams }

  TGSAutosortParams = class(TPersistent)
  strict private
    FOwner: TGSCustomListView;
//    FUseGroup: Boolean;
    FSortStyle: TAutoSortStyle;
    FEnabled: Boolean;
    FUseDataType: Boolean;
  protected
    function GetOwner: TPersistent; override;
  public
    procedure Assign(Source: TPersistent); override;
    constructor Create(AOwner: TGSCustomListView);
  published
    property Enabled: Boolean read FEnabled write FEnabled default False;
    property SortStyle: TAutoSortStyle read FSortStyle write FSortStyle default asUpDown;
    property UseColumnDataType: Boolean read FUseDataType write FUseDataType default False;
//    property UseGroup: Boolean read FUseGroup write FUseGroup default True;
  end;

  { TRectWrapper }

  TSizeWrapper = class(TPersistent)
  private
    FSize: TSize;
    FOnChange: TNotifyEvent;
    function GetValue(const Index: Integer): Integer;
    procedure SetValue(const Index, Value: Integer);
  protected
    procedure Change; virtual;
    procedure AssignTo(Dest: TPersistent); override;
  public
    function GetSize: TSize;
    property OnChange: TNotifyEvent read FOnChange write FOnChange;
  published
    property X: Integer index 0 read GetValue write SetValue default 0;
    property Y: Integer index 1 read GetValue write SetValue default 0; 
  end;

  { TMarginsWrapper }

  TMarginsWrapper = class(TMargins)
  protected
    class procedure InitDefaults(Margins: TMargins); override;
  published
    property Left default 0;
    property Top default 0;
    property Right default 0;
    property Bottom default 0;
  end;

  { TGSListTiles}

  TGSListTiles = class(TPersistent)
  strict private
    FOwner: TGSCustomListView;
    FColumns: array of UINT;
    FSizeFlag: TGSTileSizeFlag;
    FTileSize: TSizeWrapper;
    FLines: Integer;
    FLabelMargin: TMarginsWrapper;
    FUpdateCount: Integer;
    procedure SetTileSize(const Value: TSizeWrapper);
    procedure SetLines(const Value: Integer);
    procedure SetLabelMargin(const Value: TMarginsWrapper);
    function GetColumn(Index: Integer): UINT;
    procedure SetColumn(Index: Integer; const Value: UINT);
    procedure SetSizeFlag(const Value: TGSTileSizeFlag);
  protected
    procedure OnLabelMarginChanged(Sender: TObject);
    procedure OnTileSizeChanged(Sender: TObject);
    procedure DoChanged; virtual;
    procedure ReadData(Reader: TReader);
    procedure WriteData(Writer: TWriter);
    function Handle: THandle;
    procedure DefineProperties(Filer: TFiler); override;
    procedure UpdateItems; virtual;
    procedure FillTileInfoColumn(var Value: TUINTDinArray); virtual;
  public
    procedure Assign(Source: TPersistent); override;
    constructor Create(AOwner: TGSCustomListView);
    destructor Destroy; override;
    procedure BeginUpdate;
    procedure EndUpdate;
    property Column[Index: Integer]: UINT read GetColumn write SetColumn;
  published
    property SizeFlag: TGSTileSizeFlag read FSizeFlag write SetSizeFlag default tsAutoSize;
    property TileSize: TSizeWrapper read FTileSize write SetTileSize;
    property LinesCount: Integer read FLines write SetLines default 0;
    property LabelMargin: TMarginsWrapper read FLabelMargin write SetLabelMargin;
  end;

  { TGSListGroup }

  TGSListGroupStringValues = (svHeader, svFooter, svSubtitle,
    svTask, svTopDescription, svBottomDescription, svSubsetTitle);

  TGSListGroupClass = class of TGSListGroup;
  TGSListGroup = class(TCollectionItem)
  strict private
    FHeader: String;
    FFooter: String;
    FGroupID: Integer;
    FState: TGSListGroupStates;
    FHeaderAlign: TAlignment;
    FFooterAlign: TAlignment;
    FSubtitle: String;
    FTask: String;
    FTopDescription: String;
    FBottomDescription: String;
    FTitleImage: TImageIndex;
    FExtendedImage: TImageIndex;
    FSubsetTitle: String;
    procedure SetGroupID(Value: Integer);
    procedure SetState(Value: TGSListGroupStates);
    function GetState: TGSListGroupStates;
    procedure SetHeaderAlign(Value: TAlignment);
    procedure SetFooterAlign(Value: TAlignment);
    procedure SetTitleImage(Value: TImageIndex);
    procedure SetExtendedImage(Value: TImageIndex);
    procedure SetString(const Index: TGSListGroupStringValues; const Value: String);
    function GetString(const Index: TGSListGroupStringValues): String;
  protected
    function GetDisplayName: String; override;
    procedure UpdateGroups;
    property PreparedState: TGSListGroupStates read FState;
  public
    constructor Create(Collection: TCollection); override;
    destructor Destroy; override;
    procedure Assign(Source: TPersistent); override;
  published
    property Header: String index svHeader read GetString write SetString;
    property Footer: String index svFooter read GetString write SetString;
    property GroupID: Integer read FGroupID write SetGroupID default 0;
    property State: TGSListGroupStates read GetState
      write SetState default [lgsNormal, lgsCollapsible];
    property HeaderAlign: TAlignment read FHeaderAlign
      write SetHeaderAlign default taLeftJustify;
    property FooterAlign: TAlignment read FFooterAlign
      write SetFooterAlign default taLeftJustify;
    property Subtitle: String index svSubtitle read GetString write SetString;
    property Task: String index svTask read GetString write SetString;
    property TopDescription: String index svTopDescription read GetString write SetString;
    property BottomDescription: String index svBottomDescription read GetString write SetString;
    property TitleImage: TImageIndex read FTitleImage
      write SetTitleImage default -1;
    property ExtendedImage: TImageIndex read FExtendedImage
      write SetExtendedImage default -1;
    property SubsetTitle: String index svSubsetTitle read GetString write SetString;
  end;

  { TGSListGroups }

  TGroupClickEvent = procedure(Sender: TObject; Group: TGSListGroup) of object;

  TGSListGroups = class(TOwnedCollection)
  private
    FEnable: Boolean;
    FGroupClick: TGroupClickEvent;
    FGroupDblClick: TGroupClickEvent;
    FInverted, FLockUpdateNow: Boolean;
    function GetItem(Index: Integer): TGSListGroup;
    procedure SetItem(Index: Integer; const Value: TGSListGroup);
    function GetHandle: HWND;
    procedure SetEnable(const Value: Boolean);
    function GetNextGroupID: Integer;
    procedure SetInverted(const Value: Boolean);
  protected
    procedure DoGroupClick(Value: TGSListGroup);
    procedure DoGroupDblClick(Value: TGSListGroup);
    procedure Notify(Item: TCollectionItem; Action: TCollectionNotification); override;    
    function GetItemClass: TGSListGroupClass; virtual;
    procedure Update(Item: TCollectionItem); override;
    procedure UpdateGroups;
  public
    constructor Create(AOwner: TGSCustomListView); virtual;
    function Add: TGSListGroup;
    function Owner: TGSCustomListView;
    function GetGroupIndexByName(const Value: String;
      const StringValueType: TGSListGroupStringValues = svHeader): Integer;
    property Handle: HWND read GetHandle;
    property Items[Index: Integer]: TGSListGroup read GetItem write SetItem; default;
    property NextGroupID: Integer read GetNextGroupID;
  published
    property Enabled: Boolean read FEnable write SetEnable default False;
    property Inverted: Boolean read FInverted write SetInverted default False;
    property OnGroupClick: TGroupClickEvent read FGroupClick write FGroupClick;
    property OnGroupDblClick: TGroupClickEvent read FGroupDblClick
      write FGroupDblClick;
  end;

  { TGSListColumn }

  TGSListColumn = class(TCollectionItem)
  private
    FAlignment: TAlignment;
    FAutoSize: Boolean;
    FCaption: string;
    FMaxWidth: TWidth;
    FMinWidth: TWidth;
    FImageIndex: TImageIndex;
    FPrivateWidth: TWidth;
    FWidth: TWidth;
    FOrderTag,
    FTag: Integer;
    FDataType: TAutoSortDataType;
    FSplitButton: Boolean;
    FCheckBox: Boolean;
    FChecked: Boolean;
    procedure DoChange;
    function GetWidth: TWidth;
    function IsWidthStored: Boolean;
    procedure ReadData(Reader: TReader);
    procedure SetAlignment(Value: TAlignment);
    procedure SetAutoSize(Value: Boolean);
    procedure SetCaption(const Value: string);
    procedure SetImageIndex(Value: TImageIndex);
    procedure SetMaxWidth(Value: TWidth);
    procedure SetMinWidth(Value: TWidth);
    procedure SetWidth(Value: TWidth);
    procedure WriteData(Writer: TWriter);
    procedure SetSplitButton(const Value: Boolean);
    procedure SetCheckBox(const Value: Boolean);
    procedure SetChecked(const Value: Boolean);
  protected
    procedure DefineProperties(Filer: TFiler); override;
    function GetDisplayName: string; override;
    procedure SetIndex(Value: Integer); override;
  public
    constructor Create(Collection: TCollection); override;
    destructor Destroy; override;
    procedure Assign(Source: TPersistent); override;
    property WidthType: TWidth read FWidth;
  published
    property Alignment: TAlignment read FAlignment write SetAlignment default taLeftJustify;
    property AutoSize: Boolean read FAutoSize write SetAutoSize default False;
    property Caption: string read FCaption write SetCaption;
    property CheckBox: Boolean read FCheckBox write SetCheckBox;
    property Checked: Boolean read FChecked write SetChecked;
    property ImageIndex: TImageIndex read FImageIndex write SetImageIndex default -1;
    property MaxWidth: TWidth read FMaxWidth write SetMaxWidth default 0;
    property MinWidth: TWidth read FMinWidth write SetMinWidth default 0;
    property SplitButton: Boolean read FSplitButton write SetSplitButton;
    property Tag: Integer read FTag write FTag default 0;
    property Width: TWidth read GetWidth write SetWidth stored IsWidthStored default 50;
    property DataType: TAutoSortDataType read FDataType write FDataType default dtNone;
  end;

  { TGSListColumns }

  TGSListColumns = class(TCollection)
  private
    FOwner: TGSCustomListView;
    FHeaderHandle: THandle;
    FSortedIndex: Integer;
    FSortDirection: TGSSortDirection;
    function GetItem(Index: Integer): TGSListColumn;
    procedure SetItem(Index: Integer; Value: TGSListColumn);
    procedure UpdateCols;
    procedure SetSortedIndex(const Value: Integer);
    function GetHeaderHandle: THandle;
    procedure SetSortDirection(const Value: TGSSortDirection);
  protected
    procedure SetColumnSortedMask(const PreviosSelected: Integer = -1);
    function GetOwner: TPersistent; override;
    procedure Update(Item: TCollectionItem); override;
    property HeaderHandle: THandle read GetHeaderHandle;
  public
    constructor Create(AOwner: TGSCustomListView); virtual;
    function Add: TGSListColumn; virtual;
    function Owner: TGSCustomListView;
    property Items[Index: Integer]: TGSListColumn read GetItem write SetItem; default;
    property SortedIndex: Integer read FSortedIndex write SetSortedIndex;
    property SortDirection: TGSSortDirection
      read FSortDirection write SetSortDirection;
  end;

  TDisplayCode = (drBounds, drIcon, drLabel, drSelectBounds);

  { TGSListItem }

  TGSListItemClass = class of TGSListItem;
  TGSListItem = class(TPersistent)
  private
    FOwner: TGSListItems;
    FSubItems: TStrings;
    FData: Pointer;
    FImageIndex: TImageIndex;
    FIndent: Integer;
    FIndex: Integer;
    FOverlayIndex: TImageIndex;
    FStateIndex: TImageIndex;
    FCaption: string;
    FDeleting: Boolean;
    FProcessedDeleting: Boolean;
    FChecked: Boolean;
    FGroupID: Integer;
    FTileIndex: TImageIndex;
    FLargeIndex: TImageIndex;
    FTag: Integer;
    function GetChecked: Boolean;
    function GetHandle: HWND;
    function GetIndex: Integer;
    function GetListView: TGSCustomListView;
    function GetLeft: Integer;
    function GetState(Index: Integer): Boolean;
    function GetTop: Integer;
    function IsEqual(Item: TGSListItem): Boolean;
    procedure SetChecked(Value: Boolean);
    procedure SetCaption(const Value: string);
    procedure SetData(Value: Pointer);
    procedure SetImage(Index: Integer; Value: TImageIndex);
    procedure SetIndent(Value: Integer);
    procedure SetLeft(Value: Integer);
    procedure SetState(Index: Integer; State: Boolean);
    procedure SetSubItems(Value: TStrings);
    procedure SetTop(Value: Integer);
    function GetSubItemImage(Index: Integer): Integer;
    procedure SetSubItemImage(Index: Integer; const Value: Integer);
    procedure SetGroupID(const Value: Integer);
  protected
    procedure UpdateTile;
  public
    constructor Create(AOwner: TGSListItems);
    destructor Destroy; override;
    procedure Assign(Source: TPersistent); override;
    procedure CancelEdit;
    procedure Delete;
    function DisplayRect(Code: TDisplayCode): TRect;
    function EditCaption: Boolean;
    function GetPosition: TPoint;
    procedure MakeVisible(PartialOK: Boolean);
    procedure Update;
    procedure SetPosition(const Value: TPoint);
    function WorkArea: Integer;
    property Data: Pointer read FData write SetData;
    property SubItemImages[Index: Integer]: Integer read GetSubItemImage write SetSubItemImage;    
//  published
    property Caption: string read FCaption write SetCaption;
    property Checked: Boolean read GetChecked write SetChecked;
    property Cut: Boolean index 0 read GetState write SetState;
    property Deleting: Boolean read FDeleting;
    property DropTarget: Boolean index 1 read GetState write SetState;
    property Focused: Boolean index 2 read GetState write SetState;
    property GroupID: Integer read FGroupID write SetGroupID default -1;
    property Handle: HWND read GetHandle;
    property ImageIndex: TImageIndex index 0 read FImageIndex write SetImage;
    property Indent: Integer read FIndent write SetIndent default 0;
    property Index: Integer read GetIndex;
    property Left: Integer read GetLeft write SetLeft;
    property ListView: TGSCustomListView read GetListView;
    property Owner: TGSListItems read FOwner;
    property OverlayIndex: TImageIndex index 1 read FOverlayIndex write SetImage;
    property Position: TPoint read GetPosition write SetPosition;
    property Selected: Boolean index 3 read GetState write SetState;
    property StateIndex: TImageIndex index 2 read FStateIndex write SetImage;
    property SubItems: TStrings read FSubItems write SetSubItems;
    property Tag: Integer read FTag write FTag; 
    property Top: Integer read GetTop write SetTop;
    property LargeIndex: TImageIndex index 3 read FLargeIndex write SetImage;
    property TileIndex: TImageIndex index 4 read FTileIndex write SetImage;
  end;

{ TGSListItemsEnumerator }

  TGSListItemsEnumerator = class
  private
    FIndex: Integer;
    FListItems: TGSListItems;
  public
    constructor Create(AListItems: TGSListItems);
    function GetCurrent: TGSListItem;
    function MoveNext: Boolean;
    property Current: TGSListItem read GetCurrent;
  end;

{ TGSListItems }

  TGSListItems = class(TPersistent)
  private
    FOwner: TGSCustomListView;
    FUpdateCount: Integer;
    FNoRedraw: Boolean;
    procedure ReadData(Stream: TStream);
    procedure ReadItemData(Stream: TStream);
    procedure WriteItemData(Stream: TStream);
  protected
    procedure DefineProperties(Filer: TFiler); override;
    function CreateItem(Index: Integer; ListItem: TGSListItem): TLVItem;
    function GetCount: Integer;
    function GetHandle: HWND;
    function GetItem(Index: Integer): TGSListItem;
    procedure SetCount(Value: Integer);
    procedure SetItem(Index: Integer; Value: TGSListItem);
    procedure SetUpdateState(Updating: Boolean);
    property UpdateCount: Integer read FUpdateCount;
  public
    constructor Create(AOwner: TGSCustomListView);
    destructor Destroy; override;
    function Add: TGSListItem;
    function AddItem(Item: TGSListItem; Index: Integer = -1): TGSListItem;
    procedure Assign(Source: TPersistent); override;
    procedure BeginUpdate;
    procedure Clear;
    procedure Delete(Index: Integer);
    procedure EndUpdate;
    function GetEnumerator: TGSListItemsEnumerator;
    procedure GroupCheckOperation(CheckAll: Boolean);
    function IndexOf(Value: TGSListItem): Integer;
    function Insert(Index: Integer): TGSListItem;
    property Count: Integer read GetCount write SetCount;
    property Handle: HWND read GetHandle;
    property Item[Index: Integer]: TGSListItem read GetItem write SetItem; default;
    property Owner: TGSCustomListView read FOwner;
  end;

{ TWorkArea }

  TWorkArea = class(TCollectionItem)
  private
    FRect: TRect;
    FDisplayName: string;
    FColor: TColor;
    procedure SetRect(const Value: TRect);
    procedure SetColor(const Value: TColor);
  public
    constructor Create(Collection: TCollection); override;
    procedure SetDisplayName(const Value: string); override;
    function  GetDisplayName: string; override;
    property Rect: TRect read FRect write SetRect;
    property Color: TColor read FColor write SetColor;
  end;

{ TWorkAreas }

  TWorkAreas = class(TOwnedCollection)
  private
    function  GetItem(Index: Integer): TWorkArea;
    procedure SetItem(Index: Integer; const Value: TWorkArea);
  protected
    procedure Changed;
    procedure Update(Item: TCollectionItem); override;
  public
    function  Add: TWorkArea;
    procedure Delete(Index: Integer);
    function  Insert(Index: Integer): TWorkArea;
    property  Items[Index: Integer]: TWorkArea read GetItem write SetItem; default;
  end;

{ TIconOptions }

  TIconArrangement = (iaTop, iaLeft);

  TIconOptions = class(TPersistent)
  private
    FListView: TGSCustomListView;
    FArrangement: TIconArrangement;
    FAutoArrange: Boolean;
    GSrapText: Boolean;
    procedure SetArrangement(Value: TIconArrangement);
    procedure SetAutoArrange(Value: Boolean);
    procedure SetWrapText(Value: Boolean);
  public
    constructor Create(AOwner: TGSCustomListView);
  published
    property Arrangement: TIconArrangement read FArrangement write SetArrangement default iaTop;
    property AutoArrange: Boolean read FAutoArrange write SetAutoArrange default False;
    property WrapText: Boolean read GSrapText write SetWrapText default True;
  end;

  TOwnerDrawState = Windows.TOwnerDrawState;

  {$REGION ' EventsDefine '}

  (*$NODEFINE TOwnerDrawState*)

  TListArrangement = (arAlignBottom, arAlignLeft, arAlignRight,
    arAlignTop, arDefault, arSnapToGrid);
  TGSViewStyle = (vsIcon, vsSmallIcon, vsList, vsReport, vsTile);
  TItemState = (isNone, isCut, isDropHilited, isFocused, isSelected, isActivating);
  TItemStates = set of TItemState;
  TItemChange = (ctText, ctImage, ctState);
  TItemFind = (ifData, ifPartialString, ifExactString, ifNearest);
  TSearchDirection = (sdLeft, sdRight, sdAbove, sdBelow, sdAll);
  TListHotTrackStyle = (htHandPoint, htUnderlineCold, htUnderlineHot);
  TListHotTrackStyles = set of TListHotTrackStyle;
  TItemRequests = (irText, irImage, irParam, irState, irIndent);
  TItemRequest = set of TItemRequests;

  TLVDeletedEvent = procedure(Sender: TObject; Item: TGSListItem) of object;
  TLVEditingEvent = procedure(Sender: TObject; Item: TGSListItem;
    var AllowEdit: Boolean) of object;
  TLVEditedEvent = procedure(Sender: TObject; Item: TGSListItem; var S: string) of object;
  TLVChangeEvent = procedure(Sender: TObject; Item: TGSListItem;
    Change: TItemChange) of object;
  TLVChangingEvent = procedure(Sender: TObject; Item: TGSListItem;
    Change: TItemChange; var AllowChange: Boolean) of object;
  TLVColumnClickEvent = procedure(Sender: TObject; Column: TGSListColumn) of object;
  TLVColumnRClickEvent = procedure(Sender: TObject; Column: TGSListColumn;
    APoint: TPoint) of object;
  TLVCompareEvent = procedure(Sender: TObject; Item1, Item2: TGSListItem;
    Data: Integer; var Compare: Integer) of object;
  TLVNotifyEvent = procedure(Sender: TObject; Item: TGSListItem) of object;
  TLVSelectItemEvent = procedure(Sender: TObject; Item: TGSListItem;
    Selected: Boolean) of object;
  TLVDrawItemEvent = procedure(Sender: TGSCustomListView; Item: TGSListItem;
    Rect: TRect; State: TOwnerDrawState) of object;
  TLVCustomDrawEvent = procedure(Sender: TGSCustomListView; const ARect: TRect;
    var DefaultDraw: Boolean) of object;
  TLVCustomDrawItemEvent = procedure(Sender: TGSCustomListView; Item: TGSListItem;
    State: TCustomDrawState; var DefaultDraw: Boolean) of object;
  TLVCustomDrawSubItemEvent = procedure(Sender: TGSCustomListView; Item: TGSListItem;
    SubItem: Integer; State: TCustomDrawState; var DefaultDraw: Boolean) of object;
  TLVAdvancedCustomDrawEvent = procedure(Sender: TGSCustomListView; const ARect: TRect;
    Stage: TCustomDrawStage; var DefaultDraw: Boolean) of object;
  TLVAdvancedCustomDrawItemEvent = procedure(Sender: TGSCustomListView; Item: TGSListItem;
    State: TCustomDrawState; Stage: TCustomDrawStage; var DefaultDraw: Boolean) of object;
  TLVAdvancedCustomDrawSubItemEvent = procedure(Sender: TGSCustomListView; Item: TGSListItem;
    SubItem: Integer; State: TCustomDrawState; Stage: TCustomDrawStage;
    var DefaultDraw: Boolean) of object;
  TLVOwnerDataEvent = procedure(Sender: TObject; Item: TGSListItem) of object;
  TLVOwnerDataFindEvent = procedure(Sender: TObject; Find: TItemFind;
    const FindString: string; const FindPosition: TPoint; FindData: Pointer;
    StartIndex: Integer; Direction: TSearchDirection; Wrap: Boolean;
    var Index: Integer) of object;
  TLVOwnerDataHintEvent = procedure(Sender: TObject; StartIndex, EndIndex: Integer) of object;
  TLVOwnerDataStateChangeEvent = procedure(Sender: TObject; StartIndex,
    EndIndex: Integer; OldState, NewState: TItemStates) of object;
  TLVSubItemImageEvent = procedure(Sender: TObject; Item: TGSListItem; SubItem: Integer;
    var ImageIndex: Integer) of object;
  TLVInfoTipEvent = procedure(Sender: TObject; Item: TGSListItem; var InfoTip: string) of object;
  TLVCreateItemClassEvent = procedure(Sender: TGSCustomListView; var ItemClass: TGSListItemClass) of object;
  TGSListViewTracEvent = procedure(Sender: TObject; var AWidth: Integer) of object;
  TGSListViewPopUpEvent = procedure(Sender: TObject;
    const MousePos: TPoint; var Handled: Boolean) of object;
  TGSListViewTaskClick = procedure(Sender: TObject;
    Group: TGSListGroup) of object;

  {$ENDREGION}

{ TGSCustomListView }

  TGSCustomListView = class(TCustomMultiSelectListControl)
  strict private type
    TContextPopupStack = (psEdit, psSelected, psNone);
    TContextPopupStacks = set of TContextPopupStack;
  private
    FCanvas: TCanvas;
    FBorderStyle: TBorderStyle;
    FViewStyle: TGSViewStyle;
    FReadOnly: Boolean;
    FLargeImages: TCustomImageList;
    FSaveSelectedIndex: Integer;
    FSmallImages: TCustomImageList;
    FStateImages: TCustomImageList;
    FDragImage: TDragImageList;
    FMultiSelect: Boolean;
    FSortType: TSortType;
    FColumnClick: Boolean;
    FShowColumnHeaders: Boolean;
    FListItems: TGSListItems;
    FClicked: Boolean;
    FRClicked: Boolean;
    FIconOptions: TIconOptions;
    FHideSelection: Boolean;
    FListColumns: TGSListColumns;
    FMemStream: TMemoryStream;
    FOwnerData: Boolean;
    FOwnerDraw: Boolean;
    FColStream: TMemoryStream;
    FCheckStream: TMemoryStream;
    FEditInstance: Pointer;
    FDefEditProc: Pointer;
    FEditHandle: HWND;
    FHeaderInstance: Pointer;
    FDefHeaderProc: Pointer;
    FHeaderHandle: HWND;
    FAllocBy: Integer;
    FDragIndex: Integer;
    FLastDropTarget: TGSListItem;
    FCheckboxes: Boolean;
    FFlatScrollBars: Boolean;
    FFullDrag: Boolean;
    FGridLines: Boolean;
    FHotTrack: Boolean;
    FHotTrackStyles: TListHotTrackStyles;
    FRowSelect: Boolean;
    FHoverTime: Integer;
    FTileChangeLink: TChangeLink;
    FLargeChangeLink: TChangeLink;
    FSmallChangeLink: TChangeLink;
    FStateChangeLink: TChangeLink;
    FSavedSort: TSortType;
    FReading: Boolean;
    FCanvasChanged: Boolean;
    FTempItem: TGSListItem;
    GSorkAreas: TWorkAreas;
    FShowWorkAreas: Boolean;
    FUpdatingColumnOrder: Boolean;
    FOurFont: Integer;
    FStockFont: Integer;
    FOwnerDataCount: Integer;
    FOnAdvancedCustomDraw: TLVAdvancedCustomDrawEvent;
    FOnAdvancedCustomDrawItem: TLVAdvancedCustomDrawItemEvent;
    FOnAdvancedCustomDrawSubItem: TLVAdvancedCustomDrawSubItemEvent;
    FOnChange: TLVChangeEvent;
    FOnChanging: TLVChangingEvent;
    FOnColumnClick: TLVColumnClickEvent;
    FOnColumnDragged: TNotifyEvent;
    FOnColumnRightClick: TLVColumnRClickEvent;
    FOnCompare: TLVCompareEvent;
    FOnCustomDraw: TLVCustomDrawEvent;
    FOnCustomDrawItem: TLVCustomDrawItemEvent;
    FOnCustomDrawSubItem: TLVCustomDrawSubItemEvent;
    FOnData: TLVOwnerDataEvent;
    FOnDataFind: TLVOwnerDataFindEvent;
    FOnDataHint: TLVOwnerDataHintEvent;
    FOnDataStateChange: TLVOwnerDataStateChangeEvent;
    FOnDeletion: TLVDeletedEvent;
    FOnDrawItem: TLVDrawItemEvent;
    FOnEdited: TLVEditedEvent;
    FOnEditing: TLVEditingEvent;
    FOnGetImageIndex: TLVNotifyEvent;
    FOnGetSubItemImage: TLVSubItemImageEvent;
    FOnInfoTip: TLVInfoTipEvent;
    FOnInsert: TLVDeletedEvent;
    FOnSelectItem: TLVSelectItemEvent;
    FOnCreateItemClass: TLVCreateItemClassEvent;

    FSaveSortSection: Integer;
    FSaveSortDirection: TGSSortDirection;

    FGroups: TGSListGroups;
    FTiles: TGSListTiles;
    FShowColumnAllwais: Boolean;
    FTileImages: TCustomImageList;
    FColumnAutosort: TGSAutosortParams;
    FTrackedColumn: Integer;
    FEndTrack: TNotifyEvent;
    FTrack: TGSListViewTracEvent;
    FBeginTrack: TNotifyEvent;
    FOnSelectedPopup: TContextPopupEvent;
    FOnEditPopup: TContextPopupEvent;
    FBlockDblClick: Boolean;
    FColumnDropDown: TLVColumnRClickEvent;
    FCustomTrack: Boolean;
//    FDoubleBuffered: Boolean;
    FHeaderOverflow: Boolean;
    FLockedColumnsWidth: TList;
    FBlockUpdateColumns: Boolean;
    // Rouse_ 19.04.2010
    //         
    FTaskClick: TGSListViewTaskClick;
    function AreItemsStored: Boolean;
    procedure CanvasChanged(Sender: TObject);
    procedure CMColorChanged(var Message: TMessage); message CM_COLORCHANGED;
    procedure CMCtl3DChanged(var Message: TMessage); message CM_CTL3DCHANGED;
    procedure CMDrag(var Message: TCMDrag); message CM_DRAG;
    procedure CMFontChanged(var Message: TMessage); message CM_FONTCHANGED;
    procedure CNNotify(var Message: TWMNotify); message CN_NOTIFY;
    procedure DoAutoSize;
    procedure DoDragOver(Source: TDragObject; X, Y: Integer; CanDrop: Boolean);
    procedure DrawWorkAreas;
    procedure EditWndProc(var Message: TMessage);
    function GetBoundingRect: TRect;
    function GetColumnFromIndex(Index: Integer): TGSListColumn;
    function GetColumnFromTag(Tag: Integer): TGSListColumn;
    function GetDropTarget: TGSListItem;
    function GetFocused: TGSListItem;
    procedure GetImageIndex(Item: TGSListItem);
    procedure GetSubItemImage(Item: TGSListItem; SubItem: Integer; var ImageIndex: Integer);
    function GetItem(Value: TLVItem): TGSListItem;
    function GetSelected: TGSListItem;
    function GetTopItem: TGSListItem;
    function GetViewOrigin: TPoint;
    function GetVisibleRowCount: Integer;
    function GetHoverTime: Integer;
    procedure HeaderWndProc(var Message: TMessage);
    procedure ImageListChange(Sender: TObject);
    procedure RestoreChecks;
    procedure SaveChecks;
    procedure SetBorderStyle(Value: TBorderStyle);
    procedure SetColumnClick(Value: Boolean);
    procedure SetColumnHeaders(Value: Boolean);
    procedure SetDropTarget(Value: TGSListItem);
    procedure SetFocused(Value: TGSListItem);
    procedure SetHideSelection(Value: Boolean);
    procedure SetIconOptions(Value: TIconOptions);
    procedure SetImageList(Value: HImageList; Flags: Integer);
    procedure SetNormalImageList;
    procedure SetLargeImages(Value: TCustomImageList);
    procedure SetAllocBy(Value: Integer);
    procedure SetItems(Value: TGSListItems);
    procedure SetListColumns(Value: TGSListColumns);
    procedure SetOwnerData(Value: Boolean);
    procedure SetOwnerDraw(Value: Boolean);
    procedure SetReadOnly(Value: Boolean);
    procedure SetShowWorkAreas(const Value: Boolean);
    procedure SetSmallImages(Value: TCustomImageList);
    procedure SetSortType(Value: TSortType);
    procedure SetSelected(Value: TGSListItem);
    procedure SetStateImages(Value: TCustomImageList);
    procedure SetTextBkColor(Value: TColor);
    procedure SetTextColor(Value: TColor);
    procedure SetCheckboxes(Value: Boolean);
    procedure SetFlatScrollBars(Value: Boolean);
    procedure SetFullDrag(Value: Boolean);
    procedure SetGridLines(Value: Boolean);
    procedure SetHotTrack(Value: Boolean);
    procedure SetHotTrackStyles(Value: TListHotTrackStyles);
    procedure SetRowSelect(Value: Boolean);
    procedure SetHoverTime(Value: Integer);
    procedure ResetExStyles;
    function ValidHeaderHandle: Boolean;
    procedure WMLButtonDown(var Message: TWMLButtonDown); message WM_LBUTTONDOWN;
    procedure WMNotify(var Message: TWMNotify); message WM_NOTIFY;
    procedure WMParentNotify(var Message: TWMParentNotify); message WM_PARENTNOTIFY;
    procedure WMPaint(var Message: TWMPaint); message WM_PAINT;
    procedure WMVScroll(var Message: TWMVScroll); message WM_VSCROLL;
    procedure WMWindowPosChanged(var Message: TWMWindowPosChanged); message WM_WINDOWPOSCHANGED;
    procedure CNDrawItem(var Message: TWMDrawItem); message CN_DRAWITEM;
    procedure CMHintShow(var Message: TMessage); message CM_HINTSHOW;
    procedure WMContextMenu(var Message: TWMContextMenu); message WM_CONTEXTMENU;
    procedure WMCtlColorEdit(var Message: TMessage); message WM_CTLCOLOREDIT;
    procedure SetGroups(const Value: TGSListGroups);
    procedure SetTiles(const Value: TGSListTiles);
    procedure SetShowColumnAllwais(const Value: Boolean);
    procedure SetTileImages(const Value: TCustomImageList);
    procedure SetColumnAutosort(const Value: TGSAutosortParams);
    procedure SetDoubleBuffered(const Value: Boolean);
    procedure SetHeaderOverflow(const Value: Boolean);
  protected
    procedure ActionChange(Sender: TObject; CheckDefaults: Boolean); override;
    function CanChange(Item: TGSListItem; Change: Integer): Boolean; dynamic;
    function CanEdit(Item: TGSListItem): Boolean; dynamic;
    procedure Change(Item: TGSListItem; Change: Integer); dynamic;
    procedure ChangeScale(M, D: Integer); override;
    procedure ColClick(Column: TGSListColumn); dynamic;
    procedure ColRightClick(Column: TGSListColumn; Point: TPoint); dynamic;
    function ColumnsShowing: Boolean;
    function CreateListItem: TGSListItem; virtual;
    function CreateListItems: TGSListItems; virtual;
    function CreateColumns: TGSListColumns; virtual;
    function CreateGroups: TGSListGroups; virtual;
    function CreateTyles: TGSListTiles; virtual;
    procedure CreateParams(var Params: TCreateParams); override;
    procedure CreateWnd; override;
    function CustomDraw(const ARect: TRect; Stage: TCustomDrawStage): Boolean; virtual;
    function CustomDrawItem(Item: TGSListItem; State: TCustomDrawState;
      Stage: TCustomDrawStage): Boolean; virtual;
    function CustomDrawSubItem(Item: TGSListItem; SubItem: Integer;
      State: TCustomDrawState; Stage: TCustomDrawStage): Boolean; virtual;
    procedure DblClick; override;
    procedure Delete(Item: TGSListItem); dynamic;
    procedure DestroyWnd; override;
    function DoContextPopup(const Context: TContextPopupStack;
      const MousePos: TPoint): Boolean; reintroduce;
    procedure DoEndDrag(Target: TObject; X, Y: Integer); override;
    procedure DoStartDrag(var DragObject: TDragObject); override;
    procedure DoInfoTip(Item: TGSListItem; var InfoTip: string); virtual;
    procedure DoColumnDropDown(ColumnIndex: Integer); virtual;
    procedure DrawItem(Item: TGSListItem; Rect: TRect; State: TOwnerDrawState); virtual;
    procedure Edit(const Item: TLVItem); dynamic;
    procedure MouseUp(Button: TMouseButton; Shift: TShiftState; X, Y: Integer); override;
    function OwnerDataFetch(Item: TGSListItem; Request: TItemRequest): Boolean; virtual;
    function OwnerDataFind(Find: TItemFind; const FindString: string;
      const FindPosition: TPoint; FindData: Pointer; StartIndex: Integer;
      Direction: TSearchDirection; Wrap: Boolean): Integer; virtual;
    function OwnerDataHint(StartIndex, EndIndex: Integer): Boolean; virtual;
    function OwnerDataStateChange(StartIndex, EndIndex: Integer; OldState,
      NewState: TItemStates): Boolean; virtual;
    function GetActionLinkClass: TControlActionLinkClass; override;
    function GetDragImages: TDragImageList; override;
    function GetItemIndex(Value: TGSListItem): Integer; reintroduce; overload;
    function GetItemIndex: Integer; reintroduce; overload; override;
    function GetSelCount: Integer; override;
    procedure InsertItem(Item: TGSListItem); dynamic;
    function IsCustomDrawn(Target: TCustomDrawTarget; Stage: TCustomDrawStage): Boolean; virtual;
    procedure Notification(AComponent: TComponent; Operation: TOperation); override;
    procedure SetItemIndex(const Value: Integer); override;
    procedure SetMultiSelect(Value: Boolean); override;
    procedure SetViewStyle(Value: TGSViewStyle); virtual;
    procedure UpdateColumn(AnIndex: Integer);
    procedure UpdateColumns;
    procedure UpdateGroupData(AnIndex: Integer);
    procedure UpdateGroup(AnIndex: Integer);
    procedure UpdateGroups;
    procedure UpdateAllItems;
    procedure WndProc(var Message: TMessage); override;
    property BorderStyle: TBorderStyle read FBorderStyle write SetBorderStyle default bsSingle;
    property Columns: TGSListColumns read FListColumns write SetListColumns;
    property ColumnClick: Boolean read FColumnClick write SetColumnClick default True;
    property ReadOnly: Boolean read FReadOnly write SetReadOnly;
    property HideSelection: Boolean read FHideSelection write SetHideSelection default True;
    property IconOptions: TIconOptions read FIconOptions write SetIconOptions;
    property Items: TGSListItems read FListItems write SetItems stored AreItemsStored;
    // Rouse_ 05.10.2008
    //   - 
    property Groups: TGSListGroups read FGroups write SetGroups;
    property Tiles: TGSListTiles read FTiles write SetTiles;
    property AllocBy: Integer read FAllocBy write SetAllocBy default 0;
    property HoverTime: Integer read GetHoverTime write SetHoverTime default -1;
    property LargeImages: TCustomImageList read FLargeImages write SetLargeImages;
    property TileImages: TCustomImageList read FTileImages write SetTileImages;
    property MultiSelect: Boolean read FMultiSelect write SetMultiSelect default False;
    property OwnerData: Boolean read FOwnerData write SetOwnerData default False;
    property OwnerDraw: Boolean read FOwnerDraw write SetOwnerDraw default False;
    property OnAdvancedCustomDraw: TLVAdvancedCustomDrawEvent read FOnAdvancedCustomDraw write FOnAdvancedCustomDraw;
    property OnAdvancedCustomDrawItem: TLVAdvancedCustomDrawItemEvent read FOnAdvancedCustomDrawItem write FOnAdvancedCustomDrawItem;
    property OnAdvancedCustomDrawSubItem: TLVAdvancedCustomDrawSubItemEvent read FOnAdvancedCustomDrawSubItem write FOnAdvancedCustomDrawSubItem;
    property OnChange: TLVChangeEvent read FOnChange write FOnChange;
    property OnChanging: TLVChangingEvent read FOnChanging write FOnChanging;
    property OnColumnClick: TLVColumnClickEvent read FOnColumnClick
      write FOnColumnClick;
    property OnColumnDragged: TNotifyEvent read FOnColumnDragged write FOnColumnDragged;
    property OnColumnRightClick: TLVColumnRClickEvent read FOnColumnRightClick
      write FOnColumnRightClick;
    property OnCompare: TLVCompareEvent read FOnCompare write FOnCompare;
    property OnCustomDraw: TLVCustomDrawEvent read FOnCustomDraw write FOnCustomDraw;
    property OnCustomDrawItem: TLVCustomDrawItemEvent read FOnCustomDrawItem write FOnCustomDrawItem;
    property OnCustomDrawSubItem: TLVCustomDrawSubItemEvent read FOnCustomDrawSubItem write FOnCustomDrawSubItem;
    property OnData: TLVOwnerDataEvent read FOnData write FOnData;
    property OnDataFind: TLVOwnerDataFindEvent read FOnDataFind write FOnDataFind;
    property OnDataHint: TLVOwnerDataHintEvent read FOnDataHint write FOnDataHint;
    property OnDataStateChange: TLVOwnerDataStateChangeEvent read FOnDataStateChange write FOnDataStateChange;
    property OnDeletion: TLVDeletedEvent read FOnDeletion write FOnDeletion;
    property OnDrawItem: TLVDrawItemEvent read FOnDrawItem write FOnDrawItem;
    property OnEdited: TLVEditedEvent read FOnEdited write FOnEdited;
    property OnEditing: TLVEditingEvent read FOnEditing write FOnEditing;
    property OnInfoTip: TLVInfoTipEvent read FOnInfoTip write FOnInfoTip;
    property OnInsert: TLVDeletedEvent read FOnInsert write FOnInsert;
    property OnGetImageIndex: TLVNotifyEvent read FOnGetImageIndex write FOnGetImageIndex;
    property OnGetSubItemImage: TLVSubItemImageEvent read FOnGetSubItemImage write FOnGetSubItemImage;
    property OnSelectItem: TLVSelectItemEvent read FOnSelectItem write FOnSelectItem;
    property ShowColumnHeaders: Boolean read FShowColumnHeaders write
      SetColumnHeaders default True;
    property ShowWorkAreas: Boolean read FShowWorkAreas write SetShowWorkAreas default False;
    property SmallImages: TCustomImageList read FSmallImages write SetSmallImages;
    property SortType: TSortType read FSortType write SetSortType default stNone;
    property StateImages: TCustomImageList read FStateImages write SetStateImages;
    property OnCreateItemClass: TLVCreateItemClassEvent read FOnCreateItemClass write FOnCreateItemClass;
    property ColumnAutosort: TGSAutosortParams read FColumnAutosort write SetColumnAutosort;
    property ShowColumnAllwais: Boolean read FShowColumnAllwais write SetShowColumnAllwais default False;
    property OnBeginTrack: TNotifyEvent read FBeginTrack write FBeginTrack;
    property OnTrack: TGSListViewTracEvent read FTrack write FTrack;
    property OnEndTrack: TNotifyEvent read FEndTrack write FEndTrack;
    property OnSelectedPopup: TContextPopupEvent
      read FOnSelectedPopup write FOnSelectedPopup;
    property OnEditPopup: TContextPopupEvent read FOnEditPopup write FOnEditPopup;
    property OnColumnDropDown: TLVColumnRClickEvent read FColumnDropDown
      write FColumnDropDown;
    // Rouse_ 19.04.2010
    //     
    property OnTaskClick: TGSListViewTaskClick read FTaskClick write FTaskClick;
    property CustomCoumnTrack: Boolean read FCustomTrack write FCustomTrack default False;
    property HeaderOverflow: Boolean read FHeaderOverflow write SetHeaderOverflow default False;
    procedure CheckHeaderOverflow;
    procedure Resize; override;
    procedure WMNCCalcSize(var Message: TMessage); message WM_NCCALCSIZE;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    function GetCount: Integer; override;
    function UpdateAction(Action: TBasicAction): Boolean; override;
    function ExecuteAction(Action: TBasicAction): Boolean; override;
    procedure AddItem(Item: String; AObject: TObject); override;
    function AlphaSort: Boolean;
    procedure Arrange(Code: TListArrangement);
    procedure AutosizeColumns;
    procedure Clear; override;
    procedure ClearSelection; override;
    procedure CopySelection(Destination: TCustomListControl); override;
    procedure DeleteSelected; override;
    function FindCaption(StartIndex: Integer; Value: string;
      Partial, Inclusive, Wrap: Boolean): TGSListItem;
    function FindData(StartIndex: Integer; Value: Pointer;
      Inclusive, Wrap: Boolean): TGSListItem;
    function GetHitTestInfoAt(X, Y: Integer): TGSHitTests;
    function GetItemAt(X, Y: Integer): TGSListItem;
    function GetGroupAt(X, Y: Integer): TGSListGroup;
    function GetNearestItem(Point: TPoint;
      Direction: TSearchDirection): TGSListItem;
    function GetNextItem(StartItem: TGSListItem;
      Direction: TSearchDirection; States: TItemStates): TGSListItem;
    function GetSearchString: string;
    function IsEditing: Boolean;
    procedure SelectAll; override;
    procedure Scroll(DX, DY: Integer);
    function CustomSort(SortProc: TLVCompare; lParam: Longint): Boolean;
    function StringWidth(S: string): Integer;
    procedure UpdateItems(FirstIndex, LastIndex: Integer);    
//    procedure MoveSortedItemsToGroups;
    property Canvas: TCanvas read FCanvas;
    property Checkboxes: Boolean read FCheckboxes write SetCheckboxes default False;
    property Column[Index: Integer]: TGSListColumn read GetColumnFromIndex;
    property DropTarget: TGSListItem read GetDropTarget write SetDropTarget;
    property DoubleBuffered: Boolean read FDoubleBuffered write SetDoubleBuffered;
    property FlatScrollBars: Boolean read FFlatScrollBars write SetFlatScrollBars default False;
    property FullDrag: Boolean read FFullDrag write SetFullDrag default False;
    property GridLines: Boolean read FGridLines write SetGridLines default False;
    property HotTrack: Boolean read FHotTrack write SetHotTrack default False;
    property HotTrackStyles: TListHotTrackStyles read FHotTrackStyles write SetHotTrackStyles default [];
    property ItemFocused: TGSListItem read GetFocused write SetFocused;
    property RowSelect: Boolean read FRowSelect write SetRowSelect default False;
    property SelCount: Integer read GetSelCount;
    property Selected: TGSListItem read GetSelected write SetSelected;
    property TopItem: TGSListItem read GetTopItem;
    property TrackedColumn: Integer read FTrackedColumn; 
    property ViewOrigin: TPoint read GetViewOrigin;
    property ViewStyle: TGSViewStyle read FViewStyle write SetViewStyle default vsIcon;
    property VisibleRowCount: Integer read GetVisibleRowCount;
    property BoundingRect: TRect read GetBoundingRect;
    property WorkAreas: TWorkAreas read GSorkAreas;
  end;

{ TGSListView }

  TGSListView = class(TGSCustomListView)
  published
    property Action;
    property Align;
    property AllocBy;
    property Anchors;
    property BevelEdges;
    property BevelInner;
    property BevelOuter;
    property BevelKind default bkNone;
    property BevelWidth;
    property BiDiMode;
    property BorderStyle;
    property BorderWidth;
    property Checkboxes;
    property Color;
    property ColumnAutoSort;    
    property Columns;
    property ColumnClick;
    property Constraints;
    property Ctl3D;
    property CustomCoumnTrack;
    property DragCursor;
    property DragKind;
    property DragMode;
    property Enabled;
    property Font;
    property FlatScrollBars;
    property FullDrag;
    property GridLines;
    property Groups;
    property HeaderOverflow;
    property HideSelection;
    property HotTrack;
    property HotTrackStyles;
    property HoverTime;
    property IconOptions;
    property Items;
    property LargeImages;
    property MultiSelect;
    property OwnerData;
    property OwnerDraw;
    property ReadOnly default False;
    property RowSelect;
    property ParentBiDiMode;
    property ParentColor default False;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowColumnAllwais;
    property ShowColumnHeaders;
    property ShowWorkAreas;
    property ShowHint;
    property SmallImages;
    //property SortType;
    property StateImages;
    property TabOrder;
    property TabStop default True;
    property TileImages;
    property Tiles;
    property ViewStyle;
    property Visible;
    property OnAdvancedCustomDraw;
    property OnAdvancedCustomDrawItem;
    property OnAdvancedCustomDrawSubItem;
    property OnBeginTrack;
    property OnChange;
    property OnChanging;
    property OnClick;
    property OnColumnClick;
    property OnColumnDragged;
    property OnColumnDropDown;
    property OnColumnRightClick;
    property OnCompare;
    property OnContextPopup;
    property OnCustomDraw;
    property OnCustomDrawItem;
    property OnCustomDrawSubItem;
    property OnData;
    property OnDataFind;
    property OnDataHint;
    property OnDataStateChange;
    property OnDblClick;
    property OnDeletion;
    property OnDrawItem;
    property OnEdited;
    property OnEditing;
    property OnEditPopup;
    property OnEndDock;
    property OnEndDrag;
    property OnEndTrack;
    property OnEnter;
    property OnExit;
    property OnGetImageIndex;
    property OnGetSubItemImage;
    property OnDragDrop;
    property OnDragOver;
    property OnInfoTip;
    property OnInsert;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;
    property OnMouseActivate;
    property OnMouseDown;
    property OnMouseEnter;
    property OnMouseLeave;
    property OnMouseMove;
    property OnMouseUp;
    property OnResize;
    property OnSelectedPopup;
    property OnSelectItem;   
    property OnStartDock;
    property OnStartDrag;
    property OnTaskClick;
    property OnTrack;
  end;

{ TGSListViewActionLink }

  TGSListViewActionLink = class(TListActionLink)
  protected
    procedure AddItem(AnItem: TListControlItem); override;
    procedure AddItem(ACaption: String; AImageIndex: Integer;
      DataPtr: Pointer); override;
    procedure SetImages(Value: TCustomImageList); override;
  end;

function InitCommonControl(CC: Integer): Boolean;

implementation

uses Printers, Consts, RTLConsts, ComStrs, ActnList, StdActns, ExtActns, Types,
  ActiveX, Themes, UxTheme, DwmApi;

function InitCommonControl(CC: Integer): Boolean;
var
  ICC: TInitCommonControlsEx;
begin
  ICC.dwSize := SizeOf(TInitCommonControlsEx);
  ICC.dwICC := CC;
  Result := InitCommonControlsEx(ICC);
  if not Result then InitCommonControls;
end;

{$REGION ' TGSAutosortParams '}

{ TGSAutosortParams }

procedure TGSAutosortParams.Assign(Source: TPersistent);
begin
  if Source <> nil then
    if Source is TGSAutosortParams then
    begin
      //UseGroup := TGSAutosortParams(Source).UseGroup;
      Enabled := TGSAutosortParams(Source).Enabled;
      SortStyle := TGSAutosortParams(Source).SortStyle;
      UseColumnDataType := TGSAutosortParams(Source).UseColumnDataType;
    end;
end;

constructor TGSAutosortParams.Create(AOwner: TGSCustomListView);
begin
  FOwner := AOwner;
  FEnabled := False;
  FSortStyle := asUpDown;
  //FUseGroup := True;
  FUseDataType := False;
end;

function TGSAutosortParams.GetOwner: TPersistent;
begin
  Result := FOwner;
end;

{$ENDREGION}

{$REGION ' TSizeWrapper '}

{ TSizeWrapper }

procedure TSizeWrapper.AssignTo(Dest: TPersistent);
begin
  if Dest is TSizeWrapper then
    with TSizeWrapper(Dest) do
    begin
      FSize.cx := Self.X;
      FSize.cy := Self.Y;
      Change;
    end
  else
    inherited;
end;

procedure TSizeWrapper.Change;
begin
  if Assigned(FOnChange) then
    FOnChange(Self);
end;

function TSizeWrapper.GetSize: TSize;
begin
  Result := FSize;
end;

function TSizeWrapper.GetValue(const Index: Integer): Integer;
begin
  case Index of
    0: Result := FSize.cx;
    1: Result := FSize.cy;
  else
    Result := 0;
  end;
end;

procedure TSizeWrapper.SetValue(const Index, Value: Integer);
begin
  case Index of
    0:
      if FSize.cx <> Value then
        FSize.cx := Value
      else
        Exit;
    1:
      if FSize.cy <> Value then
        FSize.cy := Value
      else
        Exit;
  end;
  Change;
end;

{$ENDREGION}

{$REGION ' TSizeWrapper '}

{ TMarginsWrapper }

class procedure TMarginsWrapper.InitDefaults(Margins: Controls.TMargins);
begin
  { Zero initialization is sufficient here }
end;

{$ENDREGION}

{$REGION ' TGSListTiles '}

{ TGSListTiles }

procedure TGSListTiles.Assign(Source: TPersistent);
var
  I: Integer;
begin
  if Source is TGSListTiles then
  begin
    BeginUpdate;
    try
      FLines := TGSListTiles(Source).LinesCount;
      SetLength(FColumns, FLines);
      FSizeFlag := TGSListTiles(Source).SizeFlag;
      FTileSize := TGSListTiles(Source).TileSize;
      FLabelMargin := TGSListTiles(Source).LabelMargin;
      for I := 0 to FLines - 1 do
        FColumns[I] := TGSListTiles(Source).Column[I];
    finally
      EndUpdate;
    end;
  end;
  inherited Assign(Source);
end;

procedure TGSListTiles.BeginUpdate;
begin
  Inc(FupdateCount)
end;

constructor TGSListTiles.Create(AOwner: TGSCustomListView);
begin
  FOwner := AOwner;
  FUpdateCount := 0;
  FLabelMargin := TMarginsWrapper.Create(nil);
  FLabelMargin.OnChange := OnLabelMarginChanged;
  FTileSize := TSizeWrapper.Create;
  FTileSize.OnChange := OnTileSizeChanged;
end;

procedure TGSListTiles.DefineProperties(Filer: TFiler);
begin
  inherited DefineProperties(Filer);
  Filer.DefineProperty('Column', ReadData, WriteData,
    LinesCount > 0);
end;

destructor TGSListTiles.Destroy;
begin
  FTileSize.Free;
  FLabelMargin.Free;
  inherited;
end;

procedure TGSListTiles.DoChanged;
const
  Flags: array [TGSTileSizeFlag] of DWORD = (LVTVIF_AUTOSIZE,
    LVTVIF_FIXEDWIDTH, LVTVIF_FIXEDHEIGHT, LVTVIF_FIXEDSIZE, LVTVIF_EXTENDED);
var
  LvTileViewInfo: TLVTILEVIEWINFO;
  LabelMarginRect: TRect;
begin
  // Rouse_ 05.10.2009
  //    ,     
  if FUpdateCount > 0 then Exit;
  FillChar(LvTileViewInfo, SizeOf(TLVTILEVIEWINFO), 0);
  LabelMarginRect.Left := LabelMargin.Left;
  LabelMarginRect.Top := LabelMargin.Top;
  LabelMarginRect.Right := LabelMargin.Right;
  LabelMarginRect.Bottom := LabelMargin.Bottom;
  with LvTileViewInfo do
  begin
    cbSize := SizeOf(TLVTILEVIEWINFO);
    dwMask := LVTVIM_COLUMNS or LVTVIM_TILESIZE or LVTVIM_LABELMARGIN;
    sizeTile := TileSize.GetSize;
    cLines := LinesCount;
    dwFlags := Flags[SizeFlag];
    rcLabelMargin := LabelMarginRect;
  end;
  ListView_SetTileViewInfo(Handle, LvTileViewInfo);
  if FOwner.Groups.Enabled then
    UpdateItems
  else
    if not (csLoading in FOwner.ComponentState) then
      SendMessage(FOwner.Handle, CM_RECREATEWND, 0, 0);
end;

procedure TGSListTiles.EndUpdate;
begin
  if FUpdateCount > 0 then
    Dec(FUpdateCount);
  if FUpdateCount = 0 then
    DoChanged;
end;

procedure TGSListTiles.FillTileInfoColumn(var Value: TUINTDinArray);
begin
  SetLength(Value, LinesCount);
  Move(FColumns[0], Value[0], LinesCount * SizeOf(UINT));
end;

function TGSListTiles.GetColumn(Index: Integer): UINT;
begin
  Result := FColumns[Index];
end;

function TGSListTiles.Handle: THandle;
begin
  Result := FOwner.Handle;
end;

procedure TGSListTiles.OnLabelMarginChanged(Sender: TObject);
begin
  DoChanged;
end;

procedure TGSListTiles.OnTileSizeChanged(Sender: TObject);
begin
  DoChanged;
end;

procedure TGSListTiles.ReadData(Reader: TReader);
var
  I: Integer;
begin
  for I := 0 to LinesCount - 1 do
    Reader.Read(FColumns[I], 4);
  DoChanged;
end;

procedure TGSListTiles.SetColumn(Index: Integer; const Value: UINT);
begin
  // Rouse_ 05.10.2009
  //        
  FOwner.HandleNeeded;
  FColumns[Index] := Value;
  DoChanged;
end;

procedure TGSListTiles.SetLabelMargin(const Value: TMarginsWrapper);
begin
  FLabelMargin.Assign(Value);
end;

procedure TGSListTiles.SetLines(const Value: Integer);
begin
  // Rouse_ 05.10.2009
  //        
  FOwner.HandleNeeded;
  FLines := Value;
  SetLength(FColumns, Value);
  DoChanged;
end;

procedure TGSListTiles.SetSizeFlag(const Value: TGSTileSizeFlag);
begin
  FSizeFlag := Value;
  DoChanged;
end;

procedure TGSListTiles.SetTileSize(const Value: TSizeWrapper);
begin
  FTileSize.Assign(Value);
end;

procedure TGSListTiles.UpdateItems;
var
  I: Integer;
begin
  if FUpdateCount <> 0 then Exit;
  FOwner.Items.BeginUpdate;
  try
    for I := 0 to FOwner.Items.Count - 1 do
      FOwner.Items[I].UpdateTile;
  finally
    FOwner.Items.EndUpdate;
  end;
end;

procedure TGSListTiles.WriteData(Writer: TWriter);
var
  I: Integer;
begin
  for I := 0 to LinesCount - 1 do
    Writer.Write(FColumns[I], 4);
end;

{$ENDREGION}

{$REGION ' TConversion '}

{ TConversion }

function TConversion.ConvertReadStream(Stream: TStream; Buffer: PChar; BufSize: Integer): Integer;
begin
  Result := Stream.Read(Buffer^, BufSize);
end;

function TConversion.ConvertWriteStream(Stream: TStream; Buffer: PChar; BufSize: Integer): Integer;
begin
  Result := Stream.Write(Buffer^, BufSize);
end;

{$ENDREGION}

{$REGION ' TGSListGroup '}

{ TGSListGroup }

procedure TGSListGroup.Assign(Source: TPersistent);
var
  Group: TGSListGroup;
begin
  if Source is TGSListGroup then
  begin
    Group := TGSListGroup(Source);

    Header := Group.Header;
    Footer := Group.Footer;
    State := Group.State;
    HeaderAlign := Group.HeaderAlign;
    FooterAlign := Group.FooterAlign;
    Subtitle := Group.Subtitle;
    Task := Group.Task;
    TopDescription := Group.TopDescription;
    BottomDescription := Group.BottomDescription;
    TitleImage := Group.TitleImage;
    ExtendedImage := Group.ExtendedImage;
    SubsetTitle := Group.SubsetTitle;
  end
  else
    inherited Assign(Source);
end;

constructor TGSListGroup.Create(Collection: TCollection);
var
  Group: TLVGroup;
begin
  FGroupID := TGSListGroups(Collection).NextGroupID;

  inherited Create(Collection);

  FState := [lgsNormal, lgsCollapsible];
  FHeaderAlign := taLeftJustify;
  FFooterAlign := taLeftJustify;

  FTitleImage := -1;
  FExtendedImage := -1;

  ZeroMemory(@Group, SizeOf(TLVGroup));
  with Group do
  begin
    cbSize := SizeOf(Group);
    mask := LVGF_STATE or LVGF_GROUPID;
    iGroupID := FGroupID;
    state := LVGS_NORMAL;
  end;

  if TGSListGroups(Collection).Owner.HandleAllocated then
    ListView_InsertGroup(TGSListGroups(Collection).Owner.Handle, Index, Group);
end;

destructor TGSListGroup.Destroy;
var
  Groups: TGSListGroups;
  Items: TGSListItems;
  I: Integer;
begin
  Groups := TGSListGroups(Collection);
  if Groups.Owner.HandleAllocated then
    ListView_RemoveGroup(Groups.Owner.Handle, GroupID);
  Items := Groups.Owner.Items;
  for I := 0 to Items.Count - 1 do
    if Items[I].GroupID = GroupID then
      Items[I].GroupID := -1;
  inherited Destroy;
  if not (csDestroying in Groups.Owner.ComponentState) then
    Groups.UpdateGroups;
end;

function TGSListGroup.GetDisplayName: string;
begin
  Result := Header;
  if Result = '' then
    Result := inherited GetDisplayName;
end;

function TGSListGroup.GetState: TGSListGroupStates;
var
  State: Cardinal;
begin
  Result := FState;

  if TGSListGroups(Collection).Owner.HandleAllocated then
  begin
    Result := FState;

    State := ListView_GetGroupState(
      TGSListGroups(Collection).Owner.Handle, GroupID, $FFFFFFFF);
    Result := Result - [lgsHidden, lgsCollapsed, lgsFocused,
      lgsSelected, lgsSubseted, lgsSubSetLinkFocused];
    if State and LVGS_HIDDEN <> 0 then
      Include(Result, lgsHidden);
    if State and LVGS_COLLAPSED <> 0 then
      Include(Result, lgsCollapsed);
    if State and LVGS_FOCUSED <> 0 then
      Include(Result, lgsFocused);
    if State and LVGS_SELECTED <> 0 then
      Include(Result, lgsSelected);
    if State and LVGS_SUBSETED <> 0 then
      Include(Result, lgsSubseted);
    if State and LVGS_SUBSETLINKFOCUSED <> 0 then
      Include(Result, lgsSubSetLinkFocused);     
    FState := Result;
  end;
end;

function TGSListGroup.GetString(const Index: TGSListGroupStringValues): String;
begin
  case Byte(Index) of
    0: Result := FHeader;
    1: Result := FFooter;
    2: Result := FSubtitle;
    3: Result := FTask;
    4: Result := FTopDescription;
    5: Result := FBottomDescription;
    6: Result := FSubsetTitle;
  end;
end;

procedure TGSListGroup.SetExtendedImage(Value: TImageIndex);
begin
  if FExtendedImage <> Value then
  begin
    FExtendedImage := Value;
    Changed(False);
    //UpdateGroups;
  end;
end;

procedure TGSListGroup.SetFooterAlign(Value: TAlignment);
begin
  if FFooterAlign <> Value then
  begin
    FFooterAlign := Value;
    //UpdateGroups;
  end;
end;

procedure TGSListGroup.SetGroupID(Value: Integer);
var
  I: Integer;
  GroupItems: array of Integer;
begin
  SetLength(GroupItems, 0);

  if Value <> FGroupID then
  begin
    for I := 0 to TGSListGroups(Collection).Count - 1 do
    begin
      if TGSListGroups(Collection)[I].GroupID = Value then
        Exit;
    end;

    for I := 0 to TGSListGroups(Collection).Owner.Items.Count - 1 do
    begin
      if TGSListGroups(Collection).Owner.Items[I].GroupID = FGroupID then
      begin
        SetLength(GroupItems, Length(GroupItems) + 1);
        GroupItems[Length(GroupItems) - 1] := I;
      end;
    end;

    if not (csLoading in TGSListGroups(Collection).Owner.ComponentState) then
      ListView_RemoveGroup(TGSListGroups(Collection).Owner.Handle, FGroupID);
    FGroupID := Value;
    UpdateGroups;

    for I := 0 to Length(GroupItems) - 1 do
      TGSListGroups(Collection).Owner.Items[GroupItems[I]].GroupID := FGroupID;
  end;
end;

procedure TGSListGroup.SetHeaderAlign(Value: TAlignment);
begin
  if FHeaderAlign <> Value then
  begin
    FHeaderAlign := Value;
    Changed(False);
    //UpdateGroups;
  end;
end;

procedure TGSListGroup.SetState(Value: TGSListGroupStates);
begin
  if FState <> Value then
  begin
    FState := Value;
    Changed(False);
    //UpdateGroups;
  end;
end;

procedure TGSListGroup.SetString(const Index: TGSListGroupStringValues;
  const Value: String);
begin
  if GetString(Index) <> Value then
  begin
    case Byte(Index) of
      0: FHeader := Value;
      1: FFooter := Value;
      2: FSubtitle := Value;
      3: FTask := Value;
      4: FTopDescription := Value;
      5: FBottomDescription := Value;
      6: FSubsetTitle := Value;
    end;
//    UpdateGroups;
    Changed(False);
  end;
end;

procedure TGSListGroup.SetTitleImage(Value: TImageIndex);
begin
  if FTitleImage <> Value then
  begin
    FTitleImage := Value;
    Changed(False);
    //UpdateGroups;
  end;
end;

procedure TGSListGroup.UpdateGroups;
begin
  if not (csLoading in TGSListGroups(Collection).Owner.ComponentState) then
    TGSListGroups(Collection).Owner.UpdateGroups;
end;

{$ENDREGION}

{$REGION ' TGSListGroups '}

{ TGSListGroups }

function TGSListGroups.Add: TGSListGroup;
begin
  Result := TGSListGroup(inherited Add);
  Changed;
//  UpdateGroups;
end;

constructor TGSListGroups.Create(AOwner: TGSCustomListView);
begin
  inherited Create(AOwner, GetItemClass);
  FEnable := False;
  FInverted := False;
end;

procedure TGSListGroups.DoGroupClick(Value: TGSListGroup);
begin
  if Assigned(FGroupClick) then
    FGroupClick(Owner, Value);
end;

procedure TGSListGroups.DoGroupDblClick(Value: TGSListGroup);
begin
  if Assigned(FGroupDblClick) then
    FGroupDblClick(Owner, Value);
end;

function TGSListGroups.GetGroupIndexByName(const Value: String;
  const StringValueType: TGSListGroupStringValues): Integer;
var
  I: Integer;
  Data: String;
begin
  Result := -1;
  for I := 0 to Count - 1 do
  begin
    case StringValueType of
      svHeader: Data := Items[I].Header;
      svFooter: Data := Items[I].Footer;
      svSubtitle: Data := Items[I].Subtitle;
      svTask: Data := Items[I].Task;
      svTopDescription: Data := Items[I].TopDescription;
      svBottomDescription: Data := Items[I].BottomDescription;
      svSubsetTitle: Data := Items[I].SubsetTitle;
    end;
    if Data = Value then
    begin
      Result := I;
      Break;
    end;
  end;
end;

function TGSListGroups.GetHandle: HWND;
begin
  Result := Owner.Handle;
end;

function TGSListGroups.GetItem(Index: Integer): TGSListGroup;
begin
  Result := TGSListGroup(inherited GetItem(Index));
end;

function TGSListGroups.GetItemClass: TGSListGroupClass;
begin
  Result := TGSListGroup;
end;

function TGSListGroups.GetNextGroupID: Integer;
var
  I: Integer;
begin
  Result := 0;

  if Count = 0 then
    Exit;

  while True do
  begin
    for I := 0 to Count - 1 do
    begin
      if Items[I].GroupID = Result then
      begin
        Inc(Result);
        Break;
      end
      else if I = Count - 1 then
      begin
        Exit;
      end;
    end;
  end;
end;

procedure TGSListGroups.Notify(Item: TCollectionItem;
  Action: TCollectionNotification);
begin
  //     
  //      
  if Owner.HandleAllocated then
    case Action of
//      cnAdded: Enabled := True;
      cnDeleting, cnExtracting:
        if Count = 0 then
          Enabled := False;
//        Enabled := Count >= 1;
    end;
  inherited;
end;

function TGSListGroups.Owner: TGSCustomListView;
begin
  Result := TGSCustomListView(GetOwner);
end;

procedure TGSListGroups.SetEnable(const Value: Boolean);
begin
  if Enabled <> Value then
  begin
    FEnable := Value;
    ListView_EnableGroupView(Handle, Value);
    UpdateGroups;
    Owner.UpdateAllItems;
  end;
end;

procedure TGSListGroups.SetInverted(const Value: Boolean);

  function GroupSort(GroupID1, GroupID2: Integer;
    lParam: Integer): Integer; stdcall;
  begin
    if Boolean(lParam) then
      Result := GroupID2 - GroupID1
    else
      Result := GroupID1 - GroupID2;
  end;

begin
  if Inverted <> Value then
  begin
    FInverted := Value;
    ListView_SortGroups(Owner.Handle, @GroupSort, Pointer(Value));
  end;
end;

procedure TGSListGroups.SetItem(Index: Integer; const Value: TGSListGroup);
begin
  inherited SetItem(Index, Value); 
end;

procedure TGSListGroups.Update(Item: TCollectionItem);
begin
  if Item <> nil then
    Owner.UpdateGroup(Item.Index)
  else
    if not FLockUpdateNow then    
      Owner.UpdateGroups;
end;

procedure TGSListGroups.UpdateGroups;
begin
  if Owner.HandleAllocated then
  begin
    BeginUpdate;
    try
      Owner.UpdateGroups;
    finally
      FLockUpdateNow := True;
      try
        EndUpdate;
      finally
        FLockUpdateNow := False;
      end;
    end;
  end;
end;

{$ENDREGION}

{$REGION ' TGSListColumn '}

{ TGSListColumn }

constructor TGSListColumn.Create(Collection: TCollection);
var
  Column: TLVColumn;
begin
  FOrderTag := Collection.Count;
  inherited Create(Collection);
  FWidth := 50;
  FAlignment := taLeftJustify;
  FImageIndex := -1;
  with Column do
  begin
    mask := LVCF_FMT or LVCF_WIDTH;
    fmt := LVCFMT_LEFT;
    cx := FWidth;
    iImage := FImageIndex;
  end;
  if TGSListColumns(Collection).Owner.HandleAllocated then
    ListView_InsertColumn(TGSListColumns(Collection).Owner.Handle, Index, Column);
end;

destructor TGSListColumn.Destroy;
var
  Columns: TGSListColumns;
begin
  Columns := TGSListColumns(Collection);
  if TGSListColumns(Collection).Owner.HandleAllocated then
    ListView_DeleteColumn(TGSListColumns(Collection).Owner.Handle, Index);
  inherited Destroy;
  Columns.UpdateCols;
end;

procedure TGSListColumn.DefineProperties(Filer: TFiler);
begin
  inherited DefineProperties(Filer);
  Filer.DefineProperty('WidthType', ReadData, WriteData,
    WidthType <= ColumnTextWidth);
end;

procedure TGSListColumn.ReadData(Reader: TReader);
begin
  with Reader do
  begin
    ReadListBegin;
    Width := TWidth(ReadInteger);
    ReadListEnd;
  end;
end;

procedure TGSListColumn.WriteData(Writer: TWriter);
begin
  with Writer do
  begin
    WriteListBegin;
    WriteInteger(Ord(WidthType));
    WriteListEnd;
  end;
end;

procedure TGSListColumn.DoChange;

  procedure WriteCols;
  var
    Writer: TWriter;
    LV: TGSCustomListView;
  begin
    LV := TGSListColumns(Collection).Owner;
    if LV.HandleAllocated or
      ([csLoading, csReading] * LV.ComponentState <> []) or
      LV.FReading then Exit;
    if LV.FColStream = nil then
      LV.FColStream := TMemoryStream.Create
    else
      LV.FColStream.Size := 0;
    Writer := TWriter.Create(LV.FColStream, 1024);
    try
      Writer.WriteCollection(Collection);
    finally
      Writer.Free;
      LV.FColStream.Position := 0;
    end;
  end;

var
  I: Integer;
begin
  for I := 0 to Collection.Count - 1 do
    if TGSListColumn(Collection.Items[I]).WidthType <= ColumnTextWidth then Break;
  Changed(I <> Collection.Count);
  WriteCols;
end;

procedure TGSListColumn.SetIndex(Value: Integer);
var
  ColumnOrder: array of Integer;
  I: Integer;
begin
  inherited SetIndex(Value);
  SetLength(ColumnOrder, Collection.Count);
  for I := 0 to Collection.Count - 1 do
    ColumnOrder[I] := TGSListColumn(Collection.Items[I]).FOrderTag;
  ListView_SetColumnOrderArray(TGSListColumns(Collection).Owner.Handle,
    Collection.Count, PInteger(ColumnOrder));
end;

procedure TGSListColumn.SetCaption(const Value: string);
begin
  if FCaption <> Value then
  begin
    FCaption := Value;
    DoChange;
  end;
end;

procedure TGSListColumn.SetCheckBox(const Value: Boolean);
begin
  if FCheckBox <> Value then
  begin
    FCheckBox := Value;
    Changed(False);
  end;
end;

procedure TGSListColumn.SetChecked(const Value: Boolean);
begin
  if FChecked <> Value then
  begin
    FChecked := Value;
    if CheckBox then    
      Changed(False);
  end;
end;

function TGSListColumn.GetWidth: TWidth;
begin
  // Rouse_ 27.10.2009
  //        ,
  //     ListView_GetColumnWidth   
  if TGSListColumns(Collection).UpdateCount > 0 then
  begin
    Result := FWidth;
    Exit;
  end;
  if (FWidth = 0) or ((not AutoSize) and
    TGSListColumns(Collection).Owner.HandleAllocated and
     (TGSListColumns(Collection).Owner.ViewStyle = vsReport) and
     (FWidth <> LVSCW_AUTOSIZE) and
     (TGSListColumns(Collection).Owner.ValidHeaderHandle)) then
    FWidth := ListView_GetColumnWidth(
      TGSListColumns(Collection).Owner.Handle, Index);
  Result := FWidth;
end;

function TGSListColumn.IsWidthStored: Boolean;
begin
  Result := not FAutoSize;
end;

procedure TGSListColumn.SetWidth(Value: TWidth);
begin
  if FWidth <> Value then
  begin
    if ((Value < MinWidth) and (Value >= 0)) then
      Value := MinWidth
    else
      if ((MaxWidth > 0) and (Value > MaxWidth)) then
      Value := MaxWidth;
    FWidth := Value;
    if TGSListColumns(Collection).UpdateCount > 0 then Exit;
    DoChange;
    TGSListColumns(Collection).Owner.Repaint;
  end;
end;

procedure TGSListColumn.SetAlignment(Value: TAlignment);
begin
  if (Alignment <> Value) and (Index >= 0) then
  begin
    FAlignment := Value;
    Changed(False);
    TGSListColumns(Collection).Owner.Repaint;
  end;
end;

procedure TGSListColumn.SetAutoSize(Value: Boolean);
begin
  if FAutoSize <> Value then
  begin
    FAutoSize := Value;
    if TGSListColumns(Collection).Owner <> nil then
      TGSListColumns(Collection).Owner.AdjustSize;
    DoChange;
  end;
end;

procedure TGSListColumn.SetImageIndex(Value: TImageIndex);
begin
  if FImageIndex <> Value then
  begin
    FImageIndex := Value;
    DoChange;
  end;
end;

procedure TGSListColumn.SetMaxWidth(Value: TWidth);
begin
  if FMaxWidth <> Value then
  begin
    FMaxWidth := Value;
    Changed(False);
  end;
end;

procedure TGSListColumn.SetMinWidth(Value: TWidth);
begin
  if FMinWidth <> Value then
  begin
    FMinWidth := Value;
    Changed(False);
  end;
end;

procedure TGSListColumn.SetSplitButton(const Value: Boolean);
begin
  if FSplitButton <> Value then
  begin
    FSplitButton := Value;
    Changed(False);
  end;
end;

procedure TGSListColumn.Assign(Source: TPersistent);
var
  Column: TGSListColumn;
begin
  if Source is TGSListColumn then
  begin
    Column := TGSListColumn(Source);
    Alignment := Column.Alignment;
    AutoSize := Column.AutoSize;
    Caption := Column.Caption;
    ImageIndex := Column.ImageIndex;
    MaxWidth := Column.MaxWidth;
    MinWidth := Column.MinWidth;
    Width := Column.Width;
  end
  else
    inherited Assign(Source);
end;

function TGSListColumn.GetDisplayName: string;
begin
  Result := Caption;
  if Result = '' then
    Result := inherited GetDisplayName;
end;

{$ENDREGION}

{$REGION ' TGSListColumns '}

{ TGSListColumns }

constructor TGSListColumns.Create(AOwner: TGSCustomListView);
begin
  inherited Create(TGSListColumn);
  FOwner := AOwner;
  FHeaderHandle := 0;
  FSortedIndex := -1;
end;

function TGSListColumns.GetHeaderHandle: THandle;
begin                           
  if not IsWindow(FHeaderHandle) then
    FHeaderHandle := ListView_GetHeader(Owner.Handle);
  Result := FHeaderHandle
end;

function TGSListColumns.GetItem(Index: Integer): TGSListColumn;
begin
  Result := TGSListColumn(inherited GetItem(Index));
end;

procedure TGSListColumns.SetColumnSortedMask(
  const PreviosSelected: Integer);
var
  Direction: Integer;
  Item: THDItem;
begin
  if (SortedIndex < 0) or (SortedIndex >= Count) then
    Exit;

  case SortDirection of
    sdUp: Direction := HDF_SORTUP;
    sdDown: Direction := HDF_SORTDOWN;
  else
    Direction := 0;
  end;

  //       :
  if ThemeServices.ThemesEnabled then
  begin
    Item.Mask := HDI_FORMAT;
    //   
    if Header_GetItem(HeaderHandle, PreviosSelected, Item) then
    begin
      if (Item.fmt and HDF_SORTUP) = HDF_SORTUP then
      begin
        Item.fmt := Item.fmt xor HDF_SORTUP;
        Header_SetItem(HeaderHandle, PreviosSelected, Item);
      end;
      if (Item.fmt and HDF_SORTDOWN) = HDF_SORTDOWN then
      begin
        Item.fmt := Item.fmt xor HDF_SORTDOWN;
        Header_SetItem(HeaderHandle, PreviosSelected, Item);
      end;
    end;
    //  
    Item.Mask := HDI_FORMAT;
    Header_GetItem(HeaderHandle, SortedIndex, Item);
    Item.fmt := Item.fmt or Direction;
    Header_SetItem(HeaderHandle, SortedIndex, Item);
  end;
  ListView_SetSelectedColumn(Owner.Handle, SortedIndex);  
end;

procedure TGSListColumns.SetItem(Index: Integer; Value: TGSListColumn);
begin
  inherited SetItem(Index, Value);
end;

procedure TGSListColumns.SetSortDirection(const Value: TGSSortDirection);
begin
  FSortDirection := Value;
  SetColumnSortedMask(SortedIndex);
end;

procedure TGSListColumns.SetSortedIndex(const Value: Integer);
var
  PreviosSortedIndex: Integer;
begin
  PreviosSortedIndex := SortedIndex;
  FSortedIndex := Value;
  SetColumnSortedMask(PreviosSortedIndex);
end;

function TGSListColumns.Add: TGSListColumn;
begin
  Result := TGSListColumn(inherited Add);
  Changed;
//  UpdateCols;
end;

function TGSListColumns.Owner: TGSCustomListView;
begin
  Result := FOwner;
end;

function TGSListColumns.GetOwner: TPersistent;
begin
  Result := FOwner;
end;

procedure TGSListColumns.Update(Item: TCollectionItem);
begin
  if Item <> nil then
    Owner.UpdateColumn(Item.Index)
  else
    Owner.UpdateColumns;
  // Rouse_ 01.11.2008
  //      
  SetColumnSortedMask;

end;

procedure TGSListColumns.UpdateCols;
var
  I: Integer;
  LVColumn: TLVColumn;
begin
  if not Owner.HandleAllocated then Exit;
  BeginUpdate;
  try
    for I := Count - 1 downto 0 do
      ListView_DeleteColumn(Owner.Handle, I);

    for I := 0 to Count - 1 do
    begin
      with LVColumn do
      begin
        mask := LVCF_FMT or LVCF_WIDTH;
        fmt := LVCFMT_LEFT;
        cx := Items[I].FWidth;
      end;
      ListView_InsertColumn(Owner.Handle, I, LVColumn);
      Items[I].FOrderTag := I;
    end;

    Owner.UpdateColumns;
  finally
    EndUpdate;
  end;
end;

{$ENDREGION}

{$REGION ' TWorkArea '}

{ TWorkArea }

constructor TWorkArea.Create(Collection: TCollection);
begin
  inherited Create(Collection);
  FColor := clWindowText;
  FDisplayName := '';
end;

function TWorkArea.GetDisplayName: string;
begin
  Result := FDisplayName;
end;

procedure TWorkArea.SetColor(const Value: TColor);
begin
  FColor := Value;
  Changed(True);
end;

procedure TWorkArea.SetDisplayName(const Value: string);
begin
  FDisplayName := Value;
  Changed(True);
end;

procedure TWorkArea.SetRect(const Value: TRect);
begin
  FRect := Value;
  Changed(True);
end;

{$ENDREGION}

{$REGION ' TWorkAreas '}

{ TWorkAreas }

procedure TWorkAreas.Update(Item: TCollectionItem);
var
  I: Integer;
  Rects: array of TRect;
  ListView: TGSCustomListView;
begin
  ListView := TGSCustomListView(GetOwner);
  SetLength(Rects, Count);
  for I := 0 to Count-1 do
    Rects[I] := Items[I].Rect;
  ListView_SetWorkAreas(ListView.Handle, Count, Pointer(Rects));
  ListView.Invalidate;
end;

procedure TWorkAreas.Changed;
begin
  Update(nil);
end;

function TWorkAreas.Add: TWorkArea;
begin
  Result := TWorkArea(inherited Add);
end;

function TWorkAreas.GetItem(Index: Integer): TWorkArea;
begin
  Result := TWorkArea(inherited GetItem(Index));
end;

procedure TWorkAreas.SetItem(Index: Integer; const Value: TWorkArea);
begin
  inherited SetItem(Index, Value);
  Update(nil);
end;

procedure TWorkAreas.Delete(Index: Integer);
begin
  Items[Index].Free;
  Changed;
end;

function TWorkAreas.Insert(Index: Integer): TWorkArea;
begin
  Result := TWorkArea(inherited Insert(Index));
end;

{$ENDREGION}

{$REGION ' TSubItems '}

{ TSubItems }

type
  TSubItems = class(TStringList)
  private
    FOwner: TGSListItem;
    FImageIndices: TList;
    procedure SetColumnWidth(Index: Integer);
    procedure RefreshItem(Index: Integer);
    function GetImageIndex(Index: Integer): TImageIndex;
    procedure SetImageIndex(Index: Integer; const Value: TImageIndex);
  protected
    function GetHandle: HWND;
    function Add(const S: string): Integer; override;
    function AddObject(const S: string; AObject: TObject): Integer; override;
    procedure Clear; override;
    procedure Delete(Index: Integer); override;
    procedure Put(Index: Integer; const S: string); override;
    procedure SetUpdateState(Updating: Boolean); override;
  public
    constructor Create(AOwner: TGSListItem);
    destructor Destroy; override;
    procedure Insert(Index: Integer; const S: string); override;
    property Handle: HWND read GetHandle;
    property Owner: TGSListItem read FOwner;
    property ImageIndex[Index: Integer]: TImageIndex read GetImageIndex write SetImageIndex;
  end;

constructor TSubItems.Create(AOwner: TGSListItem);
begin
  inherited Create;
  FOwner := AOwner;
  FImageIndices := TList.Create;
end;

destructor TSubItems.Destroy;
begin
  FImageIndices.Free;
  inherited;
end;

function TSubItems.Add(const S: string): Integer;
begin
  Result := inherited Add(S);
  FImageIndices.Add(Pointer(-1));
  RefreshItem(Result + 1);
end;

function TSubItems.AddObject(const S: string; AObject: TObject): Integer;
begin
  Result := inherited AddObject(S, AObject);
  FImageIndices.Add(Pointer(-1));
  RefreshItem(Result + 1);
end;

procedure TSubItems.Clear;
begin
  inherited;
  FImageIndices.Clear;
end;

procedure TSubItems.Delete(Index: Integer);
begin
  inherited;
  FImageIndices.Delete(Index);
  Owner.Update;
end;

function TSubItems.GetHandle: HWND;
begin
  Result := Owner.Owner.Handle;
end;

procedure TSubItems.SetColumnWidth(Index: Integer);
var
  ListView: TGSCustomListView;
begin
  ListView := Owner.ListView;
  if ListView.ColumnsShowing and
    (ListView.Columns.Count > Index) and
    (ListView.Column[Index].WidthType = ColumnTextWidth) then
    ListView.UpdateColumn(Index);
end;

procedure TSubItems.Insert(Index: Integer; const S: string);
var
  i: Integer;
begin
  inherited Insert(Index, S);
  FImageIndices.Insert(Index, Pointer(-1));
  for i := Index + 1 to Count do RefreshItem(i);
end;

procedure TSubItems.Put(Index: Integer; const S: string);
begin
  inherited Put(Index, S);
  RefreshItem(Index + 1);
end;

procedure TSubItems.RefreshItem(Index: Integer);
begin
  ListView_SetItemText(Handle, Owner.Index, Index, LPSTR_TEXTCALLBACK);
  SetColumnWidth(Index);
end;

procedure TSubItems.SetUpdateState(Updating: Boolean);
begin
  Owner.Owner.SetUpdateState(Updating);
end;

function TSubItems.GetImageIndex(Index: Integer): TImageIndex;
begin
  Result := TImageIndex(FImageIndices[Index]);
end;

procedure TSubItems.SetImageIndex(Index: Integer; const Value: TImageIndex);
begin
  FImageIndices[Index] := Pointer(Value);
end;

{$ENDREGION}

{$REGION ' TGSListItem '}

{ TGSListItem }

constructor TGSListItem.Create(AOwner: TGSListItems);
begin
  FOwner := AOwner;
  FSubItems := TSubItems.Create(Self);
  FOverlayIndex := -1;
  FStateIndex := -1;
end;

destructor TGSListItem.Destroy;
begin
  FDeleting := True;
  if Owner.Owner.FLastDropTarget = Self then
    Owner.Owner.FLastDropTarget := nil;
  if ListView.HandleAllocated then
    ListView_DeleteItem(Handle, Index);
  FSubItems.Free;
  inherited Destroy;
end;

function TGSListItem.GetListView: TGSCustomListView;
begin
  if Assigned(Owner) then  
    Result := Owner.Owner
  else
    Result := nil;
end;

procedure TGSListItem.Delete;
begin
  if not FDeleting and (Self <> ListView.FTempItem) then Free;
end;

function TGSListItem.GetHandle: HWND;
begin
  Result := ListView.Handle;
end;

procedure TGSListItem.MakeVisible(PartialOK: Boolean);
begin
  ListView_EnsureVisible(Handle, Index, PartialOK);
end;

function TGSListItem.GetChecked: Boolean;
begin
  with Owner.Owner do
    if not OwnerData and HandleAllocated then
      Result := (ListView_GetCheckState(Handle, Index) <> 0)
    else
      Result := FChecked;
end;

procedure TGSListItem.SetChecked(Value: Boolean);
var
  LV: TGSCustomListView;
begin
  if Value <> Checked then
  begin
    FChecked := Value;
    LV := Owner.Owner;
    if not LV.OwnerData and LV.HandleAllocated then
      ListView_SetCheckState(LV.Handle, Index, Value);
  end;
end;

function TGSListItem.GetLeft: Integer;
begin
  Result := GetPosition.X;
end;

procedure TGSListItem.SetLeft(Value: Integer);
begin
  SetPosition(Point(Value, Top));
end;

function TGSListItem.GetTop: Integer;
begin
  Result := GetPosition.Y;
end;

procedure TGSListItem.SetTop(Value: Integer);
begin
  SetPosition(Point(Left, Value));
end;

procedure TGSListItem.Update;
begin
  ListView_Update(Handle, Index);
end;

procedure TGSListItem.UpdateTile;
var
  LvTileInfo: TLVTILEINFO;
  LVTILEColumns: TUINTDinArray;
begin
  // Rouse_ 02.02.2011
  //  2010-    TLVTILEINFO   piColFmt
  //  SizeOf(TLVTILEINFO)       
  // ,       AV
  ZeroMemory(@LvTileInfo, SizeOf(TLVTILEINFO));
  LvTileInfo.cbSize := SizeOf(TLVTILEINFO);
  Owner.Owner.Tiles.FillTileInfoColumn(LVTILEColumns);
  LvTileInfo.cColumns := Length(LVTILEColumns);
  LvTileInfo.puColumns := @LVTILEColumns[0];
  LvTileInfo.iItem := Index;
  ListView_SetTileInfo(Handle, LvTileInfo);
end;

procedure TGSListItem.SetCaption(const Value: string);
begin
  if Value <> Caption then
  begin
    FCaption := Value;
    if not Owner.Owner.OwnerData then
      ListView_SetItemText(Handle, Index, 0, LPSTR_TEXTCALLBACK);
    if ListView.ColumnsShowing and
      (ListView.Columns.Count > 0) and
      (ListView.Column[0].WidthType <= ColumnTextWidth) then
      ListView.UpdateColumns;
    if ListView.SortType in [stBoth, stText] then ListView.AlphaSort;
  end;
end;

procedure TGSListItem.SetData(Value: Pointer);
begin
  if Value <> Data then
  begin
    FData := Value;
    if ListView.SortType in [stBoth, stData] then
      ListView.AlphaSort;
  end;
end;

procedure TGSListItem.SetGroupID(const Value: Integer);
var
  Item: TLVItem;
begin
  if Value <> FGroupID then
  begin
    ZeroMemory(@Item, SizeOf(Item));
    with Item do
    begin
      mask := LVIF_GROUPID;
      iItem := Self.Index;
      iGroupID := Value;
    end;
    ListView_SetItem(Handle, Item);
    FGroupID := Value;
  end;
end;

function TGSListItem.EditCaption: Boolean;
begin
  ListView.SetFocus;
  Result := ListView_EditLabel(Handle, Index) <> 0;
end;

procedure TGSListItem.CancelEdit;
begin
  ListView_EditLabel(Handle, -1);
end;

function TGSListItem.GetState(Index: Integer): Boolean;
var
  Mask: Integer;
begin
  case Index of
    0: Mask := LVIS_CUT;
    1: Mask := LVIS_DROPHILITED;
    2: Mask := LVIS_FOCUSED;
    3: Mask := LVIS_SELECTED;
    4: Mask := LVIS_ACTIVATING;
  else
    Mask := 0;
  end;
  Result := ListView_GetItemState(Handle, Self.Index, Mask) and Mask <> 0;
end;

procedure TGSListItem.SetState(Index: Integer; State: Boolean);
var
  Mask: Integer;
  Data: Integer;
begin
  case Index of
    0: Mask := LVIS_CUT;
    1: Mask := LVIS_DROPHILITED;
    2: Mask := LVIS_FOCUSED;
    3: Mask := LVIS_SELECTED;
    4: Mask := LVIS_ACTIVATING;
  else
    Mask := 0;
  end;
  if State then Data := Mask
  else Data := 0;
  ListView_SetItemState(Handle, Self.Index, Data, Mask);
end;

procedure TGSListItem.SetImage(Index: Integer; Value: TImageIndex);
var
  Item: TLVItem;
  LChanged: Boolean;
  PImageIndex: PInteger;
begin
  LChanged := False;
  case Index of
    0, 3, 4:
    begin
      case Index of
        0: PImageIndex := @FImageIndex;
        3: PImageIndex := @FLargeIndex;
        4: PImageIndex := @FTileIndex;
      else
        Exit;
      end;
      if Value <> PImageIndex^ then
      begin
        case ListView.ViewStyle of
          vsIcon: LChanged := Index = 3;
          vsSmallIcon..vsReport: LChanged := Index = 0;
          vsTile: LChanged := Index = 4;
        end;
        PImageIndex^ := Value;
        if not Owner.Owner.OwnerData then
        begin
          with Item do
          begin
            mask := LVIF_IMAGE;
            iImage := I_IMAGECALLBACK;
            iItem := Self.Index;
            iSubItem := 0;
          end;
          ListView_SetItem(Handle, Item);
        end;
      end;
    end;
    1:
    if Value <> FOverlayIndex then
    begin
      LChanged := True;
      FOverlayIndex := Value;
      if not Owner.Owner.OwnerData then
        ListView_SetItemState(Handle, Self.Index,
          IndexToOverlayMask(OverlayIndex + 1), LVIS_OVERLAYMASK);
    end;
    2:
    if Value <> FStateIndex then
    begin
      LChanged := True;
      FStateIndex := Value;
      if Owner.Owner.CheckBoxes and (Value = -1) then
        Value := 0;
      if not Owner.Owner.OwnerData then
        ListView_SetItemState(Handle, Self.Index,
          IndexToStateImageMask(Value + 1), LVIS_STATEIMAGEMASK);
    end;
  end;
  if Owner.UpdateCount = 0 then
    if LChanged and not Owner.Owner.OwnerData then
      ListView.UpdateItems(Self.Index, Self.Index);
end;

procedure TGSListItem.SetIndent(Value: Integer);
var
  Item: TLVItem;
begin
  if FIndent <> Value then
  begin
    FIndent := Value;
    if not Owner.Owner.OwnerData then
    begin
      with Item do
      begin
        mask := LVIF_INDENT;
        iIndent := Value;
        iItem := Self.Index;
        iSubItem := 0;
      end;
      ListView_SetItem(Handle, Item);
      ListView.UpdateItems(Self.Index, Self.Index);
    end;
  end;
end;

procedure TGSListItem.Assign(Source: TPersistent);
begin
  if Source is TGSListItem then
    with Source as TGSListItem do
    begin
      Self.Caption := Caption;
      Self.Data := Data;
      Self.ImageIndex := ImageIndex;
      Self.Indent := Indent;
      Self.OverlayIndex := OverlayIndex;
      Self.StateIndex := StateIndex;
      Self.SubItems := SubItems;
      Self.Checked := Checked;
      Self.Tag := Tag;
    end
  else inherited Assign(Source);
end;

function TGSListItem.IsEqual(Item: TGSListItem): Boolean;
begin
  Result := (Caption = Item.Caption) and (Data = Item.Data);
end;

procedure TGSListItem.SetSubItems(Value: TStrings);
begin
  if Value <> nil then
    FSubItems.Assign(Value);
end;

function TGSListItem.GetIndex: Integer;
begin
  if Owner.Owner.OwnerData then
    Result := FIndex else
    Result := Owner.IndexOf(Self);
end;

function TGSListItem.GetPosition: TPoint;
begin
  ListView_GetItemPosition(Handle, Index, Result);
end;

procedure TGSListItem.SetPosition(const Value: TPoint);
var
  LAt: TPoint;
begin
  LAt := Position;
  if (LAt.X <> Value.X) or (LAt.Y <> Value.Y) then
    if ListView.ViewStyle in [vsSmallIcon, vsIcon] then
      ListView_SetItemPosition32(Handle, Index, Value.X, Value.Y);
end;

function TGSListItem.DisplayRect(Code: TDisplayCode): TRect;
const
  Codes: array[TDisplayCode] of Longint = (LVIR_BOUNDS, LVIR_ICON, LVIR_LABEL,
    LVIR_SELECTBOUNDS);
begin
  ListView_GetItemRect(Handle, Index, Result, Codes[Code]);
end;

function TGSListItem.GetSubItemImage(Index: Integer): Integer;
begin
  Result := TSubItems(FSubItems).ImageIndex[Index];
end;

procedure TGSListItem.SetSubItemImage(Index: Integer; const Value: Integer);
var
  item: TLVItem;
begin
  {Storage of sub-item image indices cannot be provided by the control because
   all display-related content requires a callback}
  if TSubItems(FSubItems).ImageIndex[Index] <> Value then
  begin
    TSubItems(FSubItems).ImageIndex[Index] := Value;
    if not Owner.Owner.OwnerData then
    begin
      with item do
      begin
        mask := LVIF_IMAGE;
        iImage := I_IMAGECALLBACK;
        iItem := Self.Index;
        iSubItem := Index+1;
      end;
      ListView_SetItem(Handle, item);
    end;
  end;
end;

function TGSListItem.WorkArea: Integer;
begin
  with Owner.Owner.WorkAreas do
  begin
    Result := Count-1;
    while (Result >= 0) and not PtInRect(Items[Result].Rect, GetPosition) do
      Dec(Result);
  end;
end;

{$ENDREGION}

{$REGION ' TGSListItemsEnumerator '}

{ TGSListItemsEnumerator }

constructor TGSListItemsEnumerator.Create(AListItems: TGSListItems);
begin
  inherited Create;
  FIndex := -1;
  FListItems := AListItems;
end;

function TGSListItemsEnumerator.GetCurrent: TGSListItem;
begin
  Result := FListItems[FIndex];
end;

function TGSListItemsEnumerator.MoveNext: Boolean;
begin
  Result := FIndex < FListItems.Count - 1;
  if Result then
    Inc(FIndex);
end;

{$ENDREGION}

{$REGION ' TGSListItems '}

{ TGSListItems }

type
  PItemHeader = ^TItemHeader;
  TItemHeader = packed record
    Size, Count: Integer;
    Items: record end;
  end;

  PItemInfo = ^TItemInfo;
  TItemInfo = packed record
    ImageIndex: Integer;
    StateIndex: Integer;
    OverlayIndex: Integer;
    SubItemCount: Integer;
    GroupID: Integer;
    Data: Pointer;
    Caption: string[255];
  end;

  TItemDataInfo = packed record
    ImageIndex: Integer;
    StateIndex: Integer;
    OverlayIndex: Integer;
    SubItemCount: Integer;
    GroupID: Integer;
    Data: Pointer;
    CaptionLen: Byte;
    Tag: Integer;
    // WideString Caption of CaptionLen chars follows
  end;
  ShortStr = string[255];
  PShortStr = ^ShortStr;

constructor TGSListItems.Create(AOwner: TGSCustomListView);
begin
  inherited Create;
  FOwner := AOwner;
end;

destructor TGSListItems.Destroy;
begin
  Clear;
  inherited Destroy;
end;

function TGSListItems.Add: TGSListItem;
begin
  Result := AddItem(nil, -1);
end;

function TGSListItems.Insert(Index: Integer): TGSListItem;
begin
  Result := AddItem(nil, Index);
end;

function TGSListItems.AddItem(Item: TGSListItem; Index: Integer): TGSListItem;
begin
  if Item = nil then
    Result := Owner.CreateListItem
  else
    Result := Item;
  if Index < 0 then
    Index := Count;
  ListView_InsertItem(Handle, CreateItem(Index, Result));
  Result.UpdateTile;
end;

function TGSListItems.GetCount: Integer;
begin
  if Owner.HandleAllocated then
    Result := ListView_GetItemCount(Handle)
  else
    Result := 0;
end;

function TGSListItems.GetEnumerator: TGSListItemsEnumerator;
begin
  Result := TGSListItemsEnumerator.Create(Self);
end;

function TGSListItems.GetHandle: HWND;
begin
  Result := Owner.Handle;
end;

function TGSListItems.GetItem(Index: Integer): TGSListItem;
var
  Item: TLVItem;
begin
  Result := nil;
  if Owner.Handle <> 0 then
  begin
    if Owner.OwnerData then
    begin
      FillChar(Item, SizeOf(Item), 0);
      with Item do
      begin
        mask := 0;
        iItem := Index;
        iSubItem := 0;
      end;
      Result := Owner.GetItem(Item);
    end
    else
    begin
      with Item do
      begin
        mask := LVIF_PARAM;
        iItem := Index;
        iSubItem := 0;
      end;
      if ListView_GetItem(Handle, Item) then
        Result := TGSListItem(Item.lParam);
    end;
  end;
end;

procedure TGSListItems.GroupCheckOperation(CheckAll: Boolean);
var
  I: Integer;
begin
  BeginUpdate;
  try
    for I := 0 to Count - 1 do
      Item[I].Checked := CheckAll;
  finally
    EndUpdate;
  end;
end;

function TGSListItems.IndexOf(Value: TGSListItem): Integer;
var
  Info: TLVFindInfo;
begin
  with Info do
  begin
    flags := LVFI_PARAM;
    lParam := Integer(Value);
  end;
  Result := ListView_FindItem(Handle, -1, Info);
end;

procedure TGSListItems.SetCount(Value: Integer);
begin
  if Value <> 0 then
    ListView_SetItemCountEx(Handle, Value, LVSICF_NOINVALIDATEALL)
  else
    ListView_SetItemCountEx(Handle, Value, 0);
end;

procedure TGSListItems.SetItem(Index: Integer; Value: TGSListItem);
begin
  Item[Index].Assign(Value);
end;

procedure TGSListItems.Clear;
begin
  if Owner.HandleAllocated then ListView_DeleteAllItems(Handle);
end;

procedure TGSListItems.BeginUpdate;
begin
  if FUpdateCount = 0 then SetUpdateState(True);
  Inc(FUpdateCount);
end;

procedure TGSListItems.SetUpdateState(Updating: Boolean);
var
  i: Integer;
begin
  if Updating then
  begin
    with Owner do
    begin
      FSavedSort := SortType;
      SortType := stNone;
    end;
    for i := 0 to Owner.Columns.Count - 1 do
    begin
      with Owner.Columns[i] as TGSListColumn do
        if WidthType < 0 then
        begin
          FPrivateWidth := WidthType;
          FWidth := Width;
          DoChange;
        end;
    end;
    SendMessage(Handle, WM_SETREDRAW, 0, 0);
    if Owner.ColumnsShowing and Owner.ValidHeaderHandle then
      SendMessage(Owner.FHeaderHandle, WM_SETREDRAW, 0, 0);
  end
  else
    if FUpdateCount = 0 then
    begin
      Owner.SortType := Owner.FSavedSort;
      for i := 0 to Owner.Columns.Count - 1 do
      begin
        with Owner.Columns[i] as TGSListColumn do
          if FPrivateWidth < 0 then
          begin
            Width := FPrivateWidth;
            FPrivateWidth := 0;
          end;
      end;
      FNoRedraw := True;
      try
        SendMessage(Handle, WM_SETREDRAW, 1, 0);
        Owner.Invalidate;
      finally
        FNoRedraw := False;
      end;
      if Owner.ColumnsShowing and Owner.ValidHeaderHandle then
        SendMessage(Owner.FHeaderHandle, WM_SETREDRAW, 1, 0);
    end;
end;

procedure TGSListItems.EndUpdate;
begin
  Dec(FUpdateCount);
  if FUpdateCount = 0 then SetUpdateState(False);
end;

procedure TGSListItems.Assign(Source: TPersistent);
var
  Items: TGSListItems;
  I: Integer;
begin
  if Source is TGSListItems then
  begin
    Clear;
    Items := TGSListItems(Source);
    for I := 0 to Items.Count - 1 do Add.Assign(Items[I]);
  end
  else inherited Assign(Source);
end;

procedure TGSListItems.DefineProperties(Filer: TFiler);

  function WriteItems: Boolean;
  var
    I: Integer;
    Items: TGSListItems;
  begin
    Items := TGSListItems(Filer.Ancestor);
    if (Items = nil) then
      Result := Count > 0
    else if (Items.Count <> Count) then
      Result := True
    else
    begin
      Result := False;
      for I := 0 to Count - 1 do
      begin
        Result := not Item[I].IsEqual(Items[I]);
        if Result then Break;
      end
    end;
  end;

begin
  inherited DefineProperties(Filer);
  // Data property is platform specific (Ansi)
  // ItemData property stores data in Unicode
  Filer.DefineBinaryProperty('Data', ReadData, nil, False);
  Filer.DefineBinaryProperty('ItemData', ReadItemData, WriteItemData, WriteItems);
end;

procedure TGSListItems.ReadData(Stream: TStream);
var
  I, J, Size, L, Len: Integer;
  ItemHeader: PItemHeader;
  ItemInfo: PItemInfo;
  PStr: PShortStr;
  PInt: PSmallInt;
begin
  Clear;
  Stream.ReadBuffer(Size, SizeOf(Integer));
  ItemHeader := AllocMem(Size);
  try
    Stream.ReadBuffer(ItemHeader^.Count, Size - SizeOf(Integer));
    ItemInfo := @ItemHeader^.Items;
    PStr := nil;
    for I := 0 to ItemHeader^.Count - 1 do
    begin
      with Add do
      begin
        Caption := string(AnsiString(ItemInfo^.Caption));
        ImageIndex := ItemInfo^.ImageIndex;
        OverlayIndex := ItemInfo^.OverlayIndex;
        StateIndex := ItemInfo^.StateIndex;
        Data := ItemInfo^.Data;
        PStr := @ItemInfo^.Caption;
        Inc(Integer(PStr), Length(PStr^) + 1);
        Len := 0;
        for J := 0 to ItemInfo^.SubItemCount - 1 do
        begin
          SubItems.Add(string(PStr^));
          L := Length(PStr^);
          Inc(Len, L + 1);
          Inc(Integer(PStr), L + 1);
        end;
      end;
      Inc(Integer(ItemInfo), SizeOf(TItemInfo) - 255 +
        Length(ItemInfo.Caption) + Len);
    end;
    //read subitem images, if present.
    if PAnsiChar(PStr) - PAnsiChar(ItemHeader) < Size then
    begin
      PInt := Pointer(PStr);
      for I := 0 to Count - 1 do
        with Item[I] do
          for J := 0 to SubItems.Count - 1 do
          begin
            SubItemImages[J] := PInt^;
            Inc(PInt);
          end;
    end;
  finally
    FreeMem(ItemHeader, Size);
  end;
end;

const
  ListItemStreamVersion: Byte = $01;

procedure TGSListItems.ReadItemData(Stream: TStream);
var
  I, J, Size, ItemCount: Integer;
  LImageIndex: SmallInt;
  StreamVersion, Len: Byte;
  ItemInfo: TItemDataInfo;
  LWideStr: WideString;
begin
  Clear;
  Stream.ReadBuffer(StreamVersion, SizeOf(StreamVersion));
  if StreamVersion <> ListItemStreamVersion then
    Exit;
  Stream.ReadBuffer(Size, SizeOf(Integer));
  Stream.ReadBuffer(ItemCount, SizeOf(Integer));

  for I := 0 to ItemCount - 1 do
  begin
    Stream.ReadBuffer(ItemInfo, SizeOf(TItemDataInfo));
    with Add do
    begin
      ImageIndex := ItemInfo.ImageIndex;
      OverlayIndex := ItemInfo.OverlayIndex;
      StateIndex := ItemInfo.StateIndex;
      GroupID := ItemInfo.GroupID;
      Data := ItemInfo.Data;
      Tag := ItemInfo.Tag;
      
      // Read Caption
      SetLength(LWideStr, ItemInfo.CaptionLen);
      Stream.ReadBuffer(LWideStr[1], ItemInfo.CaptionLen * 2);
      Caption := LWideStr;

      // Read length of each SubItem in chars, followed by actual text
      for J := 0 to ItemInfo.SubItemCount - 1 do
      begin
        Stream.ReadBuffer(Len, SizeOf(Byte));
        SetLength(LWideStr, Len);
        Stream.ReadBuffer(LWideStr[1], Len * 2);
        SubItems.Add(LWideStr);
      end;
    end;
  end;

  // Read subitem images, if present
  for I := 0 to Count - 1 do
    with Item[I] do
      for J := 0 to SubItems.Count - 1 do
      begin
        Stream.ReadBuffer(LImageIndex, SizeOf(SmallInt));
        SubItemImages[J] := LImageIndex;
      end;
end;

procedure TGSListItems.WriteItemData(Stream: TStream);
var
  ItemInfo: TItemDataInfo;
  LCaption: WideString;
  I, J, Size, L: Integer;
  LImageIndex: Smallint;
  LItemCount, LCaptionLen: Integer;

  function GetByteLength(const S: string): Integer;
  begin
    Result := Length(S) * 2;
    if Result > 510 then
      Result := 510; // Max length for an item is 255 chars
  end;

begin
  Size := 0;
  for I := 0 to Count - 1 do
  begin
    L := GetByteLength(Item[I].Caption) + SizeOf(Byte); // Add length byte
    for J := 0 to Item[I].SubItems.Count - 1 do
    begin
      Inc(L, GetByteLength(Item[I].SubItems[J]) + SizeOf(Byte)); // Add length byte
      Inc(L, SizeOf(SmallInt)); // SubItem images
    end;
    Inc(Size, SizeOf(TItemDataInfo) + L);
  end;

  LItemCount := Count;
  Stream.WriteBuffer(ListItemStreamVersion, SizeOf(Byte));
  Stream.WriteBuffer(Size, SizeOf(Integer));
  Stream.WriteBuffer(LItemCount, SizeOf(Integer));
  for I := 0 to Count - 1 do
  begin
    with Item[I] do
    begin
      // Write TItemDataInfo structure
      ItemInfo.ImageIndex := ImageIndex;
      ItemInfo.OverlayIndex := OverlayIndex;
      ItemInfo.StateIndex := StateIndex;
      ItemInfo.GroupID := GroupID;
      ItemInfo.Data := Data;
      ItemInfo.SubItemCount := SubItems.Count;
      ItemInfo.Tag := Tag;
      LCaption := Caption;
      LCaptionLen := Length(LCaption);
      if LCaptionLen > 255 then
        LCaptionLen := 255;
      ItemInfo.CaptionLen := LCaptionLen;
      Stream.WriteBuffer(ItemInfo, SizeOf(TItemDataInfo));

      // Write Caption
      Stream.WriteBuffer(LCaption[1], ItemInfo.CaptionLen * 2);

      // Write length of each SubItem in chars followed by the SubItem
      for J := 0 to SubItems.Count - 1 do
      begin
        LCaption := SubItems[J];
        LCaptionLen := Length(LCaption);
        if LCaptionLen > 255 then
          LCaptionLen := 255;
        Stream.WriteBuffer(LCaptionLen, SizeOf(Byte));
        Stream.WriteBuffer(LCaption[1], LCaptionLen * 2);
      end;
    end;
  end;

  // Write SubItem images
  for I := 0 to Count - 1 do
    with Item[I] do
      for J := 0 to SubItems.Count - 1 do
      begin
        LImageIndex := SubItemImages[J];
        Stream.WriteBuffer(LImageIndex, SizeOf(SmallInt));
      end;
end;

procedure TGSListItems.Delete(Index: Integer);
begin
  Item[Index].Delete;
end;

function TGSListItems.CreateItem(Index: Integer;
  ListItem: TGSListItem): TLVItem;
const
  GroupMasks: array [Boolean] of Integer = (0, LVIF_GROUPID);
begin
  with Result do
  begin
    // Rouse_ 05.10.2009
    //    ,      LVIF_GROUPID,
    //     NTDLL
    mask := LVIF_PARAM or LVIF_IMAGE or GroupMasks[
      Owner.Groups.Enabled and (Owner.Groups.Count > 0)];
    iItem := Index;
    iSubItem := 0;
    iImage := I_IMAGECALLBACK;
    lParam := Longint(ListItem);
    iGroupId := 0;
  end;
end;

{$ENDREGION}

{$REGION ' TIconOptions '}

{ TIconOptions }

constructor TIconOptions.Create(AOwner: TGSCustomListView);
begin
  inherited Create;
  if AOwner = nil then raise Exception.CreateRes(@sInvalidOwner);
  FListView := AOwner;
  Arrangement := iaTop;
  AutoArrange := False;
  WrapText := True;
end;

procedure TIconOptions.SetArrangement(Value: TIconArrangement);
begin
  if Value <> Arrangement then
  begin;
    FArrangement := Value;
    FListView.RecreateWnd;
  end;
end;

procedure TIconOptions.SetAutoArrange(Value: Boolean);
begin
  if Value <> AutoArrange then
  begin
    FAutoArrange := Value;
    FListView.RecreateWnd;
  end;
end;

procedure TIconOptions.SetWrapText(Value: Boolean);
begin
  if Value <> WrapText then
  begin
    GSrapText := Value;
    FListView.RecreateWnd;
  end;
end;

{$ENDREGION}

{$REGION ' TGSCustomListView '}

{ TGSCustomListView }

function DefaultListViewSort(Item1, Item2: TGSListItem;
  lParam: Integer): Integer; stdcall;
begin
  with Item1 do
    if Assigned(ListView.OnCompare) then
      ListView.OnCompare(ListView, Item1, Item2, lParam, Result)
    else Result := lstrcmp(PChar(Item1.Caption), PChar(Item2.Caption));
end;

constructor TGSCustomListView.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := ControlStyle - [csCaptureMouse] + [csDisplayDragImage, csReflector, csPannable];
  Width := 250;
  Height := 150;
  BorderStyle := bsSingle;
  ViewStyle := vsIcon;
  ParentColor := False;
  TabStop := True;
  HideSelection := True;
  ShowColumnHeaders := True;
  ColumnClick := True;
  FCanvas := TControlCanvas.Create;
  TControlCanvas(FCanvas).Control := Self;
  FDragIndex := -1;
  FIconOptions := TIconOptions.Create(Self);
  FListColumns := CreateColumns;
  FListItems := CreateListItems;
  FTempItem := CreateListItem;
  // Rouse_ 05.11.2008
  //   - 
  FGroups := CreateGroups;
  FTiles := CreateTyles;
  GSorkAreas := TWorkAreas.Create(Self, TWorkArea);
  FShowWorkAreas := False;
  FUpdatingColumnOrder := False;
  FOwnerDataCount := 0;
  FHoverTime := -1;
  FDragImage := TDragImageList.CreateSize(32, 32);
  FEditInstance := Classes.MakeObjectInstance(EditWndProc);
  FHeaderInstance := Classes.MakeObjectInstance(HeaderWndProc);
  FLargeChangeLink := TChangeLink.Create;
  FLargeChangeLink.OnChange := ImageListChange;
  FSmallChangeLink := TChangeLink.Create;
  FSmallChangeLink.OnChange := ImageListChange;
  FStateChangeLink := TChangeLink.Create;
  FStateChangeLink.OnChange := ImageListChange;
  FTileChangeLink := TChangeLink.Create;
  FTileChangeLink.OnChange := ImageListChange;
  FSaveSelectedIndex := -1;
  FColumnAutosort := TGSAutosortParams.Create(Self);
  FTrackedColumn := -1;
  FLockedColumnsWidth := TList.Create;
end;

function TGSCustomListView.CreateColumns: TGSListColumns;
begin
  Result := TGSListColumns.Create(Self);
end;

function TGSCustomListView.CreateGroups: TGSListGroups;
begin
  Result := TGSListGroups.Create(Self);
end;

destructor TGSCustomListView.Destroy;
begin
  FLockedColumnsWidth.Free;
  FColumnAutosort.Free;
  FTiles.Free;
  FGroups.Free;
  if HandleAllocated then DestroyWindowHandle;
  FDragImage.Free;
  FListColumns.Free;
  FTempItem.Free;
  FListItems.Free;
  FIconOptions.Free;
  FMemStream.Free;
  FColStream.Free;
  FCheckStream.Free;
  GSorkAreas.Free;
  Classes.FreeObjectInstance(FEditInstance);
  if FHeaderHandle <> 0 then
    SetWindowLong(FHeaderHandle, GWL_WNDPROC, LongInt(FDefHeaderProc));
  Classes.FreeObjectInstance(FHeaderInstance);
  FTileChangeLink.Free;
  FLargeChangeLink.Free;
  FSmallChangeLink.Free;
  FStateChangeLink.Free;
  FCanvas.Free;
  FCanvas := nil;
  inherited Destroy;
end;

procedure TGSCustomListView.CreateParams(var Params: TCreateParams);
const
  BorderStyles: array[TBorderStyle] of DWORD = (0, WS_BORDER);
  EditStyles: array[Boolean] of DWORD = (LVS_EDITLABELS, 0);
  MultiSelections: array[Boolean] of DWORD = (LVS_SINGLESEL, 0);
  HideSelections: array[Boolean] of DWORD = (LVS_SHOWSELALWAYS, 0);
  Arrangements: array[TIconArrangement] of DWORD = (LVS_ALIGNTOP,
    LVS_ALIGNLEFT);
  AutoArrange: array[Boolean] of DWORD = (0, LVS_AUTOARRANGE);
  WrapText: array[Boolean] of DWORD = (LVS_NOLABELWRAP, 0);
  ViewStyles: array[TGSViewStyle] of DWORD = (LVS_ICON, LVS_SMALLICON,
    LVS_LIST, LVS_REPORT, 0);
  ShowColumns: array[Boolean] of DWORD = (LVS_NOCOLUMNHEADER, 0);
  ColumnClicks: array[Boolean] of DWORD = (LVS_NOSORTHEADER, 0);
begin
  InitCommonControl(ICC_LISTVIEW_CLASSES);
  inherited CreateParams(Params);
  CreateSubClass(Params, WC_LISTVIEW);
  with Params do
  begin
    Style := Style or WS_CLIPCHILDREN or ViewStyles[ViewStyle] or
      BorderStyles[BorderStyle] or Arrangements[IconOptions.Arrangement] or
      EditStyles[ReadOnly] or MultiSelections[MultiSelect] or
      HideSelections[HideSelection] or
      AutoArrange[IconOptions.AutoArrange] or
      WrapText[IconOptions.WrapText] or
      ShowColumns[ShowColumnHeaders] or
      ColumnClicks[ColumnClick] or
      LVS_SHAREIMAGELISTS;
    if FOwnerData then Style := Style or LVS_OWNERDATA;
    if FOwnerDraw then Style := Style or LVS_OWNERDRAWFIXED;
    if Ctl3D and NewStyleControls and (FBorderStyle = bsSingle) then
    begin
      Style := Style and not WS_BORDER;
      ExStyle := Params.ExStyle or WS_EX_CLIENTEDGE;
    end;
    WindowClass.style := WindowClass.style and not (CS_HREDRAW or CS_VREDRAW);
  end;
end;

function TGSCustomListView.CreateTyles: TGSListTiles;
begin
  Result := TGSListTiles.Create(Self);
end;

procedure TGSCustomListView.CreateWnd;

  procedure ReadCols;
  var
    Reader: TReader;
  begin
    if FColStream = nil then Exit;
    Columns.Clear;
    Reader := TReader.Create(FColStream, 1024);
    try
      Reader.ReadValue;
      Reader.ReadCollection(Columns);
    finally
      Reader.Free;
    end;
    FColStream.Destroy;
    FColStream := nil;
  end;

begin
  inherited CreateWnd;
  ResetExStyles;
  SetTextBKColor(Color);
  SetTextColor(Font.Color);
  SetAllocBy(AllocBy);
  HoverTime := FHoverTime;
  if FMemStream <> nil then
  begin
    Items.BeginUpdate;
    FReading := True;
    try
      Columns.Clear;
      FMemStream.ReadComponent(Self);
      FMemStream.Destroy;
      FMemStream := nil;
      if OwnerData then Items.Count := FOwnerDataCount;
      if FCheckboxes then RestoreChecks;
      ReadCols;
      Font := Font;
      if FSaveSelectedIndex <> -1 then
      begin
        Selected := Items[FSaveSelectedIndex];
        // QC #25056 BUGFIX
        if Selected <> nil then        
          Selected.MakeVisible(False);
      end;

      CheckHeaderOverflow;

      // 05.11.2008 Rouse_
      //  
      if FSaveSortSection <> -1 then
      begin
        Columns.SortedIndex := FSaveSortSection;
        Columns.SortDirection := FSaveSortDirection;
      end;

      //   ,    
      if ViewStyle = vsTile then
        ListView_SetView(Handle, LV_VIEW_TILE);

    finally
      Items.EndUpdate;
      FReading := False;
    end;
  end;
  Columns.UpdateCols;

  ListView_EnableGroupView(Handle, Groups.Enabled);

  SetNormalImageList;
  if (SmallImages <> nil) and SmallImages.HandleAllocated then
    SetImageList(SmallImages.Handle, LVSIL_SMALL);
  if (StateImages <> nil) and StateImages.HandleAllocated then
    SetImageList(StateImages.Handle, LVSIL_STATE);
  DoAutoSize;
  if ThemeServices.ThemesEnabled and (Win32MajorVersion >= 6) then
    SetWindowTheme(Handle, 'explorer', nil); // do not localize
end;

procedure TGSCustomListView.DestroyWnd;
begin
  if (csRecreating in ControlState) then
  begin
    if FMemStream = nil then
      FMemStream := TMemoryStream.Create
    else
      FMemStream.Size := 0;
    if OwnerData then FOwnerDataCount := Items.Count;
    FMemStream.WriteComponent(Self);
    FMemStream.Position := 0;
    if FCheckboxes then
      SaveChecks;
    if Assigned(Selected) then
      FSaveSelectedIndex := Selected.Index
    else
      FSaveSelectedIndex := -1;
    // 05.11.2008 Rouse_
    //   
    FSaveSortSection := Columns.SortedIndex;
    FSaveSortDirection := Columns.SortDirection;
  end;
  inherited DestroyWnd;
end;

procedure TGSCustomListView.SetImageList(Value: HImageList; Flags: Integer);
begin
  if HandleAllocated then
  begin
    if (Flags = LVSIL_NORMAL) and (Value <> 0) then
      SetNormalImageList
    else
      ListView_SetImageList(Handle, Value, Flags);
  end;
end;

procedure TGSCustomListView.ImageListChange(Sender: TObject);
var
  ImageHandle: HImageList;
begin
  if HandleAllocated then
  begin
    if TCustomImageList(Sender).HandleAllocated then
      ImageHandle := TCustomImageList(Sender).Handle
    else
      ImageHandle := 0;
    if Sender = LargeImages then
      SetImageList(ImageHandle, LVSIL_NORMAL)
    else
      if Sender = SmallImages then
        SetImageList(ImageHandle, LVSIL_SMALL)
      else
        if Sender = StateImages then
          SetImageList(ImageHandle, LVSIL_STATE)
        else
          if Sender = TileImages then
            SetImageList(ImageHandle, LVSIL_NORMAL);
  end;
end;

procedure TGSCustomListView.Notification(AComponent: TComponent;
  Operation: TOperation);
begin
  inherited Notification(AComponent, Operation);
  if Operation = opRemove then
  begin
    if AComponent = LargeImages then LargeImages := nil;
    if AComponent = SmallImages then SmallImages := nil;
    if AComponent = StateImages then StateImages := nil;
    if AComponent = TileImages then TileImages := nil;    
  end;
end;

procedure TGSCustomListView.HeaderWndProc(var Message: TMessage);

  procedure UpdateColumnOrder;
  var
    I: Integer;
    ColumnOrder: array of Integer;
  begin
    SetLength(ColumnOrder, Columns.Count);
    ListView_GetColumnOrderArray(Handle, Columns.Count, PInteger(ColumnOrder));
    FListColumns.BeginUpdate;
    try
      for I := 0 to FListColumns.Count - 1 do
        GetColumnFromTag(ColumnOrder[I]).Index := I;
      if Assigned(FOnColumnDragged) then
        FOnColumnDragged(Self);
    finally
      FListColumns.EndUpdate;
      FUpdatingColumnOrder := False;
    end;
  end;

  procedure DoBufferedPaint(DC: HDC; Rect: TRect);
  var
    MemDC: HDC;
    PaintBuffer: HPAINTBUFFER;
  begin
    PaintBuffer := BeginBufferedPaint(DC, Rect, BPBF_TOPDOWNDIB, nil, MemDC);
    try
      SendMessage(FHeaderHandle, WM_PRINTCLIENT, WPARAM(MemDC), PRF_CLIENT);
      BufferedPaintMakeOpaque(PaintBuffer, @Rect);
    finally
      EndBufferedPaint(PaintBuffer, True);
    end;
  end;

var
  DC: HDC;
  PS: TPaintStruct;
  Form: TCustomForm;
begin
  try
    with Message do
    begin
      case Msg of
        WM_CAPTURECHANGED:
          if FUpdatingColumnOrder then
            UpdateColumnOrder;
        WM_NCHITTEST:
          with TWMNCHitTest(Message) do
            if csDesigning in ComponentState then
            begin
              Result := Windows.HTTRANSPARENT;
              Exit;
            end;
        WM_NCDESTROY:
          begin
            Result := CallWindowProc(FDefHeaderProc,
              FHeaderHandle, Msg, WParam, LParam);
            FHeaderHandle := 0;
            FDefHeaderProc := nil;
            Exit;
          end;
        WM_PAINT:
          begin
            if DoubleBuffered and DwmCompositionEnabled then
            begin
              Form := GetParentForm(Self);
              if (Form <> nil) and Form.GlassFrame.FrameExtended and
                Form.GlassFrame.IntersectsControl(Self) then
              begin
                DC := BeginPaint(FHeaderHandle, PS);
                try
                  DoBufferedPaint(DC, PS.rcPaint);
                finally
                  EndPaint(FHeaderHandle, PS);
                end;
                Exit;
              end;
            end;
          end;
      end;
      Result := CallWindowProc(FDefHeaderProc,
        FHeaderHandle, Msg, WParam, LParam);
    end;
  except
    Application.HandleException(Self);
  end;
end;

procedure TGSCustomListView.EditWndProc(var Message: TMessage);

  procedure DoBufferedPaint(DC: HDC; Rect: TRect);
  var
    MemDC: HDC;
    PaintBuffer: HPAINTBUFFER;
  begin
    PaintBuffer := BeginBufferedPaint(DC, Rect, BPBF_TOPDOWNDIB, nil, MemDC);
    try
      SendMessage(FEditHandle, WM_PRINTCLIENT, WPARAM(MemDC), PRF_CLIENT);
      BufferedPaintMakeOpaque(PaintBuffer, @Rect);
    finally
      EndBufferedPaint(PaintBuffer, True);
    end;
  end;

var
  DC: HDC;
  LWindowRect, AWindowRect: TRect;
  MousePos: TPoint;
begin
  try
    with Message do
    begin
      case Msg of
        WM_KEYDOWN,
        WM_SYSKEYDOWN: if DoKeyDown(TWMKey(Message)) then Exit;
        WM_CHAR: if DoKeyPress(TWMKey(Message)) then Exit;
        WM_KEYUP,
        WM_SYSKEYUP: if DoKeyUp(TWMKey(Message)) then Exit;
        CN_KEYDOWN,
        CN_CHAR, CN_SYSKEYDOWN,
        CN_SYSCHAR:
          begin
            WndProc(Message);
            Exit;
          end;
        CM_BUFFEREDPRINTCLIENT:
          if FSaveSelectedIndex = 0 then
          begin
            DC := GetDC(FEditHandle);
            try
              GetWindowRect(FEditHandle, LWindowRect);
              MapWindowPoints(0, FEditHandle, LWindowRect, 2);
              DoBufferedPaint(DC, LWindowRect);
            finally
              FSaveSelectedIndex := -1;
              ReleaseDC(FEditHandle, DC);
            end;
            Exit;
          end;
        WM_RBUTTONUP:
        begin
          GetWindowRect(FEditHandle, LWindowRect);
          if DoContextPopup(psEdit, ScreenToClient(
            Point(LWindowRect.Left + LParamLo, LWindowRect.Top + LParamHi))) then
          begin
            Message.Result := 0;
            Result := 0;
            Exit;
          end;
        end;
        WM_CONTEXTMENU:
        begin
          GetWindowRect(FEditHandle, LWindowRect);
          AWindowRect := LWindowRect;
          MapWindowPoints(0, FEditHandle, AWindowRect, 2);
          MousePos := ScreenToClient(
            Point(LWindowRect.Left + AWindowRect.Right shr 1,
            LWindowRect.Top + AWindowRect.Bottom shr 1));
          if DoContextPopup(psEdit, MousePos) then
          begin
            Message.Result := 0;
            Result := 0;
            Exit;
          end;
        end;
      end;
      Result := CallWindowProc(FDefEditProc, FEditHandle, Msg, WParam, LParam);
    end;
  except
    Application.HandleException(Self);
  end;
end;

function TGSCustomListView.ExecuteAction(Action: TBasicAction): Boolean;
begin
  Result := inherited ExecuteAction(Action);
  if not IsEditing then
  begin
    //     
    //     
    if Action is TEditSelectAll then
    begin
      SelectAll;
      Result := True;
      Exit;
    end;
  end
  else
  begin
    if (Action is TEditDelete) then
    begin
      SendMessage(FEditHandle, WM_CLEAR, 0, 0);
      Result := True;
      Exit;
    end;
    if (Action is TEditSelectAll) then
    begin
      SendMessage(FEditHandle, EM_SETSEL, 0, -1);
      Result := True;
      Exit;
    end;
    if (Action is TEditCopy) then
    begin
      SendMessage(FEditHandle, WM_COPY, 0, 0);
      Result := True;
      Exit;
    end;
    if (Action is TEditCut) then
    begin
      SendMessage(FEditHandle, WM_CUT, 0, 0);
      Result := True;
      Exit;
    end;
    if (Action is TEditPaste) then
    begin
      SendMessage(FEditHandle, WM_PASTE, 0, 0);
      Result := True;
      Exit;
    end;
    if (Action is TEditUndo) then
    begin
      SendMessage(FEditHandle, EM_UNDO, 0, 0);
      Result := True;
      Exit;
    end;
  end;
end;

procedure TGSCustomListView.UpdateItems(FirstIndex, LastIndex: Integer);
begin
  ListView_RedrawItems(Handle, FirstIndex, LastIndex);
end;

procedure TGSCustomListView.ResetExStyles;
var
  AStyles: DWORD;
  TempImages: TCustomImageList;
begin
  if HandleAllocated then
  begin
    TempImages := nil;
    if StateImages <> nil then
    begin
      TempImages := StateImages;
      StateImages := nil;
    end;
    AStyles := LVS_EX_SUBITEMIMAGES or LVS_EX_INFOTIP;
    if FCheckboxes then AStyles := LVS_EX_CHECKBOXES;
    if FGridLines then AStyles := AStyles or LVS_EX_GRIDLINES;
    if FHotTrack then AStyles := AStyles or LVS_EX_TRACKSELECT;
    if FRowSelect then AStyles := AStyles or LVS_EX_FULLROWSELECT;
    if FFlatScrollBars then AStyles := AStyles or LVS_EX_FLATSB;
    if FFullDrag then AStyles := AStyles or LVS_EX_HEADERDRAGDROP;

    if DoubleBuffered then
      AStyles := AStyles or LVS_EX_DOUBLEBUFFER;

    if FShowWorkAreas then AStyles := AStyles or LVS_EX_MULTIWORKAREAS;
    if htHandPoint in FHotTrackStyles then
      AStyles := AStyles or LVS_EX_ONECLICKACTIVATE
    else
      if FHotTrackStyles * [htUnderlineHot, htUnderlineCold] <> [] then
        AStyles := AStyles or LVS_EX_TWOCLICKACTIVATE;
    if htUnderlineHot in FHotTrackStyles then
      AStyles := AStyles or LVS_EX_UNDERLINEHOT;
    if htUnderlineCold in FHotTrackStyles then
      AStyles := AStyles or LVS_EX_UNDERLINECOLD;
    if ShowColumnAllwais then
    begin
      AStyles := AStyles or LVS_EX_HEADERINALLVIEWS;
      if HeaderOverflow then
        AStyles := AStyles or LVS_EX_COLUMNOVERFLOW;
    end;
    ListView_SetExtendedListViewStyle(Handle, AStyles);
    if TempImages <> nil then
      StateImages := TempImages;
  end;
end;

procedure TGSCustomListView.Resize;
begin
  inherited;
  CheckHeaderOverflow;
end;

procedure TGSCustomListView.RestoreChecks;
var
  i: Integer;
  Value: Boolean;
begin
  for i := 0 to Items.Count - 1 do
  begin
    if FCheckStream <> nil then
    begin
      FCheckStream.Read(Value, SizeOf(Value));
      Items[i].Checked := Value;
    end
    else
      Items[i].Checked := Items[i].FChecked;
  end;
  FCheckStream.Free;
  FCheckStream := nil;
end;

procedure TGSCustomListView.SaveChecks;
var
  i: Integer;
  Value: Boolean;
begin
  if FCheckStream = nil then FCheckStream := TMemoryStream.Create
  else FCheckStream.Size := 0;
  for i := 0 to Items.Count - 1 do
  begin
    Value := Items[i].Checked;
    FCheckStream.Write(Value, SizeOf(Value));
  end;
  FCheckStream.Position := 0;
end;

procedure TGSCustomListView.SetCheckboxes(Value: Boolean);
var
  I: Integer;
begin
  if FCheckboxes <> Value then
  begin
    FCheckboxes := Value;
    ResetExStyles;
    if FCheckboxes then
      RestoreChecks
    else
      for I := 0 to Items.Count - 1 do
        Items[I].FChecked := (ListView_GetCheckState(Handle, Items[I].Index) <> 0)
  end;
end;

procedure TGSCustomListView.SetGridLines(Value: Boolean);
begin
  if FGridLines <> Value then
  begin
    FGridLines := Value;
    ResetExStyles;
  end;
end;

procedure TGSCustomListView.SetGroups(const Value: TGSListGroups);
begin
  FGroups := Value;
end;

procedure TGSCustomListView.SetHotTrack(Value: Boolean);
begin
  if FHotTrack <> Value then
  begin
    FHotTrack := Value;
    ResetExStyles;
  end;
end;

procedure TGSCustomListView.SetHotTrackStyles(Value: TListHotTrackStyles);
begin
  if FHotTrackStyles <> Value then
  begin
    FHotTrackStyles := Value;
    ResetExStyles;
  end;
end;

procedure TGSCustomListView.SetOwnerData(Value: Boolean);
begin
  if FOwnerData <> Value then
  begin
    Items.Clear;
    FOwnerData := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetOwnerDraw(Value: Boolean);
begin
  if FOwnerDraw <> Value then
  begin
    FOwnerDraw := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetRowSelect(Value: Boolean);
begin
  if FRowSelect <> Value then
  begin
    FRowSelect := Value;
    ResetExStyles;
  end;
end;

procedure TGSCustomListView.SetFlatScrollBars(Value: Boolean);
begin
  if FFlatScrollBars <> Value then
  begin
    FFlatScrollBars := Value;
    ResetExStyles;
  end;
end;

procedure TGSCustomListView.SetFullDrag(Value: Boolean);
begin
  if FFullDrag <> Value then
  begin
    FFullDrag := Value;
    ResetExStyles;
  end;
end;

procedure TGSCustomListView.SetBorderStyle(Value: TBorderStyle);
begin
  if BorderStyle <> Value then
  begin
    FBorderStyle := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetColumnAutosort(const Value: TGSAutosortParams);
begin
  FColumnAutosort.Assign(Value);
end;

procedure TGSCustomListView.SetColumnClick(Value: Boolean);
begin
  if ColumnClick <> Value then
  begin
    FColumnClick := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetItemIndex(const Value: Integer);
begin
  if Value < 0 then
  begin
    if Selected <> nil then
      Selected.Selected := False
  end
  else
    Items[Value].Selected := True;
end;

procedure TGSCustomListView.SetMultiSelect(Value: Boolean);
begin
  if Value <> MultiSelect then
  begin
    FMultiSelect := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetNormalImageList;
var
  ILHandle: THandle;
begin
  ILHandle := 0;
  case ViewStyle of
    vsIcon:
      if (LargeImages <> nil) and LargeImages.HandleAllocated then
        ILHandle := LargeImages.Handle;
    vsTile:
      if (TileImages <> nil) and TileImages.HandleAllocated then
        ILHandle := TileImages.Handle
      else
        if (LargeImages <> nil) and LargeImages.HandleAllocated then
          ILHandle := LargeImages.Handle;
  end;
  ListView_SetImageList(Handle, ILHandle, LVSIL_NORMAL);
end;

procedure TGSCustomListView.SetColumnHeaders(Value: Boolean);
begin
  if Value <> ShowColumnHeaders then
  begin
    FShowColumnHeaders := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetTextColor(Value: TColor);
begin
  ListView_SetTextColor(Handle, ColorToRGB(Font.Color));
end;

procedure TGSCustomListView.SetTileImages(const Value: TCustomImageList);
begin
  if TileImages <> Value then
  begin
    if TileImages <> nil then
      TileImages.UnRegisterChanges(FTileChangeLink);
    FTileImages := Value;
    if TileImages <> nil then
    begin
      TileImages.RegisterChanges(FTileChangeLink);
      TileImages.FreeNotification(Self);
      SetNormalImageList;
    end
    else
    begin
      SetImageList(0, LVSIL_NORMAL);
      SetNormalImageList;
    end;
    Invalidate;
  end;
end;

procedure TGSCustomListView.SetTiles(const Value: TGSListTiles);
begin
  FTiles.Assign(Value);
end;

procedure TGSCustomListView.SetTextBkColor(Value: TColor);
begin
  ListView_SetTextBkColor(Handle, ColorToRGB(Color));
  ListView_SetBkColor(Handle, ColorToRGB(Color));
end;

procedure TGSCustomListView.SetAllocBy(Value: Integer);
begin
  if AllocBy <> Value then
  begin
    FAllocBy := Value;
    if HandleAllocated then ListView_SetItemCount(Handle, Value);
  end;
end;

procedure TGSCustomListView.CMColorChanged(var Message: TMessage);
begin
  inherited;
  if HandleAllocated then SetTextBkColor(Color);
end;

procedure TGSCustomListView.CMCtl3DChanged(var Message: TMessage);
begin
  if FBorderStyle = bsSingle then RecreateWnd;
  inherited;
end;

procedure TGSCustomListView.WMNCCalcSize(var Message: TMessage);
begin
  CheckHeaderOverflow;
  if HeaderOverflow and (ViewStyle <> vsReport) and ShowColumnHeaders then
    // Rouse_ 03.08.2010
    //    http://192.168.0.45/trac/GrandSmeta/ticket/531
    if not (ViewStyle in [vsSmallIcon, vsList]) then
      ShowScrollBar(Handle, SB_HORZ, False);
  inherited;
end;

procedure TGSCustomListView.WMNotify(var Message: TWMNotify);
var
  Col: TGSListColumn;
  P: TPoint;
  hChildWnd: HWND;
  WndClass: string;
  hdhti: THDHitTestInfo;
  HDR_STYLE{, I}: Integer;
  bIsSet: Boolean;
//  hMenu: THandle;
//  MenuItem: TMenuItemInfo;
begin
  inherited;
  if ValidHeaderHandle and (Message.NMHdr^.hWndFrom = FHeaderHandle) then
    with Message.NMHdr^ do
      case code of

        HDN_BEGINTRACKA, HDN_BEGINTRACKW:
        begin
          if CustomCoumnTrack then
            if SystemParametersInfo(SPI_GETDRAGFULLWINDOWS, 0, @bIsSet, 0) then
              if bIsSet then
              begin
                HDR_STYLE := GetWindowLong(FHeaderHandle, GWL_STYLE);
                if (HDR_STYLE and HDS_FULLDRAG) = HDS_FULLDRAG then
                  SetWindowLong(FHeaderHandle, GWL_STYLE,
                   HDR_STYLE and not HDS_FULLDRAG);
              end;
          with PHDNotify(Pointer(Message.NMHdr))^ do
          begin
            Col := GetColumnFromTag(Item);
            FTrackedColumn := Col.Index;
          end;                          
          if Assigned(FBeginTrack) then
            FBeginTrack(Self);
          Message.Result := 0;
        end;

        HDN_ENDTRACKA, HDN_ENDTRACKW:
        begin
          with PHDNotify(Pointer(Message.NMHdr))^, PItem^ do
          if (Mask and HDI_WIDTH) <> 0 then
          begin
            Col := GetColumnFromTag(Item);
            if Col.MinWidth >= cxy then
              cxy := Col.MinWidth
            else if (Col.MaxWidth > 0) and (Col.MaxWidth <= cxy) then
              cxy := Col.MaxWidth;
            Col.Width := cxy;
          end;
          if Assigned(FEndTrack) then
            FEndTrack(Self);
          FTrackedColumn := -1;
          Message.Result := 0;
        end;

        HDN_TRACKA, HDN_TRACKW:
        begin
          with PHDNotify(Pointer(Message.NMHdr))^ do
          begin
            if PItem^.mask = HDI_WIDTH then
              if Assigned(FTrack) then
                FTrack(Self, PItem^.cxy);
          end;
          Message.Result := 0;
        end;

        HDN_OVERFLOWCLICK:
        begin
          // Rouse_ 19.08.2009
          //   Overflow   

          //    

//          hMenu := CreatePopupMenu;
//          try
//            for I := PNMHeader(Pointer(Message.NMHdr))^.iItem to
//              Columns.Count - 1 do
//              InsertMenu(hMenu, DWORD(-1), MF_BYPOSITION, I,
//                PChar(Columns[I].Caption));
//            GetCursorPos(P);
//            TrackPopupMenu(hMenu, TPM_RETURNCMD or TPM_NONOTIFY, P.X, P.Y,
//              0, 0, nil);
//          finally
//            DestroyMenu(hMenu);
//          end;
        end;
        
        HDN_ENDDRAG:
          FUpdatingColumnOrder := True;

        HDN_DIVIDERDBLCLICK:
          with PHDNotify(Pointer(Message.NMHdr))^ do
          begin
            Col := GetColumnFromTag(Item);
            Col.Width := ListView_GetColumnWidth(Handle, Item);
            if IsCustomDrawn(dtControl, cdPrePaint) then Invalidate;
          end;
          
        NM_RCLICK:
          begin
            P := Point(LoWord(GetMessagePos), HiWord(GetMessagePos));
            hChildWnd := ChildWindowFromPoint(Handle, ScreenToClient(P));
            if (hChildWnd <> 0) and (hChildWnd <> Handle) then
            begin
              SetLength(WndClass, 80);
              SetLength(WndClass, GetClassName(hChildWnd, PChar(WndClass), Length(WndClass)));
              if WndClass = 'SysHeader32' then
              begin
                hdhti.Point := ScreenToClient(P);
                hdhti.Point.X := hdhti.Point.X + GetScrollPos(Handle, SB_HORZ);
                if SendMessage(hChildWnd, HDM_HITTEST, 1, Longint(@hdhti)) >= 0 then
                  ColRightClick(GetColumnFromTag(hdhti.Item), hdhti.Point);
              end;
            end;
          end;
      end;
end;

function TGSCustomListView.ColumnsShowing: Boolean;
begin
  Result := (ViewStyle = vsReport);
end;

function TGSCustomListView.ValidHeaderHandle: Boolean;
begin
  Result := FHeaderHandle <> 0;
end;

procedure TGSCustomListView.CMFontChanged(var Message: TMessage);
begin
  inherited;
  if HandleAllocated then
  begin
    SetTextColor(Font.Color);
    if ValidHeaderHandle then
      InvalidateRect(FHeaderHandle, nil, True);
  end;
end;

procedure TGSCustomListView.SetHeaderOverflow(const Value: Boolean);
var
  I: Integer;
begin
  if Value <> HeaderOverflow then
  begin
    FHeaderOverflow := Value;
    if Value then
    begin
      FLockedColumnsWidth.Clear;
      for I := 0 to Columns.Count - 1 do
        FLockedColumnsWidth.Add(Pointer(Columns[I].Width));
    end
    else
      for I := 0 to Columns.Count - 1 do
        Columns[I].Width := Integer(FLockedColumnsWidth[I]);
    CheckHeaderOverflow;
    ResetExStyles;
  end;
end;

procedure TGSCustomListView.SetHideSelection(Value: Boolean);
begin
  if Value <> HideSelection then
  begin
    FHideSelection := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetReadOnly(Value: Boolean);
begin
  if Value <> ReadOnly then
  begin
    FReadOnly := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetIconOptions(Value: TIconOptions);
begin
  with FIconOptions do
  begin
    Arrangement := Value.Arrangement;
    AutoArrange := Value.AutoArrange;
    WrapText := Value.WrapText;
  end;
end;

procedure TGSCustomListView.SetViewStyle(Value: TGSViewStyle);
const
  ViewStyles: array[TGSViewStyle] of Integer = (LVS_ICON, LVS_SMALLICON,
    LVS_LIST, LVS_REPORT, 0);
  SetViews: array[TGSViewStyle] of Integer = (LV_VIEW_ICON, LV_VIEW_SMALLICON,
    LV_VIEW_LIST, LV_VIEW_DETAILS, LV_VIEW_TILE);
var
  Style: Longint;
begin
  if Value <> FViewStyle then
  begin
    FViewStyle := Value;
    if HandleAllocated then
    begin
      Style := GetWindowLong(Handle, GWL_STYLE);
      Style := Style and (not LVS_TYPEMASK);
      Style := Style or ViewStyles[FViewStyle];
      SetWindowLong(Handle, GWL_STYLE, Style);
      UpdateColumns;
      ListView_SetView(Handle, SetViews[FViewStyle]);
      SetNormalImageList;
      case ViewStyle of
        vsIcon,
        vsSmallIcon:
          if IconOptions.Arrangement = iaTop then
            Arrange(arAlignTop)
          else
            Arrange(arAlignLeft);
        vsReport:
          DoAutoSize;
      end;
    end;
  end;
end;

procedure TGSCustomListView.WMParentNotify(var Message: TWMParentNotify);
begin
  with Message do
    if (Event = WM_CREATE) and (FHeaderHandle = 0) then
    begin
      FHeaderHandle := ChildWnd;
      FDefHeaderProc := Pointer(GetWindowLong(FHeaderHandle, GWL_WNDPROC));
      SetWindowLong(FHeaderHandle, GWL_WNDPROC, LongInt(FHeaderInstance));
    end;
  inherited;
end;


function TGSCustomListView.GetItemIndex(Value: TGSListItem): Integer;
var
  I: Integer;
begin
  Result := -1;
  for I := 0 to Items.Count - 1 do if Items[I] = Value then Break;
  if I < Items.Count then Result := I;
end;

function TGSCustomListView.GetItemIndex: Integer;
begin
  Result := -1;
  if Selected <> nil then
    Result := Selected.Index;
end;

function TGSCustomListView.OwnerDataFetch(Item: TGSListItem; Request: TItemRequest): Boolean;
begin
  if Assigned(FOnData) then
  begin
    FOnData(Self, Item);
    Result := True;
  end
  else Result := False;
end;

function TGSCustomListView.OwnerDataFind(Find: TItemFind; const FindString: string;
  const FindPosition: TPoint; FindData: Pointer; StartIndex: Integer;
  Direction: TSearchDirection; Wrap: Boolean): Integer;
begin
  Result := -1;
  if Assigned(FOnDataFind) then FOnDataFind(Self, Find, FindString, FindPosition,
    FindData, StartIndex, Direction, Wrap, Result)
end;

function TGSCustomListView.OwnerDataHint(StartIndex, EndIndex: Integer): Boolean;
begin
  if Assigned(FOnDataHint) then
  begin
    FOnDataHint(Self, StartIndex, EndIndex);
    Result := True;
  end
  else Result := False;
end;

function TGSCustomListView.OwnerDataStateChange(StartIndex, EndIndex: Integer;
  OldState, NewState: TItemStates): Boolean;
begin
  if Assigned(FOnDataStateChange) then
  begin
    FOnDataStateChange(Self, StartIndex, EndIndex, OldState, NewState);
    Result := True;
  end
  else Result := False;
end;

function TGSCustomListView.CreateListItem: TGSListItem;
var
  LClass: TGSListItemClass;
begin
  LClass := TGSListItem;
  if Assigned(FOnCreateItemClass) then
    FOnCreateItemClass(Self, LClass);
  Result := LClass.Create(Items);
end;

function TGSCustomListView.CreateListItems: TGSListItems;
begin
  Result := TGSListItems.Create(Self);
end;

function TGSCustomListView.GetItem(Value: TLVItem): TGSListItem;
var
  S: string;
  Request: TItemRequest;

  function ConvertMask(Mask: Longint): TItemRequest;
  begin
    Result := [];
    if Mask and LVIF_TEXT <> 0 then
      Include(Result, irText);
    if Mask and LVIF_IMAGE <> 0 then
      Include(Result, irImage);
    if Mask and LVIF_PARAM <> 0 then
      Include(Result, irParam);
    if Mask and LVIF_STATE <> 0 then
      Include(Result, irState);
    if Mask and LVIF_INDENT <> 0 then
      Include(Result, irIndent);
  end;

begin
  with Value do
    if (mask and LVIF_PARAM) <> 0 then
      Result := TGSListItem(lParam)
    else
    begin
      if OwnerData then
      begin
        if iItem < 0 then
          Result := nil
        else if iSubItem = 0 then
        begin
          Request := ConvertMask(mask);
          FTempItem.FIndex := iItem;
          FTempItem.FData := Pointer(lParam);
          FTempItem.FSubItems.Clear;
          if (irText in Request) and (pszText <> nil) then
            S := StrPas(pszText) else
            S := '';
            FTempItem.FCaption := S;
          if irImage in Request then
            FTempItem.FImageIndex := iImage;
          if irIndent in Request then
            FTempItem.FIndent := iIndent;
          OwnerDataFetch(FTempItem, Request);
          Result := FTempItem;
        end
        else
          Result := FTempItem;
      end
      else
        Result := Items[IItem];
    end;
end;

function TGSCustomListView.GetSelCount: Integer;
begin
  Result := ListView_GetSelectedCount(Handle);
end;

procedure TGSCustomListView.CNNotify(var Message: TWMNotify);
var
  Item: TGSListItem;
  I: Integer;
  R: TRect;
  DefaultDraw: Boolean;
  ItemFind: TItemFind;
  FindString: string;
  FindPos: TPoint;
  FindData: Pointer;
  SearchDir: TSearchDirection;
  TmpItem: TLVItem;
  SubItem: Boolean;
  SubItemImage: Integer;
  LogFont: TLogFont;
  TmpGroup: TGSListGroup;

  function ConvertFlags(Flags: Integer): TItemFind;
  begin
    if Flags and LVFI_PARAM <> 0 then
      Result := ifData
    else if Flags and LVFI_PARTIAL <> 0 then
      Result := ifPartialString
    else if Flags and LVFI_STRING <> 0 then
      Result := ifExactString
    else if Flags and LVFI_NEARESTXY <> 0 then
      Result := ifNearest
    else
      Result := ifData; // Fall-back value
  end;

  function ConvertStates(State: Integer): TItemStates;
  begin
    Result := [];
    if State and LVIS_ACTIVATING <> 0 then
      Include(Result, isActivating);
    if State and LVIS_CUT <> 0 then
      Include(Result, isCut);
    if State and LVIS_DROPHILITED <> 0 then
      Include(Result, isDropHilited);
    if State and LVIS_FOCUSED <> 0 then
      Include(Result, isFocused);
    if State and LVIS_SELECTED <> 0 then
      Include(Result, isSelected);
  end;

begin
  with Message do
    case NMHdr^.code of
      HDN_TRACK:
        with PHDNotify(Pointer(Message.NMHdr))^, PItem^ do
          if ((Mask and HDI_WIDTH) <> 0) then
          begin
            if Column[Item].MinWidth >= cxy then
              Column[Item].Width := Column[Item].MinWidth
            else if Column[Item].MaxWidth <= cxy then
              Column[Item].Width := Column[Item].MaxWidth;
          end;

      NM_CUSTOMDRAW:
        if Assigned(FCanvas) then
          with PNMCustomDraw(NMHdr)^ do
          try
            FCanvas.Lock;
            Result := CDRF_DODEFAULT;

            if (dwDrawStage and CDDS_ITEM) = 0 then
            begin
              R := ClientRect;
              case dwDrawStage of
                CDDS_PREPAINT:
                begin
                  if IsCustomDrawn(dtControl, cdPrePaint) then
                  begin
                    try
                      FCanvas.Handle := hdc;
                      FCanvas.Font := Font;
                      FCanvas.Brush := Brush;
                      DefaultDraw := CustomDraw(R, cdPrePaint);
                    finally
                      FCanvas.Handle := 0;
                    end;
                    if not DefaultDraw then
                    begin
                      Result := CDRF_SKIPDEFAULT;
                      Exit;
                    end;
                  end;
                  if IsCustomDrawn(dtItem, cdPrePaint) or IsCustomDrawn(dtItem, cdPreErase) then
                    Result := CDRF_NOTIFYITEMDRAW;
                  if IsCustomDrawn(dtItem, cdPostPaint) then
                    Result := Result or CDRF_NOTIFYPOSTPAINT;
                  if IsCustomDrawn(dtItem, cdPostErase) then
                    Result := Result or CDRF_NOTIFYPOSTERASE;
                  if IsCustomDrawn(dtSubItem, cdPrePaint) or IsCustomDrawn(dtSubItem, cdPostPaint) then
                    Result := Result or CDRF_NOTIFYSUBITEMDRAW;
                end;
                CDDS_POSTPAINT:
                  if IsCustomDrawn(dtControl, cdPostPaint) then
                    CustomDraw(R, cdPostPaint);
                CDDS_PREERASE:
                  if IsCustomDrawn(dtControl, cdPreErase) then
                    CustomDraw(R, cdPreErase);
                CDDS_POSTERASE:
                  if IsCustomDrawn(dtControl, cdPostErase) then
                    CustomDraw(R, cdPostErase);
              end;
            end else
            begin
              SubItem := dwDrawStage and CDDS_SUBITEM <> 0;
              { Don't call CustomDrawSubItem for the 0th subitem since
                CustomDrawItem draws that item. }
              if SubItem and (PNMLVCustomDraw(NMHdr)^.iSubItem = 0) then Exit;
              FillChar(TmpItem, SizeOf(TmpItem), 0);
              TmpItem.iItem := dwItemSpec;

              if (dwDrawStage and CDDS_ITEMPREPAINT) = CDDS_ITEMPREPAINT then
              begin
                try
                  FCanvas.Handle := hdc;
                  FCanvas.Font := Font;
                  FCanvas.Brush := Brush;
                  FCanvas.Font.OnChange := CanvasChanged;
                  FCanvas.Brush.OnChange := CanvasChanged;
                  FCanvasChanged := False;
                  if SubItem then
                    DefaultDraw := CustomDrawSubItem(GetItem(TmpItem),
                      PNMLVCustomDraw(NMHdr)^.iSubItem,
                      TCustomDrawState(Word(uItemState)), cdPrePaint)
                  else
                    DefaultDraw := CustomDrawItem(GetItem(TmpItem),
                      TCustomDrawState(Word(uItemState)), cdPrePaint);
                  if not DefaultDraw then
                  begin
                    Result := Result or CDRF_SKIPDEFAULT;
                    Exit;
                  end
                  else if FCanvasChanged then
                  begin
                    FCanvasChanged := False;
                    FCanvas.Font.OnChange := nil;
                    FCanvas.Brush.OnChange := nil;
                    with PNMLVCustomDraw(NMHdr)^ do
                    begin
                      clrText := ColorToRGB(FCanvas.Font.Color);
                      clrTextBk := ColorToRGB(FCanvas.Brush.Color);
                      if GetObject(FCanvas.Font.Handle, SizeOf(LogFont), @LogFont) <> 0 then
                      begin
                        FCanvas.Handle := 0;  // disconnect from hdc
                        // release the font if it's been changed when painting
                        // the listview item, or a previous subitem
                        if SubItem and (FOurFont <> 0) and (FStockFont <> 0) then
                        begin
                          SelectObject(hdc, FStockFont);
                          DeleteObject(FOurFont);
                          FOurFont := 0;
                          FStockFont := 0;
                        end;
                        // don't delete the stock font
                        FOurFont := CreateFontIndirect(LogFont);
                        FStockFont := SelectObject(hdc, FOurFont);
                        Result := Result or CDRF_NEWFONT;
                      end;
                    end;
                  end;
                finally
                  FCanvas.Handle := 0;
                end;
                if not SubItem then
                begin
                  if IsCustomDrawn(dtSubItem, cdPrePaint) then
                    Result := Result or CDRF_NOTIFYSUBITEMDRAW;
                  if IsCustomDrawn(dtItem, cdPostPaint) then
                    Result := Result or CDRF_NOTIFYPOSTPAINT;
                  if IsCustomDrawn(dtItem, cdPostErase) then
                    Result := Result or CDRF_NOTIFYPOSTERASE;
                end else
                begin
                  if IsCustomDrawn(dtSubItem, cdPostPaint) then
                    Result := Result or CDRF_NOTIFYPOSTPAINT;
                  if IsCustomDrawn(dtSubItem, cdPostErase) then
                    Result := Result or CDRF_NOTIFYPOSTERASE;
                end;
              end
              else if (dwDrawStage and CDDS_ITEMPOSTPAINT) = CDDS_ITEMPOSTPAINT then
              begin
                try
                  FCanvas.Handle := hdc;
                  FCanvas.Font := Font;
                  FCanvas.Brush := Brush;
                  if SubItem then
                    CustomDrawSubItem(GetItem(TmpItem),
                      PNMLVCustomDraw(NMHdr)^.iSubItem,
                      TCustomDrawState(Word(uItemState)), cdPostPaint)
                  else
                    CustomDrawItem(GetItem(TmpItem),
                      TCustomDrawState(Word(uItemState)), cdPostPaint);
                finally
                  FCanvas.Handle := 0;
                end;

                //release the font we may have loaned during item drawing.
                if (FOurFont <> 0) and (FStockFont <> 0) then
                begin
                  SelectObject(hdc, FStockFont);
                  DeleteObject(FOurFont);
                  FOurFont := 0;
                  FStockFont := 0;
                end;
              end
              else if (dwDrawStage and CDDS_ITEMPREERASE) = CDDS_ITEMPREERASE then
              begin
                if SubItem then
                  CustomDrawSubItem(GetItem(TmpItem),
                    PNMLVCustomDraw(NMHdr)^.iSubItem,
                    TCustomDrawState(Word(uItemState)), cdPreErase)
                else
                  CustomDrawItem(GetItem(TmpItem),
                    TCustomDrawState(Word(uItemState)), cdPreErase);
              end
              else if (dwDrawStage and CDDS_ITEMPOSTERASE) = CDDS_ITEMPOSTERASE then
              begin
                if SubItem then
                  CustomDrawSubItem(GetItem(TmpItem),
                    PNMLVCustomDraw(NMHdr)^.iSubItem,
                    TCustomDrawState(Word(uItemState)), cdPostErase)
                else
                  CustomDrawItem(GetItem(TmpItem),
                    TCustomDrawState(Word(uItemState)), cdPostErase);
              end;
            end;
          finally
            FCanvas.Unlock;
          end;
      LVN_BEGINDRAG:
        FDragIndex := PNMListView(NMHdr)^.iItem;
      LVN_COLUMNDROPDOWN:
        DoColumnDropDown(PNMListView(NMHdr)^.iSubItem);
      LVN_DELETEITEM:
        begin
          Delete(TGSListItem(PNMListView(NMHdr)^.lParam));
          Result := 1;
        end;
      LVN_DELETEALLITEMS:
        begin
          for I := Items.Count - 1 downto 0 do
            Delete(Items[I]);
          Result := 1;
        end;
      LVN_GETDISPINFO:
        begin
          Item := GetItem(PLVDispInfo(NMHdr)^.item);
          // 04.02.2009 Rouse_
          if Item = nil then
            Exit;
          with PLVDispInfo(NMHdr)^.item do
          begin
            if (mask and LVIF_TEXT) <> 0 then
              if iSubItem = 0 then
                StrPLCopy(pszText, Item.Caption, cchTextMax - 1)
              else
                with Item.SubItems do
                  if iSubItem <= Count then
                    StrPLCopy(pszText, Strings[iSubItem - 1], cchTextMax - 1)
                  else pszText[0] := #0;
            if (mask and LVIF_IMAGE) <> 0 then
            begin
              if iSubItem = 0 then
              begin
                GetImageIndex(Item);
                iImage := Item.ImageIndex;
                
                case ViewStyle of
                  vsIcon:
                    if Assigned(LargeImages) then
                      if Item.LargeIndex >= 0 then
                        iImage := Item.LargeIndex;
                  vsTile:
                    if Assigned(TileImages) and (Item.TileIndex >= 0) then
                      iImage := Item.TileIndex
                    else
                      if Assigned(LargeImages) and (Item.LargeIndex >= 0) then
                        iImage := Item.LargeIndex;
                end;

                if Assigned(FStateImages) then
                begin
                  state := IndexToStateImageMask(Item.StateIndex + 1);
                  stateMask := $F000;
                  mask := mask or LVIF_STATE;
                end;
              end
              else
                if (iSubItem-1 >= 0) and (iSubItem-1 < Item.FSubItems.Count) then
                begin
                  SubItemImage := Item.SubItemImages[iSubItem-1];
                  GetSubItemImage(Item, iSubItem-1, SubItemImage);
                  iImage := SubItemImage;
                end;
            end;
            if (mask and LVIF_INDENT) <> 0 then
              iIndent := Item.Indent;
          end;
        end;

      LVN_ODCACHEHINT:
        with PNMLVCacheHint(NMHdr)^ do
          OwnerDataHint(iFrom, iTo);
      LVN_ODFINDITEM:
        with PNMLVFindItem(NMHdr)^ do
        begin
          ItemFind := ConvertFlags(lvfi.flags);
          FindData := nil;
          FindString := '';
          FindPos := Point(0,0);
          SearchDir := sdAll;
          case ItemFind of
            ifData: FindData := Pointer(lvfi.lParam);
            ifPartialString, ifExactString:
              if lvfi.psz <> nil then
                FindString := StrPas(lvfi.psz) else
                FindString := '';
            ifNearest:
              begin
                FindPos := lvfi.pt;
                case lvfi.vkDirection of
                  VK_LEFT: SearchDir := sdLeft;
                  VK_UP: SearchDir := sdAbove;
                  VK_RIGHT: SearchDir := sdRight;
                  VK_DOWN: SearchDir := sdBelow;
                end;
              end;
          end;
          Result := OwnerDataFind(ConvertFlags(lvfi.flags), FindString, FindPos,
            FindData, iStart, SearchDir, lvfi.flags and LVFI_WRAP <> 0);
        end;
      LVN_ODSTATECHANGED:
        with PNMLVODStateChange(NMHdr)^ do
          OwnerDataStateChange(iFrom, iTo, ConvertStates(uNewState),
            ConvertStates(uOldState));

      LVN_BEGINLABELEDIT:
        begin
          Item := GetItem(PLVDispInfo(NMHdr)^.item);
          if not CanEdit(Item) then Result := 1;
          if Result = 0 then
          begin
            FEditHandle := ListView_GetEditControl(Handle);
            FDefEditProc := Pointer(GetWindowLong(FEditHandle, GWL_WNDPROC));
            SetWindowLong(FEditHandle, GWL_WNDPROC, LongInt(FEditInstance));
          end;
        end;
      LVN_ENDLABELEDIT:
        with PLVDispInfo(NMHdr)^ do
          if (item.pszText <> nil) and (item.IItem <> -1) then
            Edit(item);
      LVN_COLUMNCLICK:
        ColClick(GetColumnFromTag(PNMListView(NMHdr)^.iSubItem));
      LVN_INSERTITEM:
        InsertItem(Items[PNMListView(NMHdr)^.iItem]);
      LVN_ITEMCHANGING:
        with PNMListView(NMHdr)^ do
          if not CanChange(Items[iItem], uChanged) then Result := 1;
      LVN_ITEMCHANGED:
        with PNMListView(NMHdr)^ do
        begin
          Item := Items[iItem];
          Change(Item, uChanged);
          if Assigned(FOnSelectItem) and (uChanged = LVIF_STATE) then
          begin
            if (uOldState and LVIS_SELECTED <> 0) and
              (uNewState and LVIS_SELECTED = 0) then
              FOnSelectItem(Self, Item, False)
            else if (uOldState and LVIS_SELECTED = 0) and
              (uNewState and LVIS_SELECTED <> 0) then
              FOnSelectItem(Self, Item, True);
          end;
          if (Action <> nil) and not (csDesigning in ComponentState) and
             (ActionLink <> nil) then
            ActionLink.Execute(Self);
        end;
      LVN_GETINFOTIP:
        if Assigned(FOnInfoTip) then
          Application.ActivateHint(Mouse.CursorPos);
      LVN_LINKCLICK:
      begin
        // Rouse_ 19.04.2010
        //     
        TmpGroup := FGroups.Items[PNMLVLink(NMHdr)^.iSubItem];
        if Assigned(FTaskClick) then
          FTaskClick(Self, TmpGroup);
      end;
      NM_CLICK:
        FClicked := True;
      NM_RCLICK:
        FRClicked := True;
    end;
end;

procedure TGSCustomListView.ChangeScale(M, D: Integer);
var
  I: Integer;
begin
  if sfWidth in ScalingFlags then
    for I := 0 to Columns.Count-1 do
      Columns[I].Width := MulDiv(Columns[I].Width, M, D);
  inherited ChangeScale(M,D);
end;

procedure TGSCustomListView.CheckHeaderOverflow;
var
  HeaderStyle: DWORD;
  I, A, RightBorder: Integer;
begin
  if not IsWindow(FHeaderHandle) then Exit;
  if FBlockUpdateColumns then Exit;
  if Columns.UpdateCount > 0 then Exit;
  HeaderStyle := GetWindowLong(FHeaderHandle, GWL_STYLE);
  HeaderStyle := HeaderStyle or HDS_CHECKBOXES;
  if HeaderOverflow and (ViewStyle <> vsReport) and
    ShowColumnHeaders then
  begin
    HeaderStyle := HeaderStyle or HDS_OVERFLOW or HDS_NOSIZING;
    SetWindowLong(FHeaderHandle, GWL_STYLE, HeaderStyle);
    if (GetWindowLong(Handle, GWL_STYLE) and WS_HSCROLL) = WS_HSCROLL then
      // Rouse_ 03.08.2010
      //    http://192.168.0.45/trac/GrandSmeta/ticket/531
      if not (ViewStyle in [vsSmallIcon, vsList]) then
        ShowScrollBar(Handle, SB_HORZ, False);
    RightBorder := 0;
    Columns.BeginUpdate;
    try
      FBlockUpdateColumns := True;
      // 31.08.2009 Rouse_
      //   ,
      //      
      //if FLockedColumnsWidth.Count = 0 then
      if FLockedColumnsWidth.Count <> Columns.Count then
      begin
        FLockedColumnsWidth.Clear;
        for I := 0 to Columns.Count - 1 do
          FLockedColumnsWidth.Add(Pointer(Columns[I].Width));
      end;
      for I := 0 to Columns.Count - 1 do
        if RightBorder + Integer(FLockedColumnsWidth[I]) > ClientWidth then
        begin
          for A := I + 1 to Columns.Count - 1 do
            Columns[A].Width := 0;
          Columns[I].Width := ClientWidth - RightBorder;
          Break;
        end
        else
        begin
          Inc(RightBorder, Integer(FLockedColumnsWidth[I]));
          Columns[I].Width := Integer(FLockedColumnsWidth[I]);
        end;
    finally
      Columns.EndUpdate;
      FBlockUpdateColumns := False;
      // 31.08.2009 Rouse_
      //      -  
      //     .
      //    :
      Invalidate;
    end;
  end
  else
  begin
    HeaderStyle := HeaderStyle and not (HDS_OVERFLOW or HDS_NOSIZING);
    SetWindowLong(FHeaderHandle, GWL_STYLE, HeaderStyle);
  end;
end;

procedure TGSCustomListView.ColClick(Column: TGSListColumn);

type
  PSortCallbackParam = ^TSortCallbackParam;
  TSortCallbackParam = record
    SortDirection: TGSSortDirection;
    SortType: TSortType;
    SubItemIndex: Integer;
    UseColumnsData: Boolean;
    Columns: TGSListColumns;
  end;

  function DirectionalSort(lParam1, lParam2, lParamSort: Integer): Integer stdcall;
  var
    szA, szB: PChar;
    iA, iB: Integer;
    fA, fB: Extended;
    dA, dB: TDateTime;
    AIndex: Integer;
  begin
    //      -    ...
    with TGSListItem(lParam1) do
      if Assigned(ListView.OnCompare) then
        ListView.OnCompare(ListView, TGSListItem(lParam1),
          TGSListItem(lParam2), 0, Result)
      else
      begin
        //    -  ,
        //        
        AIndex := PSortCallbackParam(lParamSort).SubItemIndex;
        if AIndex >= 0 then
        begin
          //  -  - ? :)
          if AIndex >= TGSListItem(lParam1).SubItems.Count then
          begin
           szA := #0;
           szB := #0;
          end
          else
          begin
            szA := PChar(TGSListItem(lParam1).SubItems[AIndex]);
            szB := PChar(TGSListItem(lParam2).SubItems[AIndex]);
          end;
        end
        else
        begin
          szA := PChar(TGSListItem(lParam1).Caption);
          szB := PChar(TGSListItem(lParam2).Caption);
        end;

        Result := lstrcmp(szA, szB);
        //  Caption
        Inc(AIndex);
        if PSortCallbackParam(lParamSort).UseColumnsData then
        begin
          //      -    ,
          //  ..      ,
          //      
          case PSortCallbackParam(lParamSort).Columns[AIndex].DataType of
            dtInteger:
            begin
              if TryStrToInt(szA, iA) then
                if TryStrToInt(szB, iB) then
                  if iA < iB then
                    Result := -1
                  else
                    if iA = iB then
                      Result := 0
                    else
                      Result := 1;
            end;
            dtFloat:
            begin
              if TryStrToFloat(szA, fA) then
                if TryStrToFloat(szB, fB) then
                  if fA < fB then
                    Result := -1
                  else
                    if fA = fB then
                      Result := 0
                    else
                      Result := 1;
            end;
            dtDate:
            begin
              if TryStrToDateTime(szA, dA) then
                if TryStrToDateTime(szB, dB) then
                  if dA < dB then
                    Result := -1
                  else
                    if dA = dB then
                      Result := 0
                    else
                      Result := 1;
            end;
          end;
        end;
      end;
    //      
    //    
    case PSortCallbackParam(lParamSort).SortDirection of
      sdDown: Result := -Result;
      sdNone: Result := 0;
    end;
  end;

var
  CallbackParam: TSortCallbackParam;
begin
  if Assigned(FOnColumnClick) then
    FOnColumnClick(Self, Column);
  // Rouse_ 01.11.2008
  //   
  if ColumnAutoSort.Enabled then
  begin
    Columns.SortedIndex := Column.Index;
    //      ,
    //        
    case Columns.SortDirection of
      sdNone: CallbackParam.SortDirection := sdUp;
      sdUp: CallbackParam.SortDirection := sdDown;
      sdDown:
        if ColumnAutoSort.SortStyle = asUpDown then
          CallbackParam.SortDirection := sdUp
        else
          CallbackParam.SortDirection := sdNone;
    end;
    CallbackParam.SortType := SortType;
    CallbackParam.SubItemIndex := Column.Index - 1;
    CallbackParam.Columns := Columns;
    CallbackParam.UseColumnsData := ColumnAutosort.UseColumnDataType;
    Columns.SortDirection := CallbackParam.SortDirection;
    // 
    CustomSort(@DirectionalSort, Integer(@CallbackParam));
//    if Groups.Enabled then
//      if ColumnAutosort.UseGroup then
//        MoveSortedItemsToGroups;
    UpdateAllItems;
  end;
end;

procedure TGSCustomListView.ColRightClick(Column: TGSListColumn; Point: TPoint);
begin
  if Assigned(FOnColumnRightClick) then FOnColumnRightClick(Self, Column, Point);
end;

procedure TGSCustomListView.InsertItem(Item: TGSListItem);
begin
  if Assigned(FOnInsert) then FOnInsert(Self, Item);
end;

procedure TGSCustomListView.AddItem(Item: String; AObject: TObject);
begin
  with Items.Add do
  begin
    Caption := Item;
    Data := AObject;
  end;
end;

function TGSCustomListView.CanChange(Item: TGSListItem; Change: Integer): Boolean;
var
  ItemChange: TItemChange;
begin
  Result := True;
  case Change of
    LVIF_TEXT: ItemChange := ctText;
    LVIF_IMAGE: ItemChange := ctImage;
    LVIF_STATE: ItemChange := ctState;
  else
    Exit;
  end;
  if Assigned(FOnChanging) then
    FOnChanging(Self, Item, ItemChange, Result);
end;

procedure TGSCustomListView.Change(Item: TGSListItem; Change: Integer);
var
  ItemChange: TItemChange;
begin
  case Change of
    LVIF_TEXT: ItemChange := ctText;
    LVIF_IMAGE: ItemChange := ctImage;
    LVIF_STATE: ItemChange := ctState;
  else
    Exit;
  end;
  if Assigned(FOnChange) then
    FOnChange(Self, Item, ItemChange);
end;

procedure TGSCustomListView.DblClick;
begin
  if not FBlockDblClick then inherited;
  FBlockDblClick := False;
end;

procedure TGSCustomListView.Delete(Item: TGSListItem);
begin
  if (Item <> nil) and not Item.FProcessedDeleting then
  begin
    if Assigned(FOnDeletion) then
      FOnDeletion(Self, Item);
    Item.FProcessedDeleting := True;
    Item.Delete;
  end;
end;

function TGSCustomListView.CanEdit(Item: TGSListItem): Boolean;
begin
  Result := True;
  if Assigned(FOnEditing) then FOnEditing(Self, Item, Result);
end;

procedure TGSCustomListView.Edit(const Item: TLVItem);
var
  S: string;
  EditItem: TGSListItem;
begin
  with Item do
  begin
    S := pszText;
    EditItem := GetItem(Item);
    if Assigned(FOnEdited) then FOnEdited(Self, EditItem, S);
    if EditItem <> nil then EditItem.Caption := S;
  end;
end;

function TGSCustomListView.IsEditing: Boolean;
var
  ControlHand: HWnd;
begin
  ControlHand := ListView_GetEditControl(Handle);
  Result := (ControlHand <> 0) and IsWindowVisible(ControlHand);
end;

function TGSCustomListView.GetDragImages: TDragImageList;
begin
  if SelCount = 1 then
    Result := FDragImage
  else
    Result := nil;
end;

procedure TGSCustomListView.WndProc(var Message: TMessage);

  function ProcessGroupHeaderClick: Boolean;
  var
    HitTest: TGSHitTests;
  begin
    Result := False;
    HitTest :=
      GetHitTestInfoAt(TWMMouse(Message).XPos, TWMMouse(Message).YPos);
    if htOnGroup in HitTest then
    begin
      if Message.Msg = WM_LBUTTONDOWN then
        Groups.DoGroupClick(
          GetGroupAt(TWMMouse(Message).XPos, TWMMouse(Message).YPos))
      else
        Groups.DoGroupDblClick(
          GetGroupAt(TWMMouse(Message).XPos, TWMMouse(Message).YPos));
      Result := True;
    end;
 end;

begin
  if not (csDesigning in ComponentState) and
    ((Message.Msg = WM_LBUTTONDOWN) or
    (Message.Msg = WM_LBUTTONDBLCLK)) and not
    Dragging and (DragMode = dmAutomatic) then
  begin
    if not IsControlMouseMsg(TWMMouse(Message)) then
    begin
      ControlState := ControlState + [csLButtonDown];
      FBlockDblClick := ProcessGroupHeaderClick;
      Dispatch(Message);
    end;
  end
  else
    case Message.Msg of
      WM_LBUTTONDOWN, WM_LBUTTONDBLCLK:
      begin
        FBlockDblClick := ProcessGroupHeaderClick;
        inherited WndProc(Message);
      end;
      WM_KEYDOWN:
      if Message.WParam = VK_F2 then
      begin
        if (Selected <> nil) and CanEdit(Selected) then
          Selected.EditCaption;
      end
      else
        inherited WndProc(Message);
      WM_KEYUP:
      if Message.WParam = VK_ESCAPE then
      begin
        if (Selected <> nil) and IsEditing then
          Selected.CancelEdit;
      end
      else
        inherited WndProc(Message);
    else
      if not (((Message.Msg = WM_PAINT) or (Message.Msg = WM_ERASEBKGND)) and
        Items.FNoRedraw) then
        inherited WndProc(Message);
    end;
end;

procedure TGSCustomListView.DoStartDrag(var DragObject: TDragObject);
var
  P, P1: TPoint;
  ImageHandle: HImageList;
  DragItem: TGSListItem;
begin
  inherited DoStartDrag(DragObject);
  FLastDropTarget := nil;
  GetCursorPos(P);
  P := ScreenToClient(P);
  if FDragIndex <> -1 then
    DragItem := Items[FDragIndex]
    else DragItem := nil;
  FDragIndex := -1;
  if DragItem = nil then
    with P do DragItem := GetItemAt(X, Y);
  if DragItem <> nil then
  begin
    ImageHandle := ListView_CreateDragImage(Handle, DragItem.Index, P1);
    if ImageHandle <> 0 then
      with FDragImage do
      begin
        Handle := ImageHandle;
        with P, DragItem.DisplayRect(drBounds) do
          SetDragImage(0, X - Left , Y - Top);
      end;
  end;
end;

procedure TGSCustomListView.DoEndDrag(Target: TObject; X, Y: Integer);

begin
  inherited DoEndDrag(Target, X, Y);
  FDragImage.EndDrag;
  FLastDropTarget := nil;
end;

procedure TGSCustomListView.CMDrag(var Message: TCMDrag);
var
  I: Integer;
  Item: TGSListItem;
begin
  inherited;
  with Message, DragRec^ do
    case DragMessage of
      dmDragMove: with ScreenToClient(Pos) do DoDragOver(Source, X, Y, Message.Result <> 0);
      dmDragLeave:
        begin
          TDragObject(Source).HideDragImage;
          FLastDropTarget := DropTarget;
          DropTarget := nil;
          Update;
          TDragObject(Source).ShowDragImage;
        end;
      dmDragDrop:
        begin
          FLastDropTarget := nil;
          { ListView_GetNextItem always returns nil for OwnerData = True and
            LVNI_ALL and LVNI_DROPHIGHLITED, so it is necessary to find the
            DropTarget and reset it by iterating through all items, starting
            with the first one that's visible }
          if OwnerData then
          begin
            if ViewStyle in [vsIcon, vsSmallIcon] then
              Item := GetNearestItem(Point(0, 0), sdAll)
            else
              Item := TopItem;
            if Item <> nil then
            for I := Item.Index to Items.Count - 1 do
              if Items[I].DropTarget then
              begin
                Items[I].DropTarget := False;
                Exit;
              end;
            end;
        end;
    end
end;

procedure TGSCustomListView.DoDragOver(Source: TDragObject; X, Y: Integer; CanDrop: Boolean);
var
  Item: TGSListItem;
  Target: TGSListItem;
begin
  Item := GetItemAt(X, Y);
  if Item <> nil then
  begin
    Target := DropTarget;
    if (Item <> Target) or (Item = FLastDropTarget) then
    begin
      FLastDropTarget := nil;
      TDragObject(Source).HideDragImage;
      Update;
      if Target <> nil then
        Target.DropTarget := False;
      Item.DropTarget := CanDrop;
      Update;
      TDragObject(Source).ShowDragImage;
    end;
  end;
end;

procedure TGSCustomListView.SetItems(Value: TGSListItems);
begin
  FListItems.Assign(Value);
end;

procedure TGSCustomListView.SetListColumns(Value: TGSListColumns);
begin
  FListColumns.Assign(Value);
end;

function TGSCustomListView.CustomSort(SortProc: TLVCompare; lParam: Longint): Boolean;
begin
  Result := False;
  if HandleAllocated then
  begin
    if not Assigned(SortProc) then SortProc := @DefaultListViewSort;
    Result := ListView_SortItems(Handle, SortProc, lParam);
  end;
end;

function TGSCustomListView.AlphaSort: Boolean;
begin
  if HandleAllocated then
    Result := ListView_SortItems(Handle, @DefaultListViewSort, 0)
  else Result := False;
end;

procedure TGSCustomListView.SetSortType(Value: TSortType);
begin
  if SortType <> Value then
  begin
    FSortType := Value;
    if ((SortType in [stData, stBoth]) and Assigned(OnCompare)) or
      (SortType in [stText, stBoth]) then
      AlphaSort;
  end;
end;

function TGSCustomListView.GetVisibleRowCount: Integer;
begin
  if ViewStyle in [vsReport, vsList] then
    Result := ListView_GetCountPerPage(Handle)
  else Result := 0;
end;

function TGSCustomListView.GetViewOrigin: TPoint;
begin
  ListView_GetOrigin(Handle, Result);
end;

function TGSCustomListView.GetTopItem: TGSListItem;
var
  Index: Integer;
begin
  Result := nil;
  if not (ViewStyle in [vsSmallIcon, vsIcon]) then
  begin
    Index := ListView_GetTopIndex(Handle);
    if Index <> -1 then Result := Items[Index];
  end;
end;

function TGSCustomListView.GetBoundingRect: TRect;
begin
  ListView_GetViewRect(Handle, Result);
end;

procedure TGSCustomListView.Scroll(DX, DY: Integer);
begin
  ListView_Scroll(Handle, DX, DY);
end;

procedure TGSCustomListView.SetLargeImages(Value: TCustomImageList);
begin
  if LargeImages <> Value then
  begin
    if LargeImages <> nil then
      LargeImages.UnRegisterChanges(FLargeChangeLink);
    FLargeImages := Value;
      if LargeImages <> nil then
      begin
        LargeImages.RegisterChanges(FLargeChangeLink);
        LargeImages.FreeNotification(Self);
        SetNormalImageList;
      end
      else
        SetImageList(0, LVSIL_NORMAL);

    Invalidate;
  end;
end;

procedure TGSCustomListView.SetSmallImages(Value: TCustomImageList);
begin
  if Value <> SmallImages then
  begin
    if SmallImages <> nil then
      SmallImages.UnRegisterChanges(FSmallChangeLink);
    FSmallImages := Value;
    if SmallImages <> nil then
    begin
      SmallImages.RegisterChanges(FSmallChangeLink);
      SmallImages.FreeNotification(Self);
      SetImageList(SmallImages.Handle, LVSIL_SMALL)
    end
    else SetImageList(0, LVSIL_SMALL);
    Invalidate;
  end;
end;

procedure TGSCustomListView.SetStateImages(Value: TCustomImageList);
begin
  if StateImages <> Value then
  begin
    if StateImages <> nil then
      StateImages.UnRegisterChanges(FStateChangeLink);
    FStateImages := Value;
    if CheckBoxes then SaveChecks;
    if StateImages <> nil then
    begin
      StateImages.RegisterChanges(FStateChangeLink);
      StateImages.FreeNotification(Self);
      SetImageList(StateImages.Handle, LVSIL_STATE);
      if CheckBoxes then RestoreChecks;
    end
    else
    begin
      SetImageList(0, LVSIL_STATE);
      if CheckBoxes then
      begin
        CheckBoxes := False;
        CheckBoxes := True;
      end;
    end;
    Invalidate;
  end;
end;

function TGSCustomListView.GetColumnFromIndex(Index: Integer): TGSListColumn;
begin
  Result := FListColumns[Index];
end;

function TGSCustomListView.FindCaption(StartIndex: Integer; Value: string;
  Partial, Inclusive, Wrap: Boolean): TGSListItem;
const
  FullString: array[Boolean] of Integer = (0, LVFI_PARTIAL);
  Wraps: array[Boolean] of Integer = (0, LVFI_WRAP);
var
  Info: TLVFindInfo;
  Index: Integer;
begin
  with Info do
  begin
    flags := LVFI_STRING or FullString[Partial] or Wraps[Wrap];
    psz := PChar(Value);
  end;
  if Inclusive then Dec(StartIndex);
  Index := ListView_FindItem(Handle, StartIndex, Info);
  if Index <> -1 then Result := Items[Index]
  else Result := nil;
end;

function TGSCustomListView.FindData(StartIndex: Integer; Value: Pointer;
  Inclusive, Wrap: Boolean): TGSListItem;
var
  I: Integer;
  Item: TGSListItem;
begin
  Result := nil;
  if Inclusive then Dec(StartIndex);
  for I := StartIndex + 1 to Items.Count - 1 do
  begin
    Item := Items[I];
    if (Item <> nil) and (Item.Data = Value) then
    begin
      Result := Item;
      Exit;
    end;
  end;
  if Wrap then
  begin
    if Inclusive then Inc(StartIndex);
    for I := 0 to StartIndex - 1 do
    begin
      Item := Items[I];
      if (Item <> nil) and (Item.Data = Value) then
      begin
        Result := Item;
        Exit;
      end;
    end;
  end;
end;

function TGSCustomListView.GetHitTestInfoAt(X, Y: Integer): TGSHitTests;

  procedure AddOnGroupValue(const Value: TGSHitTest);
  begin
    Include(Result, htOnGroup);
    Include(Result, Value);
  end;

var
  HitTest: TLVHitTestInfo;
  I: Integer;
  R: TRect;
begin
  Result := [];
  ZeroMemory(@HitTest, SizeOf(TLVHitTestInfo));
  with HitTest do
  begin
    pt.X := X;
    pt.Y := Y;
//    flags := LVHT_EX_GROUP;
    ListView_HitTest(Handle, HitTest);
//    ListView_SubItemHitTest(Handle, @HitTest);

    //! WINBUG: LVHT_ABOVE and LVHT_ONITEMSTATEICON have the same value!
    //! We can determine whether a LVHT_ABOVE ocurred ourselves by checking
    //! whether the Y is below 0, and whether a LVHT_ONITEMSTATEICON ocurred
    //! by
    if ((flags and LVHT_ABOVE) <> 0) and (Y < 0) then Include(Result, htAbove);
    if (flags and LVHT_BELOW) <> 0 then Include(Result, htBelow);
    if (flags and LVHT_NOWHERE) <> 0 then Include(Result, htNowhere);
    if (flags and LVHT_ONITEM) = LVHT_ONITEM then
      Include(Result, htOnItem)
    else
    begin
      if (flags and LVHT_ONITEMICON) <> 0 then Include(Result, htOnIcon);
      if (flags and LVHT_ONITEMLABEL) <> 0 then Include(Result, htOnLabel);
      if (flags and LVHT_ONITEMSTATEICON) <> 0 then Include(Result, htOnStateIcon);
    end;
    if (flags and LVHT_TOLEFT) <> 0 then Include(Result, htToLeft);
    if (flags and LVHT_TORIGHT) <> 0 then Include(Result, htToRight);

    //    Viste  
    //       -   ?!
    if (flags and LVHT_EX_GROUP_HEADER) <> 0 then AddOnGroupValue(htOnGroupHeader);
    if (flags and LVHT_EX_GROUP_FOOTER) <> 0 then AddOnGroupValue(htOnGroupFooter);
    if (flags and LVHT_EX_GROUP_COLLAPSE) <> 0 then AddOnGroupValue(htOnGroupCollapse);
    if (flags and LVHT_EX_GROUP_BACKGROUND) <> 0 then AddOnGroupValue(htOnGroupBackGround);
    if (flags and LVHT_EX_GROUP_STATEICON) <> 0 then AddOnGroupValue(htOnGroupStateIcon);
    if (flags and LVHT_EX_GROUP_SUBSETLINK) <> 0 then AddOnGroupValue(htOnGroupSubSetLink);
    if (flags and LVHT_EX_ONCONTENTS) <> 0 then Include(Result, htOnContents);
    if (flags and LVHT_EX_FOOTER) <> 0 then Include(Result, htOnFooter);

    //       
    for I := 0 to Groups.Count - 1 do
    begin
      if ListView_GetGroupRect(Handle,
        Groups[I].GroupID, LVGGR_HEADER, R) = 1 then
      begin
        if PtInRect(R, pt) then
          AddOnGroupValue(htOnGroupHeader);
        ListView_GetGroupRect(Handle, Groups[I].GroupID, LVGGR_SUBSETLINK, R);
        if PtInRect(R, pt) then
          AddOnGroupValue(htOnGroupSubSetLink);
        Break;
      end;
    end;
  end;
end;

function TGSCustomListView.GetSelected: TGSListItem;
begin
  Result := GetNextItem(nil, sdAll, [isSelected]);
end;

procedure TGSCustomListView.SetSelected(Value: TGSListItem);
var
  I: Integer;
begin
  if Value <> nil then Value.Selected := True
  else begin
    Value := Selected;
    for I := 0 to SelCount - 1 do
      if Value <> nil then
      begin
        Value.Selected := False;
        Value := GetNextItem(Value, sdAll, [isSelected]);
      end;                                            
  end;
end;

function TGSCustomListView.GetDropTarget: TGSListItem;
begin
  Result := GetNextItem(nil, sdAll, [isDropHilited]);
  if Result = nil then
    Result := FLastDropTarget;
end;

procedure TGSCustomListView.SetDoubleBuffered(const Value: Boolean);
begin
  FDoubleBuffered := Value;
  ResetExStyles;
end;

procedure TGSCustomListView.SetDropTarget(Value: TGSListItem);
begin
  if HandleAllocated then
    if Value <> nil then Value.DropTarget := True
    else begin
      Value := DropTarget;
      if Value <> nil then Value.DropTarget := False;
    end;
end;

function TGSCustomListView.GetFocused: TGSListItem;
begin
  Result := GetNextItem(nil, sdAll, [isFocused]);
end;

function TGSCustomListView.GetGroupAt(X, Y: Integer): TGSListGroup;
var
  pt: Tpoint;
  I: Integer;
  R: TRect;
begin
  Result := nil;
  if HandleAllocated then
  begin
    pt := Point(X, Y);
    for I := 0 to Groups.Count - 1 do
    begin
      if ListView_GetGroupRect(Handle,
        Groups[I].GroupID, LVGGR_HEADER, R) = 0 then Break;
      if PtInRect(R, pt) then
      begin
        Result := Groups[I];
        Break;
      end;
    end;
  end;
end;

procedure TGSCustomListView.SetFocused(Value: TGSListItem);
begin
  if HandleAllocated then
    if Value <> nil then Value.Focused := True
    else begin
      Value := ItemFocused;
      if Value <> nil then Value.Focused := False;
    end;
end;

procedure TGSCustomListView.GetImageIndex(Item: TGSListItem);
begin
  if Assigned(FOnGetImageIndex) then
    FOnGetImageIndex(Self, Item);
end;

function TGSCustomListView.GetNextItem(StartItem: TGSListItem;
  Direction: TSearchDirection; States: TItemStates): TGSListItem;
var
  Flags, Index: Integer;
begin
  Result := nil;
  if HandleAllocated then
  begin
    Flags := 0;
    case Direction of
      sdAbove: Flags := LVNI_ABOVE;
      sdBelow: Flags := LVNI_BELOW;
      sdLeft: Flags := LVNI_TOLEFT;
      sdRight: Flags := LVNI_TORIGHT;
      sdAll: Flags := LVNI_ALL;
    end;
    if StartItem <> nil then Index := StartItem.Index
    else Index := -1;
    if isCut in States then Flags := Flags or LVNI_CUT;
    if isDropHilited in States then Flags := Flags or LVNI_DROPHILITED;
    if isFocused in States then Flags := Flags or LVNI_FOCUSED;
    if isSelected in States then Flags := Flags or LVNI_SELECTED;
    Index := ListView_GetNextItem(Handle, Index, Flags);
    if Index <> -1 then Result := Items[Index];
  end;
end;

function TGSCustomListView.GetNearestItem(Point: TPoint;
  Direction: TSearchDirection): TGSListItem;
const
  Directions: array[TSearchDirection] of Integer = (VK_LEFT, VK_RIGHT,
    VK_UP, VK_DOWN, 0);
var
  Info: TLVFindInfo;
  Index: Integer;
begin
  with Info do
  begin
    flags := LVFI_NEARESTXY;
    pt := Point;
    vkDirection := Directions[Direction];
  end;
  Index := ListView_FindItem(Handle, -1, Info);
  if Index <> -1 then Result := Items[Index]
  else Result := nil;
end;

function TGSCustomListView.GetItemAt(X, Y: Integer): TGSListItem;
var
  Info: TLVHitTestInfo;
var
  Index: Integer;
begin
  Result := nil;
  if HandleAllocated then
  begin
    Info.pt := Point(X, Y);
    Index := ListView_HitTest(Handle, Info);
    if Index <> -1 then Result := Items[Index];
  end;
end;

procedure TGSCustomListView.Arrange(Code: TListArrangement);
const
  Codes: array[TListArrangement] of Longint = (LVA_ALIGNBOTTOM, LVA_ALIGNLEFT,
    LVA_ALIGNRIGHT, LVA_ALIGNTOP, LVA_DEFAULT, LVA_SNAPTOGRID);
begin
  ListView_Arrange(Handle, Codes[Code]);
end;

procedure TGSCustomListView.AutosizeColumns;
begin
  DoAutoSize;
end;

function TGSCustomListView.StringWidth(S: string): Integer;
begin
  Result := ListView_GetStringWidth(Handle, PChar(S));
end;

procedure TGSCustomListView.UpdateColumns;
var
  I: Integer;
begin
  if HandleAllocated and not FUpdatingColumnOrder then
    for I := 0 to Columns.Count - 1 do UpdateColumn(I);
  Columns.SetSortDirection(Columns.SortDirection);
  CheckHeaderOverflow;
end;

procedure TGSCustomListView.UpdateGroup(AnIndex: Integer);
var
  I, GroupID: Integer;
  GroupIDs: array of Integer;
begin
  if HandleAllocated then
  begin
    SetLength(GroupIDs, Items.Count);
    GroupID := Groups[AnIndex].GroupID;
    for I := 0 to Items.Count - 1 do
      if Items[I].GroupID = GroupID then
        Items[I].GroupID := -2;

    UpdateGroupData(AnIndex);

    for I := 0 to Items.Count - 1 do
      if Items[I].GroupID = -2 then
        Items[I].GroupID := GroupID;
  end;
end;

procedure TGSCustomListView.UpdateGroupData(AnIndex: Integer);
var
  Group: TLVGroup;
begin
  if HandleAllocated then
  begin
    ZeroMemory(@Group, SizeOf(Group));
    with Group, Groups.Items[AnIndex] do
    begin
      ListView_RemoveGroup(Handle, Groups.Items[AnIndex].GroupID);

      mask := LVGF_STATE or LVGF_ALIGN;

      if Header <> '' then
        mask := mask or LVGF_HEADER;
      if Footer <> '' then
        mask := mask or LVGF_FOOTER;

      if Task <> '' then
        mask := mask or LVGF_TASK;

      cbSize := SizeOf(Group);
      pszHeader := PWideChar(StringToOleStr(Header));
      pszFooter := PWideChar(StringToOleStr(Footer));
      pszSubtitle := PWideChar(StringToOleStr(Subtitle));
      pszTask := PWideChar(StringToOleStr(Task));
      pszDescriptionTop := PWideChar(StringToOleStr(TopDescription));
      pszDescriptionBottom := PWideChar(StringToOleStr(BottomDescription));

      cchHeader := Length(Header);
      cchFooter := Length(Footer);
      cchSubtitle := Length(Subtitle);
      cchTask := Length(Task);
      cchDescriptionTop := Length(TopDescription);
      cchDescriptionBottom := Length(BottomDescription);

      Group.stateMask := 0;
      Group.state := 0;
      if lgsNormal in Groups.Items[AnIndex].PreparedState then
        Group.state := Group.state or LVGS_NORMAL;
      if lgsHidden in Groups.Items[AnIndex].PreparedState then
        Group.state := Group.state or LVGS_HIDDEN;

      uAlign := 0;

      if CheckWin32Version(6) then
      begin
        mask := mask or LVGF_TITLEIMAGE or LVGF_EXTENDEDIMAGE;

        if Subtitle <> '' then
          mask := mask or LVGF_SUBTITLE;
        if TopDescription <> '' then
          mask := mask or LVGF_DESCRIPTIONTOP;
        if BottomDescription <> '' then
          mask := mask or LVGF_DESCRIPTIONBOTTOM;

        if lgsNoHeader in Groups.Items[AnIndex].PreparedState then
          Group.state := Group.state or LVGS_NOHEADER;
        if lgsCollapsible in Groups.Items[AnIndex].PreparedState then
          Group.state := Group.state or LVGS_COLLAPSIBLE;
        if lgsCollapsed in Groups.Items[AnIndex].PreparedState then
          Group.state := Group.state or LVGS_COLLAPSED;
        if lgsFocused in Groups.Items[AnIndex].PreparedState then
          Group.state := Group.state or LVGS_FOCUSED;
        if lgsSelected in Groups.Items[AnIndex].PreparedState then
          Group.state := Group.state or LVGS_SELECTED;
        if lgsSubseted in Groups.Items[AnIndex].PreparedState then
          Group.state := Group.state or LVGS_SUBSETED;
        if lgsSubSetLinkFocused in Groups.Items[AnIndex].PreparedState then
          Group.state := Group.state or LVGS_SUBSETLINKFOCUSED;

        case FooterAlign of
          taLeftJustify: uAlign := uAlign or LVGA_FOOTER_LEFT;
          taRightJustify: uAlign := uAlign or LVGA_FOOTER_RIGHT;
          taCenter: uAlign := uAlign or LVGA_FOOTER_CENTER;
        end;                   
      end;

      case HeaderAlign of
        taLeftJustify: uAlign := uAlign or LVGA_HEADER_LEFT;
        taRightJustify: uAlign := uAlign or LVGA_HEADER_RIGHT;
        taCenter: uAlign := uAlign or LVGA_HEADER_CENTER;
      end;

      iTitleImage := TitleImage;
      iExtendedImage := ExtendedImage;

      mask := mask or LVGF_GROUPID;
      iGroupId := Groups[AnIndex].GroupID;
      ListView_InsertGroup(Handle, AnIndex, Group);
    end;
  end;
end;

procedure TGSCustomListView.UpdateGroups;

  function GroupSort(GroupID1, GroupID2: Integer;
    lParam: Integer): Integer; stdcall;
  begin
    if Boolean(lParam) then
      Result := GroupID2 - GroupID1
    else
      Result := GroupID1 - GroupID2;
  end;

var
  I: Integer;
  GroupIDs: array of Integer;
begin
  if HandleAllocated then
  begin
    SetLength(GroupIDs, Items.Count);

    for I := 0 to Items.Count - 1 do
    begin
      GroupIDs[I] := Items[I].GroupID;
      Items[I].GroupID := -1;
    end;

    for I := 0 to Groups.Count - 1 do
      UpdateGroupData(I);

    for I := 0 to Items.Count - 1 do
      Items[I].GroupID := GroupIDs[I];

    ListView_SortGroups(Handle, @GroupSort, Pointer(Groups.Inverted));
  end;
end;

function TGSCustomListView.UpdateAction(Action: TBasicAction): Boolean;
var
  ASelStart, ASelEnd: Integer;
begin
  Result := inherited UpdateAction(Action);
  if Focused or IsEditing then
  begin
    if not IsEditing then
    begin
      //     
      //     
      if Action is TEditSelectAll then
      begin
        TAction(Action).Enabled := MultiSelect and not ReadOnly;
        Result := True;
        Exit;
      end;
    end
    else
    begin
      //       
      if (Action is TEditDelete) or
        (Action is TEditCopy) or
        (Action is TEditCut) then
      begin
        SendMessage(FEditHandle, EM_GETSEL,
          Integer(@ASelStart), Integer(@ASelEnd));
        TAction(Action).Enabled := (ASelStart - ASelEnd) <> 0;
        Result := True;
      end;
      if Action is TEditPaste then
      begin
        {OpenClipboard(Handle);
        try
          TAction(Action).Enabled :=
            GetClipboardData(CF_TEXT) <> 0;
        finally
          CloseClipboard;
        end; }
        // Rouse_ 08.05.2009
        //     
        TAction(Action).Enabled :=
          IsClipboardFormatAvailable(CF_TEXT);
        Result := True;
        Exit;          
      end;
      if Action is TEditSelectAll then
      begin
        TAction(Action).Enabled :=
          SendMessage(FEditHandle, WM_GETTEXTLENGTH, 0, 0) <> 0;
        Result := True;
      end;
      if Action is TEditUndo then
      begin
        TAction(Action).Enabled :=
          SendMessage(FEditHandle, EM_CANUNDO, 0, 0) <> 0;
        Result := True;
      end;
    end;
  end;
end;

procedure TGSCustomListView.UpdateAllItems;
var
  I: Integer;
begin
  Items.BeginUpdate;
  try
    for I := 0 to Items.Count - 1 do
      ListView_Update(Handle, I);
  finally
    Items.EndUpdate;
  end;
end;

procedure TGSCustomListView.UpdateColumn(AnIndex: Integer);
const IAlignment: array[Boolean, TAlignment] of LongInt =
  ((LVCFMT_LEFT, LVCFMT_RIGHT, LVCFMT_CENTER),
   (LVCFMT_RIGHT, LVCFMT_LEFT, LVCFMT_CENTER));
var
  lvColumn: TLVColumn;
  AAlignment: TAlignment;
  HeaderItem: THDItem;
begin
  if HandleAllocated then
    with lvColumn, Columns.Items[AnIndex] do
    begin
      mask := LVCF_TEXT or LVCF_FMT or LVCF_IMAGE;
      iImage := FImageIndex;
      pszText := PChar(Caption);
      AAlignment := Alignment;
      if Index >= 0 then
        fmt := IAlignment[UseRightToLeftAlignment, AAlignment]
      else
        fmt := LVCFMT_LEFT;
      if FImageIndex <> -1 then
        fmt := fmt or LVCFMT_IMAGE or LVCFMT_COL_HAS_IMAGES
      else
        mask := mask and not LVCF_IMAGE;

      if SplitButton then
        fmt := fmt or LVCFMT_SPLITBUTTON;


      HeaderItem.Mask := HDI_FORMAT;
      Header_GetItem(FHeaderHandle, AnIndex, HeaderItem);
      if Columns[AnIndex].CheckBox then
      begin
        HeaderItem.fmt := HeaderItem.fmt or HDF_CHECKBOX;
        if Columns[AnIndex].Checked then
          HeaderItem.fmt := HeaderItem.fmt or HDF_CHECKED
        else
          HeaderItem.fmt := HeaderItem.fmt and not HDF_CHECKED;
      end
      else
        HeaderItem.fmt := HeaderItem.fmt and not HDF_CHECKBOX;
      Header_SetItem(FHeaderHandle, AnIndex, HeaderItem);

      if WidthType > ColumnTextWidth then
      begin
        mask := mask or LVCF_WIDTH;
        cx := FWidth;
        ListView_SetColumn(Handle, Columns[AnIndex].FOrderTag, lvColumn);
      end
      else
      begin
        ListView_SetColumn(Handle, Columns[AnIndex].FOrderTag, lvColumn);
        if ViewStyle = vsList then
          ListView_SetColumnWidth(Handle, -1, WidthType)
        else
        if (ViewStyle = vsReport) and not OwnerData then
          ListView_SetColumnWidth(Handle, Columns[AnIndex].FOrderTag, WidthType);
      end;
    end;
end;

procedure TGSCustomListView.WMLButtonDown(var Message: TWMLButtonDown);
var
  Item: TGSListItem;
  MousePos: TPoint;
  ShiftState: TShiftState;
begin
  SetFocus;
  ShiftState := KeysToShiftState(Message.Keys);
  FClicked := False;
  FDragIndex := -1;
  inherited;
  if (DragMode = dmAutomatic) and MultiSelect then
  begin
    if not (ssShift in ShiftState) and not (ssCtrl in ShiftState) then
    begin
      if not FClicked then
      begin
        Item := GetItemAt(Message.XPos, Message.YPos);
        if (Item <> nil) and Item.Selected then
        begin
          BeginDrag(False);
          Exit;
        end;
      end;
    end;
  end;
  if FClicked then
  begin
    GetCursorPos(MousePos);
    with PointToSmallPoint(ScreenToClient(MousePos)) do
      if not Dragging then
      begin
        Perform(WM_LBUTTONUP, 0, MakeLong(X, Y));
        FClicked := False;
      end
      else SendMessage(GetCapture, WM_LBUTTONUP, 0, MakeLong(X, Y));
  end
  else if (DragMode = dmAutomatic) and not (MultiSelect and
    ((ssShift in ShiftState) or (ssCtrl in ShiftState))) then
  begin
    Item := GetItemAt(Message.XPos, Message.YPos);
    if (Item <> nil) and Item.Selected then
      BeginDrag(False);
  end;
end;

procedure TGSCustomListView.DoAutoSize;
var
  I, Count, WorkWidth, TmpWidth, Remain: Integer;
  List: TList;
  Column: TGSListColumn;
begin
  { Try to fit all sections within client width }
  List := TList.Create;
  try
    WorkWidth := ClientWidth;
    for I := 0 to Columns.Count - 1 do
    begin
      Column := Columns[I];
      if Column.AutoSize then
        List.Add(Column)
      else
        Dec(WorkWidth, Column.Width);
    end;
    if List.Count > 0 then
    begin
      Columns.BeginUpdate;
      try
        repeat
          Count := List.Count;
          Remain := WorkWidth mod Count;
          { Try to redistribute sizes to those sections which can take it }
          TmpWidth := WorkWidth div Count;
          for I := Count - 1 downto 0 do
          begin
            Column := TGSListColumn(List[I]);
            if I = 0 then
              Inc(TmpWidth, Remain);
            Column.Width := TmpWidth;
          end;

          { Verify new sizes don't conflict with min/max section widths and
            adjust if necessary. }
          TmpWidth := WorkWidth div Count;
          for I := Count - 1 downto 0 do
          begin
            Column := TGSListColumn(List[I]);
            if I = 0 then
              Inc(TmpWidth, Remain);
            if Column.Width <> TmpWidth then
            begin
              List.Delete(I);
              Dec(WorkWidth, Column.Width);
            end;
          end;
        until (List.Count = 0) or (List.Count = Count);

        // Rouse_ 07.10.2009
        //     
        FLockedColumnsWidth.Clear;
        for I := 0 to Columns.Count - 1 do
          FLockedColumnsWidth.Add(Pointer(Columns[I].Width));
          
      finally
        Columns.EndUpdate;
      end;
    end;
  finally
    List.Free;
  end;
end;

procedure TGSCustomListView.DoColumnDropDown(ColumnIndex: Integer);
var
  AColumn: TGSListColumn;
  pt: TPoint;
  ARect: TRect;
begin
  if Assigned(FColumnDropDown) then
  begin
    AColumn := Columns[ColumnIndex];
    Header_GetItemDropDownRect(ListView_GetHeader(Handle),
      AColumn.Index, ARect);
    pt := ClientToScreen(Point(ARect.Left, ARect.Bottom));
    FColumnDropDown(Self, AColumn, pt);
  end;
end;

function TGSCustomListView.DoContextPopup(const Context: TContextPopupStack;
  const MousePos: TPoint): Boolean;
var
  I: TContextPopupStack;
  Stack: TContextPopupStacks;
begin
  Result := False;
  Stack := [];
  for I := Context to High(TContextPopupStack) do
    Include(Stack, I);
  if psEdit in Stack then
    if Assigned(FOnEditPopup) then
      FOnEditPopup(Self, MousePos, Result);
  if psSelected in Stack then
    if not Result then
      if Assigned(FOnSelectedPopup) then
        FOnSelectedPopup(Self, MousePos, Result);
  if not Result then
    inherited DoContextPopup(MousePos, Result);
end;

procedure TGSCustomListView.WMWindowPosChanged(var Message: TWMWindowPosChanged);
begin
  if not (csReading in ComponentState) and
     (Message.WindowPos^.flags and SWP_NOSIZE = 0) and HandleAllocated then
    DoAutoSize;
  inherited;
end;

function TGSCustomListView.GetSearchString: string;
var
  Len: Integer;
begin
  Result := '';
  if HandleAllocated then
  begin
    Len := SendMessage(Handle, LVM_GETISEARCHSTRING, 0, 0);
    if Len > 0 then
    begin
      SetLength(Result, Len);
      ListView_GetISearchString(Handle, PChar(Result));
    end;
  end;
end;

procedure TGSCustomListView.CNDrawItem(var Message: TWMDrawItem);
var
  State: TOwnerDrawState;
  SaveIndex: Integer;
begin
  if Assigned(FCanvas) then
  begin
    with Message.DrawItemStruct^ do
    begin
      State := TOwnerDrawState(LongRec(itemState).Lo);
      SaveIndex := SaveDC(hDC);
      FCanvas.Lock;
      try
        FCanvas.Handle := hDC;
        FCanvas.Font := Font;
        FCanvas.Brush := Brush;
        if itemID = DWORD(-1) then FCanvas.FillRect(rcItem)
        else DrawItem(Items[itemID], rcItem, State);
      finally
        FCanvas.Handle := 0;
        FCanvas.Unlock;
        RestoreDC(hDC, SaveIndex);
      end;
    end;
    Message.Result := 1;
  end;
end;

{ CustomDraw support }

procedure TGSCustomListView.CanvasChanged;
begin
  FCanvasChanged := True;
end;

function TGSCustomListView.IsCustomDrawn(Target: TCustomDrawTarget;
  Stage: TCustomDrawStage): Boolean;
begin
  { List view doesn't support erase notifications }
  if Stage = cdPrePaint then
  begin
    if Target = dtSubItem then
      Result := Assigned(FOnCustomDrawSubItem) or Assigned(FOnAdvancedCustomDrawSubItem)
    else if Target = dtItem then
      Result := Assigned(FOnCustomDrawItem) or Assigned(FOnAdvancedCustomDrawItem) or
        Assigned(FOnCustomDrawSubItem) or Assigned(FOnAdvancedCustomDrawSubItem)
    else
      Result := Assigned(FOnCustomDraw) or Assigned(FOnAdvancedCustomDraw) or
        Assigned(FOnCustomDrawItem) or Assigned(FOnAdvancedCustomDrawItem) or
        Assigned(FOnCustomDrawSubItem) or Assigned(FOnAdvancedCustomDrawSubItem);
  end
  else
  begin
    if Target = dtSubItem then
      Result := Assigned(FOnAdvancedCustomDrawSubItem) or Assigned(FOnCustomDrawSubItem)
    else if Target = dtItem then
      Result := Assigned(FOnAdvancedCustomDrawItem) or Assigned(FOnCustomDrawItem)
    else
      Result := Assigned(FOnAdvancedCustomDraw) or Assigned(FOnAdvancedCustomDrawItem) or
        Assigned(FOnAdvancedCustomDrawSubItem);
  end;
end;

function TGSCustomListView.CustomDraw(const ARect: TRect; Stage: TCustomDrawStage): Boolean;
begin
  Result := True;
  if (Stage = cdPrePaint) and Assigned(FOnCustomDraw) then FOnCustomDraw(Self, ARect, Result);
  if Assigned(FOnAdvancedCustomDraw) then FOnAdvancedCustomDraw(Self, ARect, Stage, Result)
end;

function TGSCustomListView.CustomDrawItem(Item: TGSListItem; State: TCustomDrawState;
  Stage: TCustomDrawStage): Boolean;
begin
  Result := True;
  if (Stage = cdPrePaint) and Assigned(FOnCustomDrawItem) then FOnCustomDrawItem(Self, Item, State, Result);
  if Assigned(FOnAdvancedCustomDrawItem) then FOnAdvancedCustomDrawItem(Self, Item, State, Stage, Result);
end;

function TGSCustomListView.CustomDrawSubItem(Item: TGSListItem; SubItem: Integer;
  State: TCustomDrawState; Stage: TCustomDrawStage): Boolean;
begin
  Result := True;
  if (Stage = cdPrePaint) and Assigned(FOnCustomDrawSubItem) then
    FOnCustomDrawSubItem(Self, Item, SubItem, State, Result);
  if Assigned(FOnAdvancedCustomDrawSubItem) then
    FOnAdvancedCustomDrawSubItem(Self, Item, SubItem, State, Stage, Result);
end;

procedure TGSCustomListView.DrawItem(Item: TGSListItem; Rect: TRect;
  State: TOwnerDrawState);
begin
  TControlCanvas(FCanvas).UpdateTextFlags;
  if Assigned(FOnDrawItem) then FOnDrawItem(Self, Item, Rect, State)
  else
  begin
    FCanvas.FillRect(Rect);
    FCanvas.TextOut(Rect.Left + 2, Rect.Top, Item.Caption);
  end;
end;

procedure TGSCustomListView.GetSubItemImage(Item: TGSListItem;
  SubItem: Integer; var ImageIndex: Integer);
begin
  if Assigned(FOnGetSubItemImage) and (SubItem < Item.SubItems.Count) and (SubItem >= 0) then
    FOnGetSubItemImage(Self, Item, SubItem, ImageIndex);
end;

procedure TGSCustomListView.DrawWorkAreas;
var
  I, dX, dY: Integer;
  R: TRect;
begin
  with FCanvas do
  begin
    Brush.Style := bsClear;
    for I := 0 to WorkAreas.Count-1 do
    begin
      Pen.Color := WorkAreas[I].Color;
      Pen.Style := psDot;
      dX := -GetViewOrigin.X;
      dY := -GetViewOrigin.Y;
      R := WorkAreas[I].Rect;
      OffsetRect(R, dX, dY);
      Rectangle(R.Left, R.Top, R.Right, R.Bottom);
      if WorkAreas[I].DisplayName <> '' then
      begin
        Pen.Style := psSolid;
        Font.Color := WorkAreas[I].Color;
        TextOut(R.Left, R.Bottom, WorkAreas[I].DisplayName);
      end;
    end;
  end;
end;

procedure TGSCustomListView.WMPaint(var Message: TWMPaint);
begin
  inherited;
  if (ViewStyle in [vsIcon, vsSmallIcon]) and FShowWorkAreas then
    DrawWorkAreas;
end;

procedure TGSCustomListView.SetShowColumnAllwais(const Value: Boolean);
begin
  if ShowColumnAllwais <> Value then
  begin
    FShowColumnAllwais := Value;
    RecreateWnd;
  end;
end;

procedure TGSCustomListView.SetShowWorkAreas(const Value: Boolean);
begin
  FShowWorkAreas := Value;
  Invalidate;
end;

{ InfoTip support }

procedure TGSCustomListView.CMHintShow(var Message: TMessage);
var
  Item: TGSListItem;
  ItemRect: TRect;
  InfoTip: string;
begin
  if Assigned(FOnInfoTip) then
    with TCMHintShow(Message) do
    begin
      Item := GetItemAt(HintInfo.CursorPos.X, HintInfo.CursorPos.Y);
      if Item <> nil then
      begin
        InfoTip := Item.Caption;
        DoInfoTip(Item, InfoTip);
        ItemRect := Item.DisplayRect(drBounds);
        ItemRect.TopLeft := ClientToScreen(ItemRect.TopLeft);
        ItemRect.BottomRight := ClientToScreen(ItemRect.BottomRight);
        with HintInfo^ do
        begin
          HintInfo.CursorRect := ItemRect;
          HintInfo.HintStr := InfoTip;
          HintPos.Y := CursorRect.Top + GetSystemMetrics(SM_CYCURSOR);
          HintPos.X := CursorRect.Left + GetSystemMetrics(SM_CXCURSOR);
          HintInfo.HintMaxWidth := ClientWidth;
          Message.Result := 0;
        end
      end;
    end
  else
    inherited;
end;

procedure TGSCustomListView.DoInfoTip(Item: TGSListItem; var InfoTip: string);
begin
  if Assigned(FOnInfoTip) then FOnInfoTip(Self, Item, InfoTip);
end;

procedure TGSCustomListView.SetHoverTime(Value: Integer);
begin
  if Value <> HoverTime then
  begin
    if HandleAllocated then
      ListView_SetHoverTime(Handle, Value)
    else
      FHoverTime := Value;
  end;
end;

function TGSCustomListView.GetHoverTime: Integer;
begin
  if HandleAllocated then
    Result := ListView_GetHoverTime(Handle)
  else
    Result := FHoverTime;
end;

function TGSCustomListView.AreItemsStored: Boolean;
begin
  if Assigned(Action) then
  begin
    if Action is TCustomListAction then
      Result := False
    else
      Result := True;
  end
  else
    Result := not OwnerData;
end;

procedure TGSCustomListView.MouseUp(Button: TMouseButton; Shift: TShiftState;
  X, Y: Integer);
begin
  if (GetItemAt(X, Y) <> nil) or not FClicked then
    inherited;
end;

//procedure TGSCustomListView.MoveSortedItemsToGroups;
//var
//  I, GroupIndex: Integer;
//  Data: String;
//begin
//  Groups.BeginUpdate;
//  try
//    Groups.Clear;
//    for I := 0 to Items.Count - 1 do
//    begin
//      if Columns.SortedIndex = 0 then
//        Data := Items[I].Caption
//      else
//        Data := Items[I].SubItems[Columns.SortedIndex - 1];
//      GroupIndex := Groups.GetGroupIndexByName(Data);
//      if GroupIndex < 0 then
//      begin
//        GroupIndex := Groups.Count;
//        Groups.Add.Header := Data;
//      end;
//      Items[I].GroupID := GroupIndex;
//    end;
//  finally
//    Groups.EndUpdate;
//  end;
//end;

function TGSCustomListView.GetColumnFromTag(Tag: Integer): TGSListColumn;
var
  I: Integer;
begin
  for I := 0 to Columns.Count - 1 do
  begin
    Result := Columns[I];
    if Result.FOrderTag = Tag then Exit;
  end;
  Result := nil;
end;

procedure TGSCustomListView.WMContextMenu(var Message: TWMContextMenu);
const
  ContextStack: array [Boolean] of TContextPopupStack =
    (psNone, psSelected);
var
  MousePos: TPoint;
begin
  if not (csDesigning in ComponentState) then
    SetFocus;

  MousePos := SmallPointToPoint(Message.Pos);
  if InvalidPoint(MousePos) then
    if (Selected <> nil) then
      MousePos := ClientToScreen(
        CenterPoint(Selected.DisplayRect(drSelectBounds)))
    else
      MousePos := ClientToScreen(Point(0, 0));

  if DoContextPopup(ContextStack[Selected <> nil], ScreenToClient(MousePos)) then
    Exit;

  Message.Pos := PointToSmallPoint(MousePos);
  inherited;
end;

procedure TGSCustomListView.WMCtlColorEdit(var Message: TMessage);
var
  Form: TCustomForm;
begin
  if DoubleBuffered and DwmCompositionEnabled and (FSaveSelectedIndex = -1) then
  begin
    Form := GetParentForm(Self);
    if (Form <> nil) and Form.GlassFrame.FrameExtended and
      Form.GlassFrame.IntersectsControl(Self) then
    begin
      FSaveSelectedIndex := 0; // Used as flag to preserve unit signature
      PostMessage(FEditHandle, CM_BUFFEREDPRINTCLIENT, 0, 0);
    end;
  end
  else
    with Message do
      Result := DefWindowProc(Handle, Msg, WParam, LParam);
end;

procedure TGSCustomListView.ClearSelection;
var
  I: Integer;
begin
  for I := 0 to Items.Count - 1 do
    Items[I].Selected := False;
end;

procedure TGSCustomListView.CopySelection(Destination: TCustomListControl);
var
  I: Integer;
begin
  for I := 0 to Items.Count - 1 do
    if Items[I].Selected then
      Destination.AddItem(Items[I].Caption, Items[I].Data);
end;

procedure TGSCustomListView.DeleteSelected;
var
  I: Integer;
begin
  Items.BeginUpdate;
  try
    for I := Items.Count - 1 downto 0 do
      if Items[I].Selected then
        Delete(Items[I]);
  finally
    Items.EndUpdate;
  end;
end;

function TGSCustomListView.GetCount: Integer;
begin
  Result := Items.Count;
end;

procedure TGSCustomListView.SelectAll;
var
  I: Integer;
begin
  for I := 0 to Items.Count - 1 do
    Items[I].Selected := True;
end;

procedure TGSCustomListView.Clear;
begin
  FListItems.BeginUpdate;
  try
    FListItems.Clear;
  finally
    FListItems.EndUpdate;
  end;
end;

function TGSCustomListView.GetActionLinkClass: TControlActionLinkClass;
begin
  Result := TGSListViewActionLink;
end;

procedure TGSCustomListView.ActionChange(Sender: TObject;
  CheckDefaults: Boolean);
begin
  inherited ActionChange(Sender, CheckDefaults);
  if Sender is TStaticListAction then
    with TStaticListAction(Sender) do
    begin
      if not CheckDefaults or (Self.SmallImages = nil) then
        Self.SmallImages := Images;
      if not CheckDefaults or (Self.ItemIndex <> -1) then
        Self.ItemIndex := ItemIndex;
    end;
end;

procedure TGSCustomListView.WMVScroll(var Message: TWMVScroll);
var
  Before,
  After: Integer;
begin
  if ThemeServices.ThemesEnabled then
  begin
    Before := GetScrollPos(Handle, SB_VERT);
    inherited;
    After := GetScrollPos(Handle, SB_VERT);
    if (Before <> After) then
      InvalidateRect(Handle, nil, True);
  end
  else
    inherited;
end;

{$ENDREGION}

{$REGION ' TGSListViewActionLink '}

{ TGSListViewActionLink }

type
  TGSCustomListViewClass = class(TGSCustomListView);

procedure TGSListViewActionLink.AddItem(ACaption: String; AImageIndex: Integer;
  DataPtr: Pointer);
begin
  with TGSCustomListViewClass(FClient).Items.Add do
  begin
    ImageIndex := AImageIndex;
    Caption := ACaption;
    Data := DataPtr;
  end;
end;

procedure TGSListViewActionLink.AddItem(AnItem: TListControlItem);
begin
  with TGSCustomListViewClass(FClient).Items.Add do
  begin
    ImageIndex := AnItem.ImageIndex;
    Caption := AnItem.Caption;
    Data := AnItem.Data;
  end;
end;

procedure TGSListViewActionLink.SetImages(Value: TCustomImageList);
begin
  if IsImagesLinked then
    with FClient as TGSCustomListView do
      TGSCustomListViewClass(FClient).SmallImages := Value
end;

{$ENDREGION}

end.
